
/*******************************************************************************
DISCLAIMER

THIS SOFTWARE IS PROVIDED "AS IS" AND BFG ENGINEERING MAKES NO WARRANTIES
REGARDING THIS SOFTWARE, WHETHER EXPRESS, IMPLIED OR STATUTORY, INCLUDING
BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
PURPOSE AND NON-INFRINGEMENT. ALL SUCH WARRANTIES ARE EXPRESSLY DISCLAIMED.

WE (BFG ENGINEERING) DO NOT WARRANT THAT THIS SOFTWARE IS FREE FROM CLAIMS
BY A THIRD PARTY OF COPYRIGHT, PATENT, TRADEMARK, TRADE SECRET OR ANY OTHER
INTELLECTUAL PROPERTY INFRINGIMENT.

TO THE MAXIMUM EXTENT PERMITTED NOT PROHIBITED BY LAW, BFG ENGINEERING
SHALL NOT BE LIABLE FOR ANY DIRECT, INDIRECT, SPECIAL, INCIDENTAL OR
CONSEQUENTIAL DAMAGES FOR ANY REASON RELATED TO THIS SOFTWARE, EVEN IF BFG
ENGINEERING HAS BEEN ADVISED OF THE POSSIBILITY OF SUCH DAMAGES.
PARTICULARLY, UNDER NO CIRCUMSTANCES ARE WE LIABLE FOR ANY OF THE FOLLOWING:
- THIRD PARTY CLAIMS AGAINST YOU FOR LOSSES OR DAMAGES;
- LOSS OF, OR DAMAGE TO YOUR RECORDS OR DATA; OR
- ECONOMIC CONSEQUENTIAL DAMAGES (INCLUDING LOST PROFITS OR SAVINGS) OR
  INCIDENTAL DAMAGES, EVEN IF WE ARE INFORMED OF THEIR POSSIBILITY.

BFG ENGINEERING DOES NOT WARRANT UNINTERRUPTED OR ERROR_FREE OPERATION OF
THIS SOFTWARE.
BFG ENGINEERING HAS NO OBLIGATION TO PROVIDE SERVICE, DEFECT CORRECTION OR
ANY MANTEINANCE OF THIS SOFTWARE; OR TO SUPPLY ANY UPDATES OR ENHANCEMENTS
EVEN IF SUCH ARE, OR LATER BECOME, AVAILABLE.

IF YOU DOWNLOAD OR USE THIS SOFTWARE YOU AGREE TO THESE TERMS, AND DO IT AT
YOUR OWN RISK.
*******************************************************************************/

/*******************************************************************************
File:		customize.h
Project:	YRotateItRX66T
Revision:	1.0
Date:		2019-04-04 (YYYY-MM-DD)
Author:		Andrea Ghirardello
Contents:	Custom values definition
*******************************************************************************/
#ifndef _CUSTOMIZE_H
#define _CUSTOMIZE_H

//#include "typedefine.h"

// power stage related definitions
#include "pws_EBRX66T.h"		// power stage definitions

// eeprom (comment if not used)
#define EEPROM_USED

// debug (comment after first control)
#define MACRO_DEBUG

// ADDITIONAL FEATURE: current PI manual tuning (comment if not used)
#define CPI_TUN

// ADDITIONAL FEATURE: current PI automatic tuning (comment if not used)
#define CPI_AUT

// ADDITIONAL FEATURE: motor parameters auto-identification (comment if not used)
#define MOT_IDENT

// ADDITIONAL FEATURE: oscilloscope window in GUI management (comment if not used)
#define OSC_WIN

// motor parameters default values include
#include "par_defines.h"				// parameters limits and default values

// other definitions related to startup
#define STUP_CUR_RT_S		( 0.2f )	// current rising time during startup alignment [sec]
#define STUP_CUR_FT_S		( 1.0f )	// d current falling time after startup [sec] (assuming id=i_start)
#define ISTART_PH			( 0.523598775f )	// pi/6

// rotation direction (uncomment to change the positive rotation direction)
//#define REVERSED1
//#define REVERSED2
//#define REVERSED3

// current offsets refresh when motor not driven
#define OFF_REFRESH1
#define OFF_REFRESH2
#define OFF_REFRESH3

// modulation
//#define CENTRED1							// centred modulation
#define CEN_POS1_K			(  1.0f )	// 0<=CEN_POS1_K<=1; 0 means clamped to halfper, 1 means centred at (halfper-0.5(halfper-dmin))
//#define CENTRED2							// centred modulation
#define CEN_POS2_K			(  1.0f )	// 0<=CEN_POS2_K<=1; 0 means clamped to halfper, 1 means centred at (halfper-0.5(halfper-dmin))
//#define CENTRED3							// centred modulation
#define CEN_POS3_K			(  1.0f )	// 0<=CEN_POS3_K<=1; 0 means clamped to halfper - 1, 1 means centred at (halfper-0.5(halfper-dmin))

// compensations in modulation
//#define COMMRED1							// reduction of commutations number when clamping modulation (can produce voltage distortion)
//#define COMMRED2							// reduction of commutations number when clamping modulation (can produce voltage distortion)

// overmodulation (adjust to obtain overmodulation)
//#define K_OVERMOD1			(   1.0f )		// 1 -> no overmod, 1.1547=2/sqrt(3) -> full hex sat, <1 to limit out vol
#define K_OVERMOD1			(   1.155f )		// 1 -> no overmod, 1.1547=2/sqrt(3) -> full hex sat, <1 to limit out vol
//#define K_OVERMOD2			(   1.0f )		// 1 -> no overmod, 1.1547=2/sqrt(3) -> full hex sat, <1 to limit out vol
#define K_OVERMOD2			(   1.155f )		// 1 -> no overmod, 1.1547=2/sqrt(3) -> full hex sat, <1 to limit out vol
//#define K_OVERMOD3			(   1.0f )		// 1 -> no overmod, 1.1547=2/sqrt(3) -> full hex sat, <1 to limit out vol
#define K_OVERMOD3			(   1.155f )		// 1 -> no overmod, 1.1547=2/sqrt(3) -> full hex sat, <1 to limit out vol

// other control parameters
#define K_MARGV_DQ			(   0.9f )	// max_d_volt/max_volt ratio

// speed PI error clamping
#define SPEEDPI_ERRCLAMP				// input to speed PI is clamped to MAXERR_RPM
#define MAXERR1_RPM			( 300.0f )	// maximum error for ramp limitation and PI clamping
#define MAXERR2_RPM			( 300.0f )	// maximum error for ramp limitation and PI clamping
#define MAXERR3_RPM			( 300.0f )	// maximum error for ramp limitation and PI clamping

// DC bus voltage limit for ramp limitation
//#define VB_RAMP						// comment this to avoid ramp limitation due to vbus
#define K_RAMPLIM			(   0.9f )	// ramp limitation gain
#define HVBUS_LIMH1			((float32_t)(1.25 * VB_NOM_VOL1))	// high level DC bus voltage limit [V]
#define HVBUS_LIML1			((float32_t)(1.10 * VB_NOM_VOL1))	// high level DC bus voltage limit reset [V]
#define HVBUS_LIMH2			((float32_t)(1.25 * VB_NOM_VOL2))	// high level DC bus voltage limit [V]
#define HVBUS_LIML2			((float32_t)(1.10 * VB_NOM_VOL2))	// high level DC bus voltage limit reset [V]
#define HVBUS_LIMH3			((float32_t)(1.25 * VB_NOM_VOL3))	// high level DC bus voltage limit [V]
#define HVBUS_LIML3			((float32_t)(1.10 * VB_NOM_VOL3))	// high level DC bus voltage limit reset [V]

// flux weakening
//#define FLUXWEAK						// comment to avoid flux weakening
#define K_MARGV_FW			(   0.85f )	// percent of available voltage at which FW begins
#define K_MARGI_FW			(   0.8f )	// max_d_cur/max_cur ratio
#define DCUR_DT				(   2.0f )	// d current variation rate [A/s] during FW

// trip control
#define TRIP_CONTROL1					// comment to avoid trip control
#define TRIP_CONTROL2					// comment to avoid trip control
#define TRIP_CONTROL3					// comment to avoid trip control
#define T_MARGL				(   0.5f )	// minimum speed trip (ratio of expected speed or of minimum speed)
#define T_MARGH				(   1.3f )	// maximum speed trip (ratio of expected speed or of maximum speed)
#define R_MARG				( 100.0f )	// further speed margin [rad/sec]
#define MAX_TRIP			( 200 )		// trip counter threshold

// speed low-pass filter cut-off frequency f0 (time constant will be tau=(1/w0)=(1/(2PIf0)))
#define	SPEED_LP_CUTOFF_HZ	( 100.0f )	// cut-off frequency [Hz]

#endif	// ifndef _CUSTOMIZE_H

// EOF customize.h
