
/*******************************************************************************
DISCLAIMER

THIS SOFTWARE IS PROVIDED "AS IS" AND BFG ENGINEERING MAKES NO WARRANTIES
REGARDING THIS SOFTWARE, WHETHER EXPRESS, IMPLIED OR STATUTORY, INCLUDING
BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
PURPOSE AND NON-INFRINGEMENT. ALL SUCH WARRANTIES ARE EXPRESSLY DISCLAIMED.

WE (BFG ENGINEERING) DO NOT WARRANT THAT THIS SOFTWARE IS FREE FROM CLAIMS
BY A THIRD PARTY OF COPYRIGHT, PATENT, TRADEMARK, TRADE SECRET OR ANY OTHER
INTELLECTUAL PROPERTY INFRINGIMENT.

TO THE MAXIMUM EXTENT PERMITTED NOT PROHIBITED BY LAW, BFG ENGINEERING
SHALL NOT BE LIABLE FOR ANY DIRECT, INDIRECT, SPECIAL, INCIDENTAL OR
CONSEQUENTIAL DAMAGES FOR ANY REASON RELATED TO THIS SOFTWARE, EVEN IF BFG
ENGINEERING HAS BEEN ADVISED OF THE POSSIBILITY OF SUCH DAMAGES.
PARTICULARLY, UNDER NO CIRCUMSTANCES ARE WE LIABLE FOR ANY OF THE FOLLOWING:
- THIRD PARTY CLAIMS AGAINST YOU FOR LOSSES OR DAMAGES;
- LOSS OF, OR DAMAGE TO YOUR RECORDS OR DATA; OR
- ECONOMIC CONSEQUENTIAL DAMAGES (INCLUDING LOST PROFITS OR SAVINGS) OR
  INCIDENTAL DAMAGES, EVEN IF WE ARE INFORMED OF THEIR POSSIBILITY.

BFG ENGINEERING DOES NOT WARRANT UNINTERRUPTED OR ERROR_FREE OPERATION OF
THIS SOFTWARE.
BFG ENGINEERING HAS NO OBLIGATION TO PROVIDE SERVICE, DEFECT CORRECTION OR
ANY MANTEINANCE OF THIS SOFTWARE; OR TO SUPPLY ANY UPDATES OR ENHANCEMENTS
EVEN IF SUCH ARE, OR LATER BECOME, AVAILABLE.

IF YOU DOWNLOAD OR USE THIS SOFTWARE YOU AGREE TO THESE TERMS, AND DO IT AT
YOUR OWN RISK.
*******************************************************************************/

/*******************************************************************************
File:		ges_eqp.h
Project:	YRotateItRX66T
Revision:	1.0
Date:		2019-04-04 (YYYY-MM-DD)
Author:		Andrea Ghirardello
Contents:	Eeprom management functions
*******************************************************************************/
#ifndef	_GES_EQP_H
#define _GES_EQP_H

#include "globdef.h"

typedef union
{
	float32_t	f32;
	uint32_t	u32;
}	param_t;

// IMPORTANT NOTE: depending on the parameters type and of the ram_tab elements type (16 or 32 bits),
// to comply with the protocol requirements, the following relations MUST be verified:
// if type is 32bit then: NUM_PAR<MAX_NLD, N_RAM_READ<MAX_NLD, N_RAM_WRITE<MAX_NLD
// if type is 16bit then: NUM_PAR<MAX_NWD, N_RAM_READ<MAX_NWD, N_RAM_WRITE<MAX_NWD
// in every case: MAX_SAM_CNT<MAX_NWD

#define NUM_PAR 		( 60 )		// parameters number

#define RIP_DEF 		( 33 )		// default parameters setting password
#define SEL_MO1			(  0 )		// motor 1 selected
#define SEL_MO2			(  1 )		// motor 2 selected
#define SEL_MO3			(  2 )		// motor 3 selected
#define SEL_MOA			(  3 )		// all motors selected (speed reference)

#define MOT1_SEL		(SEL_MO1 == SEL_OP)
#define MOT2_SEL		(SEL_MO2 == SEL_OP)
#define MOT3_SEL		(SEL_MO3 == SEL_OP)
#define MOTA_SEL		(SEL_MOA == SEL_OP)

#define IND_EQP_R_STA1	(  8 )
#define IND_EQP_L_SQ1	(  9 )
#define IND_EQP_PM_FLX1	( 10 )
#define IND_EQP_KP_CUR1	( 11 )
#define IND_EQP_KI_CUR1	( 12 )
#define IND_EQP_R_STA2	( 28 )
#define IND_EQP_L_SQ2	( 29 )
#define IND_EQP_PM_FLX2	( 30 )
#define IND_EQP_KP_CUR2	( 31 )
#define IND_EQP_KI_CUR2	( 32 )
#define IND_EQP_R_STA3	( 46 )
#define IND_EQP_L_SQ3	( 47 )
#define IND_EQP_PM_FLX3	( 48 )
#define IND_EQP_KP_CUR3	( 49 )
#define IND_EQP_KI_CUR3	( 50 )


#define SEL_OP		(p_vec[ 0]).u32	// 00 operation select
#define RPM_MIN1	(p_vec[ 1]).f32	// 01 minimum speed				rpm
#define RPM_MAX1	(p_vec[ 2]).f32	// 02 maximum speed				rpm
#define R_ACC1		(p_vec[ 3]).f32	// 03 acceleration				rpm/sec
#define R_DEC1		(p_vec[ 4]).f32	// 04 deceleration				rpm/sec
#define C_POLI1		(p_vec[ 5]).f32	// 05 polar couples
#define I_START1	(p_vec[ 6]).f32	// 06 startup current			Ampere
#define I_MAX1		(p_vec[ 7]).f32	// 07 maximum current			Ampere
#define R_STA1		(p_vec[ 8]).f32	// 08 stator resistance			Ohm
#define L_SQ1		(p_vec[ 9]).f32	// 09 q synchronous inductance	Henry
#define PM_FLX1		(p_vec[10]).f32	// 10 permanent magnets flux	Weber
#define KP_CUR1		(p_vec[11]).f32	// 11 current loop KP			Ohm
#define KI_CUR1		(p_vec[12]).f32	// 12 current loop KI (analog)	Ohm/sec
#define KP_VEL1		(p_vec[13]).f32	// 13 speed loop KP				Ampere*sec/rad
#define	KI_VEL1		(p_vec[14]).f32	// 14 speed loop KI				Ampere/rad
#define	FB_GAIN1	(p_vec[15]).f32	// 15 flux amp. feedback gain
#define PHA_OFF1	(p_vec[16]).f32	// 16 phase offset				deg
#define	SUP_TIM1	(p_vec[17]).f32	// 17 startup acc. time			sec
#define SAM_FRE		(p_vec[18]).f32	// 18 sampling frequency		Hz
#define F_RATIO		(p_vec[19]).f32	// 19 pwm_freq/sam_freq ratio
#define PAR_20		(p_vec[20]).f32	// 20
#define RPM_MIN2	(p_vec[21]).f32	// 21 minimum speed				rpm
#define RPM_MAX2	(p_vec[22]).f32	// 22 maximum speed				rpm
#define R_ACC2		(p_vec[23]).f32	// 23 acceleration				rpm/sec
#define R_DEC2		(p_vec[24]).f32	// 24 deceleration				rpm/sec
#define C_POLI2		(p_vec[25]).f32	// 25 polar couples
#define I_START2	(p_vec[26]).f32	// 26 startup current			Ampere
#define I_MAX2		(p_vec[27]).f32	// 27 maximum current			Ampere
#define R_STA2		(p_vec[28]).f32	// 28 stator resistance			Ohm
#define L_SQ2		(p_vec[29]).f32	// 29 q synchronous inductance	Henry
#define PM_FLX2		(p_vec[30]).f32	// 30 permanent magnets flux	Weber
#define KP_CUR2		(p_vec[31]).f32	// 31 current loop KP			Ohm
#define KI_CUR2		(p_vec[32]).f32	// 32 current loop KI (analog)	Ohm/sec
#define KP_VEL2		(p_vec[33]).f32	// 33 speed loop KP				Ampere*sec/rad
#define	KI_VEL2		(p_vec[34]).f32	// 34 speed loop KI				Ampere/rad
#define	FB_GAIN2	(p_vec[35]).f32	// 35 flux amp. feedback gain
#define PHA_OFF2	(p_vec[36]).f32	// 36 phase offset				deg
#define	SUP_TIM2	(p_vec[37]).f32	// 37 startup acc. time			sec
#define PAR_38		(p_vec[38]).f32	// 38
#define RPM_MIN3	(p_vec[39]).f32	// 39 minimum speed				rpm
#define RPM_MAX3	(p_vec[40]).f32	// 40 maximum speed				rpm
#define R_ACC3		(p_vec[41]).f32	// 41 acceleration				rpm/sec
#define R_DEC3		(p_vec[42]).f32	// 42 deceleration				rpm/sec
#define C_POLI3		(p_vec[43]).f32	// 43 polar couples
#define I_START3	(p_vec[44]).f32	// 44 startup current			Ampere
#define I_MAX3		(p_vec[45]).f32	// 45 maximum current			Ampere
#define R_STA3		(p_vec[46]).f32	// 46 stator resistance			Ohm
#define L_SQ3		(p_vec[47]).f32	// 47 q synchronous inductance	Henry
#define PM_FLX3		(p_vec[48]).f32	// 48 permanent magnets flux	Weber
#define KP_CUR3		(p_vec[49]).f32	// 49 current loop KP			Ohm
#define KI_CUR3		(p_vec[50]).f32	// 50 current loop KI (analog)	Ohm/sec
#define KP_VEL3		(p_vec[51]).f32	// 51 speed loop KP				Ampere*sec/rad
#define	KI_VEL3		(p_vec[52]).f32	// 52 speed loop KI				Ampere/rad
#define	FB_GAIN3	(p_vec[53]).f32	// 53 flux amp. feedback gain
#define PHA_OFF3	(p_vec[54]).f32	// 54 phase offset				deg
#define	SUP_TIM3	(p_vec[55]).f32	// 55 startup acc. time			sec
#define PAR_56		(p_vec[56]).f32	// 56
#define PAR_57		(p_vec[57]).f32	// 57
#define PAR_58		(p_vec[58]).f32	// 58
#define PAR_59		(p_vec[59]).f32	// 59

#ifdef _GES_EQP_C

const param_t
	p_min[NUM_PAR] =				// MINIMUM VALUES VECTOR
	{
		{.u32 = 0UL},				// 00 SEL_OP	operation select (minimum, default and maximum values not considered)
		RPM_MIN1_MIN,				// 01 RPM_MIN	minimum speed				rpm
		RPM_MAX1_MIN,				// 02 RPM_MAX	maximum speed				rpm
		R_ACC1_MIN,					// 03 R_ACC		acceleration				rpm/sec
		R_DEC1_MIN,					// 04 R_DEC		deceleration				rpm/sec
		C_POLI1_MIN,				// 05 C_POLI	polar couples
		I_START1_MIN,				// 06 I_START	startup current				Ampere
		I_MAX1_MIN,					// 07 I_MAX		maximum current				Ampere
		R_STA1_MIN,					// 08 R_STA		stator resistance			Ohm
		L_SQ1_MIN,					// 09 L_SQ		q synchronous inductance	Henry
		PM_FLX1_MIN,				// 10 PM_FLX	permanent magnets flux		Weber
		KP_CUR1_MIN,				// 11 KP_CUR	current loop KP				Ohm
		KI_CUR1_MIN,				// 12 KI_CUR	current loop KI (analog)	Ohm/sec
		KP_VEL1_MIN,				// 13 KP_VEL	speed loop KP				Ampere*sec/rad
		KI_VEL1_MIN,				// 14 KI_VEL	speed loop KI				Ampere/rad
		FB_GAIN1_MIN,				// 15 FB_GAIN	flux amp. feedback gain
		PHA_OFF1_MIN,				// 16 PHA_OFF	phase offset				deg
		SUP_TIM1_MIN,				// 17 SUP_TIM	startup acc. time			sec
		SAM_FRE_MIN,				// 18 SAM_FRE	sampling frequency			Hz
		F_RATIO_MIN,				// 19 F_RATIO	pwm_freq/sam_freq ratio
		PAR_20_MIN,					// 20 PAR_20
		RPM_MIN2_MIN,				// 21 RPM_MIN	minimum speed				rpm
		RPM_MAX2_MIN,				// 22 RPM_MAX	maximum speed				rpm
		R_ACC2_MIN,					// 23 R_ACC		acceleration				rpm/sec
		R_DEC2_MIN,					// 24 R_DEC		deceleration				rpm/sec
		C_POLI2_MIN,				// 25 C_POLI	polar couples
		I_START2_MIN,				// 26 I_START	startup current				Ampere
		I_MAX2_MIN,					// 27 I_MAX		maximum current				Ampere
		R_STA2_MIN,					// 28 R_STA		stator resistance			Ohm
		L_SQ2_MIN,					// 29 L_SQ		q synchronous inductance	Henry
		PM_FLX2_MIN,				// 30 PM_FLX	permanent magnets flux		Weber
		KP_CUR2_MIN,				// 31 KP_CUR	current loop KP				Ohm
		KI_CUR2_MIN,				// 32 KI_CUR	current loop KI (analog)	Ohm/sec
		KP_VEL2_MIN,				// 33 KP_VEL	speed loop KP				Ampere*sec/rad
		KI_VEL2_MIN,				// 34 KI_VEL	speed loop KI				Ampere/rad
		FB_GAIN2_MIN,				// 35 FB_GAIN	flux amp. feedback gain
		PHA_OFF2_MIN,				// 36 PHA_OFF	phase offset				deg
		SUP_TIM2_MIN,				// 37 SUP_TIM	startup acc. time			sec
		PAR_38_MIN,					// 38 PAR_38
		RPM_MIN3_MIN,				// 39 RPM_MIN	minimum speed				rpm
		RPM_MAX3_MIN,				// 40 RPM_MAX	maximum speed				rpm
		R_ACC3_MIN,					// 41 R_ACC		acceleration				rpm/sec
		R_DEC3_MIN,					// 42 R_DEC		deceleration				rpm/sec
		C_POLI3_MIN,				// 43 C_POLI	polar couples
		I_START3_MIN,				// 44 I_START	startup current				Ampere
		I_MAX3_MIN,					// 45 I_MAX		maximum current				Ampere
		R_STA3_MIN,					// 46 R_STA		stator resistance			Ohm
		L_SQ3_MIN,					// 47 L_SQ		q synchronous inductance	Henry
		PM_FLX3_MIN,				// 48 PM_FLX	permanent magnets flux		Weber
		KP_CUR3_MIN,				// 49 KP_CUR	current loop KP				Ohm
		KI_CUR3_MIN,				// 50 KI_CUR	current loop KI (analog)	Ohm/sec
		KP_VEL3_MIN,				// 51 KP_VEL	speed loop KP				Ampere*sec/rad
		KI_VEL3_MIN,				// 52 KI_VEL	speed loop KI				Ampere/rad
		FB_GAIN3_MIN,				// 53 FB_GAIN	flux amp. feedback gain
		PHA_OFF3_MIN,				// 54 PHA_OFF	phase offset				deg
		SUP_TIM3_MIN,				// 55 SUP_TIM	startup acc. time			sec
		PAR_56_MIN,					// 56 PAR_56
		PAR_57_MIN,					// 57 PAR_57	
		PAR_58_MIN,					// 58 PAR_58	
		PAR_59_MIN					// 59 PAR_59
	},
	p_def[NUM_PAR] =				// DEFAULT VALUES VECTOR
	{
		{.u32 = 0UL},				// 00 SEL_OP	operation select (minimum, default and maximum values not considered)
		RPM_MIN1_DEF,				// 01 RPM_MIN	minimum speed				rpm
		RPM_MAX1_DEF,				// 02 RPM_MAX	maximum speed				rpm
		R_ACC1_DEF,					// 03 R_ACC		acceleration				rpm/sec
		R_DEC1_DEF,					// 04 R_DEC		deceleration				rpm/sec
		C_POLI1_DEF,				// 05 C_POLI	polar couples
		I_START1_DEF,				// 06 I_START	startup current				Ampere
		I_MAX1_DEF,					// 07 I_MAX		maximum current				Ampere
		R_STA1_DEF,					// 08 R_STA		stator resistance			Ohm
		L_SQ1_DEF,					// 09 L_SQ		q synchronous inductance	Henry
		PM_FLX1_DEF,				// 10 PM_FLX	permanent magnets flux		Weber
		KP_CUR1_DEF,				// 11 KP_CUR	current loop KP				Ohm
		KI_CUR1_DEF,				// 12 KI_CUR	current loop KI (analog)	Ohm/sec
		KP_VEL1_DEF,				// 13 KP_VEL	speed loop KP				Ampere*sec/rad
		KI_VEL1_DEF,				// 14 KI_VEL	speed loop KI				Ampere/rad
		FB_GAIN1_DEF,				// 15 FB_GAIN	flux amp. feedback gain
		PHA_OFF1_DEF,				// 16 PHA_OFF	phase offset				deg
		SUP_TIM1_DEF,				// 17 SUP_TIM	startup acc. time			sec
		SAM_FRE_DEF,				// 18 SAM_FRE	sampling frequency			Hz
		F_RATIO_DEF,				// 19 F_RATIO	pwm_freq/sam_freq ratio
		PAR_20_DEF,					// 20 PAR_20
		RPM_MIN2_DEF,				// 21 RPM_MIN	minimum speed				rpm
		RPM_MAX2_DEF,				// 22 RPM_MAX	maximum speed				rpm
		R_ACC2_DEF,					// 23 R_ACC		acceleration				rpm/sec
		R_DEC2_DEF,					// 24 R_DEC		deceleration				rpm/sec
		C_POLI2_DEF,				// 25 C_POLI	polar couples
		I_START2_DEF,				// 26 I_START	startup current				Ampere
		I_MAX2_DEF,					// 27 I_MAX		maximum current				Ampere
		R_STA2_DEF,					// 28 R_STA		stator resistance			Ohm
		L_SQ2_DEF,					// 29 L_SQ		q synchronous inductance	Henry
		PM_FLX2_DEF,				// 30 PM_FLX	permanent magnets flux		Weber
		KP_CUR2_DEF,				// 31 KP_CUR	current loop KP				Ohm
		KI_CUR2_DEF,				// 32 KI_CUR	current loop KI (analog)	Ohm/sec
		KP_VEL2_DEF,				// 33 KP_VEL	speed loop KP				Ampere*sec/rad
		KI_VEL2_DEF,				// 34 KI_VEL	speed loop KI				Ampere/rad
		FB_GAIN2_DEF,				// 35 FB_GAIN	flux amp. feedback gain
		PHA_OFF2_DEF,				// 36 PHA_OFF	phase offset				deg
		SUP_TIM2_DEF,				// 37 SUP_TIM	startup acc. time			sec
		PAR_38_DEF,					// 38 PAR_38
		RPM_MIN3_DEF,				// 39 RPM_MIN	minimum speed				rpm
		RPM_MAX3_DEF,				// 40 RPM_MAX	maximum speed				rpm
		R_ACC3_DEF,					// 41 R_ACC		acceleration				rpm/sec
		R_DEC3_DEF,					// 42 R_DEC		deceleration				rpm/sec
		C_POLI3_DEF,				// 43 C_POLI	polar couples
		I_START3_DEF,				// 44 I_START	startup current				Ampere
		I_MAX3_DEF,					// 45 I_MAX		maximum current				Ampere
		R_STA3_DEF,					// 46 R_STA		stator resistance			Ohm
		L_SQ3_DEF,					// 47 L_SQ		q synchronous inductance	Henry
		PM_FLX3_DEF,				// 48 PM_FLX	permanent magnets flux		Weber
		KP_CUR3_DEF,				// 49 KP_CUR	current loop KP				Ohm
		KI_CUR3_DEF,				// 50 KI_CUR	current loop KI (analog)	Ohm/sec
		KP_VEL3_DEF,				// 51 KP_VEL	speed loop KP				Ampere*sec/rad
		KI_VEL3_DEF,				// 52 KI_VEL	speed loop KI				Ampere/rad
		FB_GAIN3_DEF,				// 53 FB_GAIN	flux amp. feedback gain
		PHA_OFF3_DEF,				// 54 PHA_OFF	phase offset				deg
		SUP_TIM3_DEF,				// 55 SUP_TIM	startup acc. time			sec
		PAR_56_DEF,					// 56 PAR_56
		PAR_57_DEF,					// 57 PAR_57	
		PAR_58_DEF,					// 58 PAR_58	
		PAR_59_DEF					// 59 PAR_59
	},
	p_max[NUM_PAR] =				// MAXIMUM VALUES VECTOR
	{
		{.u32 = 0xFFFFFFFF},		// 00 SEL_OP	operation select (minimum, default and maximum values not considered)
		RPM_MIN1_MAX,				// 01 RPM_MIN	minimum speed				rpm
		RPM_MAX1_MAX,				// 02 RPM_MAX	maximum speed				rpm
		R_ACC1_MAX,					// 03 R_ACC		acceleration				rpm/sec
		R_DEC1_MAX,					// 04 R_DEC		deceleration				rpm/sec
		C_POLI1_MAX,				// 05 C_POLI	polar couples
		I_START1_MAX,				// 06 I_START	startup current				Ampere
		I_MAX1_MAX,					// 07 I_MAX		maximum current				Ampere
		R_STA1_MAX,					// 08 R_STA		stator resistance			Ohm
		L_SQ1_MAX,					// 09 L_SQ		q synchronous inductance	Henry
		PM_FLX1_MAX,				// 10 PM_FLX	permanent magnets flux		Weber
		KP_CUR1_MAX,				// 11 KP_CUR	current loop KP				Ohm
		KI_CUR1_MAX,				// 12 KI_CUR	current loop KI (analog)	Ohm/sec
		KP_VEL1_MAX,				// 13 KP_VEL	speed loop KP				Ampere*sec/rad
		KI_VEL1_MAX,				// 14 KI_VEL	speed loop KI				Ampere/rad
		FB_GAIN1_MAX,				// 15 FB_GAIN	flux amp. feedback gain
		PHA_OFF1_MAX,				// 16 PHA_OFF	phase offset				deg
		SUP_TIM1_MAX,				// 17 SUP_TIM	startup acc. time			sec
		SAM_FRE_MAX,				// 18 SAM_FRE	sampling frequency			Hz
		F_RATIO_MAX,				// 19 F_RATIO	pwm_freq/sam_freq ratio
		PAR_20_MAX,					// 20 PAR_20
		RPM_MIN2_MAX,				// 21 RPM_MIN	minimum speed				rpm
		RPM_MAX2_MAX,				// 22 RPM_MAX	maximum speed				rpm
		R_ACC2_MAX,					// 23 R_ACC		acceleration				rpm/sec
		R_DEC2_MAX,					// 24 R_DEC		deceleration				rpm/sec
		C_POLI2_MAX,				// 25 C_POLI	polar couples
		I_START2_MAX,				// 26 I_START	startup current				Ampere
		I_MAX2_MAX,					// 27 I_MAX		maximum current				Ampere
		R_STA2_MAX,					// 28 R_STA		stator resistance			Ohm
		L_SQ2_MAX,					// 29 L_SQ		q synchronous inductance	Henry
		PM_FLX2_MAX,				// 30 PM_FLX	permanent magnets flux		Weber
		KP_CUR2_MAX,				// 31 KP_CUR	current loop KP				Ohm
		KI_CUR2_MAX,				// 32 KI_CUR	current loop KI (analog)	Ohm/sec
		KP_VEL2_MAX,				// 33 KP_VEL	speed loop KP				Ampere*sec/rad
		KI_VEL2_MAX,				// 34 KI_VEL	speed loop KI				Ampere/rad
		FB_GAIN2_MAX,				// 35 FB_GAIN	flux amp. feedback gain
		PHA_OFF2_MAX,				// 36 PHA_OFF	phase offset				deg
		SUP_TIM2_MAX,				// 37 SUP_TIM	startup acc. time			sec
		PAR_38_MAX,					// 38 PAR_38
		RPM_MIN3_MAX,				// 39 RPM_MIN	minimum speed				rpm
		RPM_MAX3_MAX,				// 40 RPM_MAX	maximum speed				rpm
		R_ACC3_MAX,					// 41 R_ACC		acceleration				rpm/sec
		R_DEC3_MAX,					// 42 R_DEC		deceleration				rpm/sec
		C_POLI3_MAX,				// 43 C_POLI	polar couples
		I_START3_MAX,				// 44 I_START	startup current				Ampere
		I_MAX3_MAX,					// 45 I_MAX		maximum current				Ampere
		R_STA3_MAX,					// 46 R_STA		stator resistance			Ohm
		L_SQ3_MAX,					// 47 L_SQ		q synchronous inductance	Henry
		PM_FLX3_MAX,				// 48 PM_FLX	permanent magnets flux		Weber
		KP_CUR3_MAX,				// 49 KP_CUR	current loop KP				Ohm
		KI_CUR3_MAX,				// 50 KI_CUR	current loop KI (analog)	Ohm/sec
		KP_VEL3_MAX,				// 51 KP_VEL	speed loop KP				Ampere*sec/rad
		KI_VEL3_MAX,				// 52 KI_VEL	speed loop KI				Ampere/rad
		FB_GAIN3_MAX,				// 53 FB_GAIN	flux amp. feedback gain
		PHA_OFF3_MAX,				// 54 PHA_OFF	phase offset				deg
		SUP_TIM3_MAX,				// 55 SUP_TIM	startup acc. time			sec
		PAR_56_MAX,					// 56 PAR_56
		PAR_57_MAX,					// 57 PAR_57	
		PAR_58_MAX,					// 58 PAR_58	
		PAR_59_MAX					// 59 PAR_59	
	};
param_t
	p_vec[NUM_PAR];					// parameters vector

#else	// _GES_EQP_C

extern const param_t
	p_min[NUM_PAR],
	p_max[NUM_PAR],
	p_def[NUM_PAR];
extern param_t
	p_vec[NUM_PAR];

#endif	// _GES_EQP_C

/*******************************************************************************
Function:		GE_IniEqp
Description:	hardware init if needed
Input:			nothing
Output:			nothing
*******************************************************************************/
void GE_IniEqp(void);

/******************************************************************************
Function:		GE_DefToRam
Description:	copies default parameters into ram
Input:			nothing
Output:			=0 -> OK, !=0 -> NOK
Modifies:		internal parameters vector
******************************************************************************/
uint16_t GE_DefToRam(void);

/******************************************************************************
Function:		GE_RamToEqp
Description:	copies all the parameters from ram to eeprom
Input:			nothing
Output:			=0 -> OK, !=0 -> NOK
Modifies:		eeprom content
Note:			to be used out of main loop, due to the high delay
******************************************************************************/
uint16_t GE_RamToEqp(void);

/******************************************************************************
Function:		GE_EqpToRam
Description:	if par0!=RIP_DEF copies all parameters from eeprom to
				ram, else copies all default values in ram parameter
				table, then copies all the parameters from ram to eeprom
Input:			nothing
Output:			=0 -> OK, !=0 -> NOK
Modifies:		internal parameters vector or eeprom content
Note:			to be used out of main loop, due to the high delay
******************************************************************************/
uint16_t GE_EqpToRam(void);

/******************************************************************************
Function:		GE_SetPar
Description:	insertion of a parameter in eqp fifo, to be updated
Input:			parameter value, parameter address in the vector
Output:			nothing
Modifies:		internal fifo
******************************************************************************/
void GE_SetPar(uint32_t val, uint16_t add);

/******************************************************************************
Function:		GE_EqpMan
Description:	eeprom parameters modification management
Input:			parameter value, parameter address in the vector
Output:			=0 -> OK, !=0 -> NOK
Modifies:		internal fifo, eeprom content
Note:			to be called in main loop
******************************************************************************/
uint16_t GE_EqpMan(void);

#endif	// ifndef _GES_EQP_H

// EOF ges_eqp.h
