
/*******************************************************************************
DISCLAIMER

THIS SOFTWARE IS PROVIDED "AS IS" AND BFG ENGINEERING MAKES NO WARRANTIES
REGARDING THIS SOFTWARE, WHETHER EXPRESS, IMPLIED OR STATUTORY, INCLUDING
BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
PURPOSE AND NON-INFRINGEMENT. ALL SUCH WARRANTIES ARE EXPRESSLY DISCLAIMED.

WE (BFG ENGINEERING) DO NOT WARRANT THAT THIS SOFTWARE IS FREE FROM CLAIMS
BY A THIRD PARTY OF COPYRIGHT, PATENT, TRADEMARK, TRADE SECRET OR ANY OTHER
INTELLECTUAL PROPERTY INFRINGIMENT.

TO THE MAXIMUM EXTENT PERMITTED NOT PROHIBITED BY LAW, BFG ENGINEERING
SHALL NOT BE LIABLE FOR ANY DIRECT, INDIRECT, SPECIAL, INCIDENTAL OR
CONSEQUENTIAL DAMAGES FOR ANY REASON RELATED TO THIS SOFTWARE, EVEN IF BFG
ENGINEERING HAS BEEN ADVISED OF THE POSSIBILITY OF SUCH DAMAGES.
PARTICULARLY, UNDER NO CIRCUMSTANCES ARE WE LIABLE FOR ANY OF THE FOLLOWING:
- THIRD PARTY CLAIMS AGAINST YOU FOR LOSSES OR DAMAGES;
- LOSS OF, OR DAMAGE TO YOUR RECORDS OR DATA; OR
- ECONOMIC CONSEQUENTIAL DAMAGES (INCLUDING LOST PROFITS OR SAVINGS) OR
  INCIDENTAL DAMAGES, EVEN IF WE ARE INFORMED OF THEIR POSSIBILITY.

BFG ENGINEERING DOES NOT WARRANT UNINTERRUPTED OR ERROR_FREE OPERATION OF
THIS SOFTWARE.
BFG ENGINEERING HAS NO OBLIGATION TO PROVIDE SERVICE, DEFECT CORRECTION OR
ANY MANTEINANCE OF THIS SOFTWARE; OR TO SUPPLY ANY UPDATES OR ENHANCEMENTS
EVEN IF SUCH ARE, OR LATER BECOME, AVAILABLE.

IF YOU DOWNLOAD OR USE THIS SOFTWARE YOU AGREE TO THESE TERMS, AND DO IT AT
YOUR OWN RISK.
*******************************************************************************/

/*******************************************************************************
File:		globdef.h
Project:	YRotateItRX66T
Revision:	1.0
Date:		2019-04-04 (YYYY-MM-DD)
Author:		Andrea Ghirardello
Contents:	Global definitions
*******************************************************************************/
#ifndef	_GLOBDEF_H
#define	_GLOBDEF_H

// inclusions
#include <machine.h>
#include <stdlib.h>
#include <mathf.h>
#include "iodefine.h"
#include "typedefine.h"
#include "globvar.h"
#include "mask.h"
#include "const_def.h"

// NULL/NOP
#ifndef NULL
	#define NULL		((void *)( 0 ))
#endif                        
#ifndef NOP
	#define NOP			{ nop(); }
#endif                        

// Delay
#define US1				(    9 )
#define US10			(   90 )
#define US100			(  900 )
#define US1000			( 9000 )
#define DELAY(X, Y)		{	volatile uint16_t x, y;				\
							for(x = ( X ); x > 0; x--) {		\
								for(y = ( Y ); y > 0; y--) {	\
									NOP					}	}	}
#define DELAY1US(X)		DELAY(X, US1)
#define DELAY10US(X)	DELAY(X, US10)
#define DELAY100US(X)	DELAY(X, US100)
#define DELAY1MS(X)		DELAY(X, US1000)

// 16bit mul_w(), mulu_w(), div_w(), divu_w() define
#ifndef _MYMULDIV
#define _MYMULDIV
#define	mul_w(X, Y)		(( int32_t)((( int16_t)( X )) * (( int16_t)( Y ))))
#define	mulu_w(X, Y)	((uint32_t)(((uint16_t)( X )) * ((uint16_t)( Y ))))
#define	div_w(X, Y)		(( int16_t)((( int32_t)( X )) / (( int16_t)( Y ))))
#define	divu_w(X, Y)	((uint16_t)(((uint32_t)( X )) / ((uint16_t)( Y ))))
#endif	// _MYMULDIV

// macro for Module Stop Control
#define	WAKEUP_GPT		{ SYSTEM.PRCR.WORD = 0xA502; SYSTEM.MSTPCRA.BIT.MSTPA7 = 0;  SYSTEM.PRCR.WORD = 0xA500; }
#define	WAKEUP_MTU		{ SYSTEM.PRCR.WORD = 0xA502; SYSTEM.MSTPCRA.BIT.MSTPA9 = 0;  SYSTEM.PRCR.WORD = 0xA500; }
#define	WAKEUP_CMT0		{ SYSTEM.PRCR.WORD = 0xA502; SYSTEM.MSTPCRA.BIT.MSTPA15= 0;  SYSTEM.PRCR.WORD = 0xA500; }
#define	WAKEUP_S12AD	{ SYSTEM.PRCR.WORD = 0xA502; SYSTEM.MSTPCRA.BIT.MSTPA17 = 0; SYSTEM.PRCR.WORD = 0xA500; }
#define	WAKEUP_S12AD1	{ SYSTEM.PRCR.WORD = 0xA502; SYSTEM.MSTPCRA.BIT.MSTPA16 = 0; SYSTEM.PRCR.WORD = 0xA500; }
#define	WAKEUP_S12AD2	{ SYSTEM.PRCR.WORD = 0xA502; SYSTEM.MSTPCRA.BIT.MSTPA23 = 0; SYSTEM.PRCR.WORD = 0xA500; }
#define WAKEUP_DA		{ SYSTEM.PRCR.WORD = 0xA502; SYSTEM.MSTPCRA.BIT.MSTPA19 = 0; SYSTEM.PRCR.WORD = 0xA500; }
#define WAKEUP_DTC		{ SYSTEM.PRCR.WORD = 0xA502; SYSTEM.MSTPCRA.BIT.MSTPA28 = 0; SYSTEM.PRCR.WORD = 0xA500; }
#define WAKEUP_ELC		{ SYSTEM.PRCR.WORD = 0xA502; SYSTEM.MSTPCRB.BIT.MSTPB9 = 0; SYSTEM.PRCR.WORD = 0xA500; }
#define WAKEUP_SCI1		{ SYSTEM.PRCR.WORD = 0xA502; SYSTEM.MSTPCRB.BIT.MSTPB30 = 0; SYSTEM.PRCR.WORD = 0xA500; }
#define WAKEUP_SCI6		{ SYSTEM.PRCR.WORD = 0xA502; SYSTEM.MSTPCRB.BIT.MSTPB25 = 0; SYSTEM.PRCR.WORD = 0xA500; }
#define WAKEUP_SCI9		{ SYSTEM.PRCR.WORD = 0xA502; SYSTEM.MSTPCRC.BIT.MSTPC26 = 0; SYSTEM.PRCR.WORD = 0xA500; }
#define WAKEUP_SCI11	{ SYSTEM.PRCR.WORD = 0xA502; SYSTEM.MSTPCRC.BIT.MSTPC24 = 0; SYSTEM.PRCR.WORD = 0xA500; }

// macro for A/D conversions: S12AD
#define	S12AD_START		{ S12AD.ADCSR.BIT.ADST = 1; }	// B15
#define	S12AD_STOP		{ S12AD.ADCSR.BIT.ADST = 0; }	// B15
#define	S12AD_C_ON		(0 != S12AD.ADCSR.BIT.ADST)		// B15
#define	WAIT_S12AD		{ while(S12AD_C_ON); }
#define AN00_IU1		((uint16_t) S12AD.ADDR0)		// P40 p090 IU1 AN000
#define AN01_IV1		((uint16_t) S12AD.ADDR1)		// P41 p089 IV1 AN001
#define AN02_IW1		((uint16_t) S12AD.ADDR2)		// P42 p088 IW1 AN002
#define AN03_VB1		((uint16_t) S12AD.ADDR3)		// P43 p087 VB1 AN003
//#define AN07_TE1		((uint16_t) S12AD.ADDR7)		// PH0 p091 TE1 AN007

// macro for A/D conversions: S12AD1
#define	S12AD1_START	{ S12AD1.ADCSR.BIT.ADST = 1; }	// B15
#define	S12AD1_STOP		{ S12AD1.ADCSR.BIT.ADST = 0; }	// B15
#define	S12AD1_C_ON		(0 != S12AD1.ADCSR.BIT.ADST)	// B15
#define	WAIT_S12AD1		{ while(S12AD1_C_ON); }
#define AN10_IU2		((uint16_t) S12AD1.ADDR0)		// P44 p085 IU2 AN100
#define AN11_IV2		((uint16_t) S12AD1.ADDR1)		// P45 p084 IV2 AN101
#define AN12_IW2		((uint16_t) S12AD1.ADDR2)		// P46 p083 IW2 AN102
#define AN13_VB2		((uint16_t) S12AD1.ADDR3)		// P47 p082 VB2 AN103
//#define AN17_TE2		((uint16_t) S12AD1.ADDR7)		// PH4 p086 TE2 AN107

// macro for A/D conversions: S12AD2
#define	S12AD2_START	{ S12AD2.ADCSR.BIT.ADST = 1; }	// B15
#define	S12AD2_STOP		{ S12AD2.ADCSR.BIT.ADST = 0; }	// B15
#define	S12AD2_C_ON		(0 != S12AD2.ADCSR.BIT.ADST)	// B15
#define	WAIT_S12AD2		{ while(S12AD2_C_ON); }
#ifndef HIV_PS_3
#define AN22_IW3		((uint16_t) S12AD2.ADDR0)		// P52 p081 IU3 AN200
#define AN21_IV3		((uint16_t) S12AD2.ADDR1)		// P53 p080 IV3 AN201
#define AN20_IU3		((uint16_t) S12AD2.ADDR2)		// P54 p079 IW3 AN202
#else 	// ifndef HIV_PS_3
#define AN20_IU3		((uint16_t) S12AD2.ADDR0)		// P52 p081 IU3 AN200
#define AN21_IV3		((uint16_t) S12AD2.ADDR1)		// P53 p080 IV3 AN201
#define AN22_IW3		((uint16_t) S12AD2.ADDR2)		// P54 p079 IW3 AN202
#endif 	// else ifndef HIV_PS_3
#define AN23_VB3		((uint16_t) S12AD2.ADDR3)		// P55 p078 VB3 AN203
#define AN28_TE3		((uint16_t) S12AD2.ADDR8)		// P62 p075 TE3 AN208
#define AN29_POT		((uint16_t) S12AD2.ADDR9)		// P63 p074 POT AN209

// macro for complementary pwm MTU timers 3, 4 (active state = high)
#define	BUF_SP1			( MTU.TCBRA )					// buffer for TCDRA (halfper)
#define	BUF_SPD1		( MTU3.TGRC )					// buffer for TGRA3 (halfper + deadtime)
#define	REG_U1			( MTU3.TGRB )					// duty U
#define	REG_V1			( MTU4.TGRA )					// duty V
#define	REG_W1			( MTU4.TGRB )					// duty W
#define	BUF_U1			( MTU3.TGRD )					// buffer for TGRB3 (duty U)
#define	BUF_V1			( MTU4.TGRC )					// buffer for TGRA4 (duty V)
#define	BUF_W1			( MTU4.TGRD )					// buffer for TGRB4 (duty W) (LAST TO BE WRITTEN!)
#define ENABLE_OUT1		{ MTU.TOERA.BYTE = 0xFF; }		// enable all PWM outputs
#define DISABLE_OUT1	{ MTU.TOERA.BYTE = 0xC0; }		// disable all PWM outputs
#define OUT1_ENABLED	(0xC0 != MTU.TOERA.BYTE)
#define NOT_OUT1_ENA	(0xC0 == MTU.TOERA.BYTE)
#define SET_PWM1(X, Y, Z)	{ BUF_U1 = ( X ); BUF_V1 = ( Y ); BUF_W1 = ( Z ); }	

// macro for complementary pwm MTU timers 6, 7 (active state = high)
#define	BUF_SP2			( MTU.TCBRB )					// buffer for TCDRB (halfper)
#define	BUF_SPD2		( MTU6.TGRC )					// buffer for TGRA6 (halfper + deadtime)
#define	REG_U2			( MTU6.TGRB )					// duty U
#define	REG_V2			( MTU7.TGRA )					// duty V
#define	REG_W2			( MTU7.TGRB )					// duty W
#define	BUF_U2			( MTU6.TGRD )					// buffer for TGRB6 (duty U)
#define	BUF_V2			( MTU7.TGRC )					// buffer for TGRA7 (duty V)
#define	BUF_W2			( MTU7.TGRD )					// buffer for TGRB7 (duty W) (LAST TO BE WRITTEN!)
#define ENABLE_OUT2		{ MTU.TOERB.BYTE = 0xFF; }		// enable all PWM outputs
#define DISABLE_OUT2	{ MTU.TOERB.BYTE = 0xC0; }		// disable all PWM outputs
#define OUT2_ENABLED	(0xC0 != MTU.TOERB.BYTE)
#define NOT_OUT2_ENA	(0xC0 == MTU.TOERB.BYTE)
#define SET_PWM2(X, Y, Z)	{ BUF_U2 = ( X ); BUF_V2 = ( Y ); BUF_W2 = ( Z ); }	

// macro for complementary pwm GPT timers 0, 1, 2 (active state = high)
#define	REG_U3			( GPTW0.GTCCRA )					// duty U
#define	REG_V3			( GPTW1.GTCCRA )					// duty V
#define	REG_W3			( GPTW2.GTCCRA )					// duty W
#define	BUF_U3			( GPTW0.GTCCRC )					// buffer for duty U
#define	BUF_V3			( GPTW1.GTCCRC )					// buffer for duty V
#define	BUF_W3			( GPTW2.GTCCRC )					// buffer for duty W
#define ENABLE_OUT3		{ GPTW0.GTIOR.LONG |= 0x01000100; GPTW1.GTIOR.LONG |= 0x01000100; GPTW2.GTIOR.LONG |= 0x01000100; }		// enable all PWM outputs
#define DISABLE_OUT3	{ GPTW0.GTIOR.LONG &= ~0x01000100; GPTW1.GTIOR.LONG &= ~0x01000100; GPTW2.GTIOR.LONG &= ~0x01000100; }	// disable all PWM outputs~
#define OUT3_ENABLED	(0 != GPTW0.GTIOR.BIT.OAE)
#define NOT_OUT3_ENA	(0 == GPTW0.GTIOR.BIT.OAE)
#define SET_PWM3(X, Y, Z)	{ BUF_U3 = ( X ); BUF_V3 = ( Y ); BUF_W3 = ( Z ); }	

// I/O macro
#define LD1_ON			( 0 != PORT2.PODR.BIT.B7 )		// P27 p064 LD1
#define LD1_OFF			( 0 == PORT2.PODR.BIT.B7 )
#define SET_LD1			{ PORT2.PODR.BIT.B7 = 1; }
#define RES_LD1			{ PORT2.PODR.BIT.B7 = 0; }

#define LD2_ON			( 0 != PORT3.PODR.BIT.B0 )		// P30 p063 LD2
#define LD2_OFF			( 0 == PORT3.PODR.BIT.B0 )
#define SET_LD2			{ PORT3.PODR.BIT.B0 = 1; }
#define RES_LD2			{ PORT3.PODR.BIT.B0 = 0; }

#define LIM_OFF_ON		( 0 != PORT3.PODR.BIT.B3 )		// P33 p058 LIM_OFF
#define LIM_OFF_OFF		( 0 == PORT3.PODR.BIT.B3 )
#define SET_LIM_OFF		{ PORT3.PODR.BIT.B3 = 1; }
#define RES_LIM_OFF		{ PORT3.PODR.BIT.B3 = 0; }



#endif	// ifndef _GLOBDEF_H

// EOF globdef.h
