
/*******************************************************************************
DISCLAIMER

THIS SOFTWARE IS PROVIDED "AS IS" AND BFG ENGINEERING MAKES NO WARRANTIES
REGARDING THIS SOFTWARE, WHETHER EXPRESS, IMPLIED OR STATUTORY, INCLUDING
BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
PURPOSE AND NON-INFRINGEMENT. ALL SUCH WARRANTIES ARE EXPRESSLY DISCLAIMED.

WE (BFG ENGINEERING) DO NOT WARRANT THAT THIS SOFTWARE IS FREE FROM CLAIMS
BY A THIRD PARTY OF COPYRIGHT, PATENT, TRADEMARK, TRADE SECRET OR ANY OTHER
INTELLECTUAL PROPERTY INFRINGIMENT.

TO THE MAXIMUM EXTENT PERMITTED NOT PROHIBITED BY LAW, BFG ENGINEERING
SHALL NOT BE LIABLE FOR ANY DIRECT, INDIRECT, SPECIAL, INCIDENTAL OR
CONSEQUENTIAL DAMAGES FOR ANY REASON RELATED TO THIS SOFTWARE, EVEN IF BFG
ENGINEERING HAS BEEN ADVISED OF THE POSSIBILITY OF SUCH DAMAGES.
PARTICULARLY, UNDER NO CIRCUMSTANCES ARE WE LIABLE FOR ANY OF THE FOLLOWING:
- THIRD PARTY CLAIMS AGAINST YOU FOR LOSSES OR DAMAGES;
- LOSS OF, OR DAMAGE TO YOUR RECORDS OR DATA; OR
- ECONOMIC CONSEQUENTIAL DAMAGES (INCLUDING LOST PROFITS OR SAVINGS) OR
  INCIDENTAL DAMAGES, EVEN IF WE ARE INFORMED OF THEIR POSSIBILITY.

BFG ENGINEERING DOES NOT WARRANT UNINTERRUPTED OR ERROR_FREE OPERATION OF
THIS SOFTWARE.
BFG ENGINEERING HAS NO OBLIGATION TO PROVIDE SERVICE, DEFECT CORRECTION OR
ANY MANTEINANCE OF THIS SOFTWARE; OR TO SUPPLY ANY UPDATES OR ENHANCEMENTS
EVEN IF SUCH ARE, OR LATER BECOME, AVAILABLE.

IF YOU DOWNLOAD OR USE THIS SOFTWARE YOU AGREE TO THESE TERMS, AND DO IT AT
YOUR OWN RISK.
*******************************************************************************/

/*******************************************************************************
File:		hwsetup.c
Project:	YRotateItRX66T
Revision:	1.0
Date:		2019-04-04 (YYYY-MM-DD)
Author:		Andrea Ghirardello
Contents:	Hardware configuration
*******************************************************************************/
#define	_HWSETUP_C

#include "globdef.h"

/* YRotateItRX66T board microcontroller pins ***********************************
  1			PE5	IRQ0	PM2_IRQ
  2	EMLE
  3	VSS
  4	UB		P00			NU
  5	VCL
  6	MD
  7			P01			PM2_IO0
  8			PE4	MTCLKC	ENC2A
  9			PE3	MTCLKD	ENC2B
 10 RES
 11	XTAL	P37			NU
 12	VSS
 13	EXTAL	P36			NU
 14	VCC
 15	NMI		PE2			TP16
 16			PE1			PM2_IO2
 17			PE0			PM2_IO1
 18	TRST	PD7			NU
 19	TMS		PD6			NU
 20	TDI		PD5	RXD1	RX_OP
 21	TCK		PD4			NU
 22	TDO		PD3	TXD1	TX_OP
 23			PD2	GTIOC0A	UH3
 24			PD1	GTIOC0B	UL3
 25			PD0	GTIOC1A	VH3
 >
 26			PB7	GTIOC1B	VL3
 27			PB6	GTIOC2A	WH3
 28			PB5	GTIOC2B	WL3
 29	VCC
 30			PB4	SCK11	PM1_SK
 31	VSS
 32			PB3			PM1_IO1
 33			PB2	SDA		EEP_SDA
 34			PB1	SCL		EEP_SCL
 35			PB0	CTS11	PM1_CTS
 36			PA5	IRQ1	PM1_IRQ
 37			PA4			PM1_IO0
 38			PA3	TXD9	TX_USB
 39			PA2	RXD9	RX_USB
 40			PA1	RX11	PM1_RX
 41			PA0	TX11	PM1_TX
 42	VCC
 43			P96	POE4	OVC2
 44	VSS
 45			P95	MTIOC6B	UH2
 46			P94	MTIOC7A	VH2
 47			P93	MTIOC7B	WH2
 48			P92	MTIOC6D	UL2
 49			P91	MTIOC7C	VL2
 50			P90	MTIOC7D	WL2
 >
 51			P76 MTIOC4D	WL1
 52			P75	MTIOC4C	VL1
 53			P74	MTIOC3D	UL1
 54			P73	MTIOC4B	WH1
 55			P72	MTIOC4A	VH1
 56			P71	MTIOC3B	UH1
 57			P70	POE0	OVC1
 58			P33			LIM_OFF
 59			P32			EXT_SUP
 60	VCC
 61			P31	IRQ6	HALL1W
 62	VSS
 63			P30			LD2
 64			P27			LD1
 65			P24	MTIC5U	HALL2U
 66			P23	MTIC5V	HALL2V
 67			P22	MTIC5W	HALL2W
 68			P21	MTCLKA	ENC1A
 69			P20	MTCLKB	ENC1B
 70			P65	DA1		TP_AN1
 71			P64	DA0		TP_AN0
 72	AVCC2
 73	AVSS2
 74			P63	AN209	POT
 75			P62	AN208	TE3
 >
 76			P61	IRQ5	HALL1V
 77			P60	IRQ4	HALL1U
 78			P55	AN203	VB3
 79			P54	AN202	IW3
 80			P53	AN201	IV3
 81			P52	AN200	IU3
 82			P47	AN103	VB2
 83			P46	AN102	IW2
 84			P45	AN101	IV2
 85			P44	AN100	IU2
 86			PH4	AN107	TE2
 87			P43	AN003	VB1
 88			P42	AN002	IW1
 89			P41	AN001	IV1
 90			P40	AN000	IU1
 91			PH0	AN007	TE1
 92	AVCC1
 93	AVCC0
 94	AVSS0
 95	AVSS1
 96			P82	SCK6	PM2_SK
 97			P81	TXD6	PM2_TX
 98			P80	RXD6	PM2_RX
 99			P11	POE9	OVC3
100			P10	CTS6	PM2_CTS
*******************************************************************************/

/*******************************************************************************
Function:		rom_cache_function_set
Description:	Configures the rom cache function
Input:			nothing
Output:			nothing
*******************************************************************************/
void rom_cache_function_set(void)
{
	FLASH.ROMCIV.WORD = 0x0001;	// Invalidates the contents of the ROM cache
	FLASH.ROMCE.WORD = 0x0001;	// Enables the ROM cache
}

/*******************************************************************************
Function:		clock_source_select
Description:	Enables and disables clocks as chosen by the user. This function
				also implements the delays needed for the clocks to stabilize.
Input:			nothing
Output:			nothing
Modifies:		clock configuration registers
*******************************************************************************/
void clock_source_select(void)
{
    SYSTEM.MOFCR.BIT.MOSEL = 0;			// Set the oscillation source of the main clock oscillator

	if(1 == SYSTEM.HOCOCR.BIT.HCSTP)	// Start HOCO operating if it is not already operating
	{
		SYSTEM.HOCOPCR.BYTE = 0x00;		// Turn on power to HOCO
		SYSTEM.HOCOCR.BYTE = 0x01;		// Stop HOCO
		while(1 == SYSTEM.OSCOVFSR.BIT.HCOVF)	// WAIT_LOOP
		{
			// The delay period needed is to make sure that the HOCO has stopped
		}
		SYSTEM.HOCOCR2.BYTE = 0x00;		// HOCO frequency: 16MHz
		SYSTEM.HOCOCR.BYTE = 0x00;		// Start it operating
		if(0x00 ==  SYSTEM.HOCOCR.BYTE)
		{
			// Dummy read and compare. cf."5. I/O Registers", "(2) Notes on writing to I/O registers" in User's manual. 
			// This is done to ensure that the register has been written before the next register access. The RX has a 
			// pipeline architecture so the next instruction could be executed before the previous write had finished. 
			nop();
		}
	}

	while(0 == SYSTEM.OSCOVFSR.BIT.HCOVF)	// WAIT_LOOP
	{
		// The delay period needed is to make sure that the HOCO has stabilized
	}

	SYSTEM.MOSCCR.BYTE = 0x01;			// Set the main clock to stopped
	if(0x01 ==  SYSTEM.MOSCCR.BYTE)
	{
		// Dummy read and compare. cf."5. I/O Registers", "(2) Notes on writing to I/O registers" in User's manual. 
		// This is done to ensure that the register has been written before the next register access. The RX has a 
		// pipeline architecture so the next instruction could be executed before the previous write had finished. 
		nop();
	}

	SYSTEM.MEMWAIT.BYTE = 0x01;			// Set MEMWAIT register since we are > 120MHz
	if(0x01 == SYSTEM.MEMWAIT.BYTE)
	{
		// Dummy read and compare. cf."5. I/O Registers", "(2) Notes on writing to I/O registers" in User's manual. 
		// This is done to ensure that the register has been written before the next register access. The RX has a 
		// pipeline architecture so the next instruction could be executed before the previous write had finished. 
		nop();
	}

	SYSTEM.PLLCR.BIT.PLIDIV = 0;		// Set PLL Input Divisor
	SYSTEM.PLLCR.BIT.PLLSRCSEL = 1;		// Set PLL clock source if PLL clock source is HOCO clock
	SYSTEM.PLLCR.BIT.STC = 0x13;		// Set PLL Multiplier (*10)
	SYSTEM.PLLCR2.BYTE = 0x00;			// Set the PLL to operating
	while(0 == SYSTEM.OSCOVFSR.BIT.PLOVF)	// WAIT_LOOP
	{
		/* The delay period needed is to make sure that the PLL has stabilized. */
	}
}

/*******************************************************************************
Function:		operating_frequency_set
Description:	Configures the clock settings for each of the device clocks
Input:			nothing
Output:			nothing
Modifies:		clock configuration registers
*******************************************************************************/
void operating_frequency_set(void)
{
	uint32_t temp_clock = 0;

	/*
	Default settings:
	Clock Description              Frequency
	----------------------------------------
	Input Clock Frequency............   8 MHz
	PLL frequency (x20).............. 160 MHz
	Internal Clock Frequency......... 160 MHz
	Peripheral Clock Frequency A.....  80 MHz
	Peripheral Clock Frequency B.....  40 MHz
	Peripheral Clock Frequency C..... 160 MHz
	Peripheral Clock Frequency D.....  40 MHz
	Flash IF Clock Frequency.........  40 MHz
	External Bus Clock Frequency.....  40 MHz
	USB Clock Frequency..............  80 MHz */

	SYSTEM.PRCR.WORD = 0xA50B;		// Protect off
	clock_source_select();			// Select the clock source

	temp_clock |= 0x20000000;		// BSP_CFG_FCK_DIV == 4		 40MHz
	// ICK bits should be 0			// BSP_CFG_ICK_DIV == 1		160MHz
	temp_clock |= 0x00020000;		// BSP_CFG_BCK_DIV == 4		external bus frequency
	temp_clock |= 0x00800000;		// BSP_CFG_BCLK_OUTPUT == 0	no external bus
	temp_clock |= 0x00001000;		// BSP_CFG_PCKA_DIV == 2	 80MHz
	temp_clock |= 0x00000200;		// BSP_CFG_PCKB_DIV == 4	 40MHz
	// PCKC bits should be 0		// BSP_CFG_PCKC_DIV == 1	160MHz
	temp_clock |= 0x00000002;		// BSP_CFG_PCKD_DIV == 4	 40MHz (A/D converter)
	SYSTEM.SCKCR.LONG = temp_clock;	// Set SCKCR register
	if(temp_clock ==  SYSTEM.SCKCR.LONG)
	{
		// Dummy read and compare. cf."5. I/O Registers", "(2) Notes on writing to I/O registers" in User's manual. 
		// This is done to ensure that the register has been written before the next register access. The RX has a 
		// pipeline architecture so the next instruction could be executed before the previous write had finished. 
		nop();
	}

	temp_clock = 0;					// Re-init temp_clock to use to set SCKCR2
	temp_clock |= 0x00000011;		// BSP_CFG_UCK_DIV == 2
	SYSTEM.SCKCR2.WORD = (uint16_t)temp_clock;	// Set SCKCR2 register
	if((uint16_t)temp_clock ==  SYSTEM.SCKCR2.WORD)
	{
		// Dummy read and compare. cf."5. I/O Registers", "(2) Notes on writing to I/O registers" in User's manual. 
		// This is done to ensure that the register has been written before the next register access. The RX has a 
		// pipeline architecture so the next instruction could be executed before the previous write had finished. 
		nop();
	}

	temp_clock = 1024;				// Choose clock source. Default is PLL
	SYSTEM.SCKCR3.WORD = (uint16_t)temp_clock;
	if((uint16_t)temp_clock ==  SYSTEM.SCKCR3.WORD)
	{
		// Dummy read and compare. cf."5. I/O Registers", "(2) Notes on writing to I/O registers" in User's manual. 
		// This is done to ensure that the register has been written before the next register access. The RX has a 
		// pipeline architecture so the next instruction could be executed before the previous write had finished. 
		nop();
	}

	SYSTEM.LOCOCR.BYTE = 0x01;	// We can now turn LOCO off since it is not going to be used

	SYSTEM.PRCR.WORD = 0xA500;	// Protect on
}

/*******************************************************************************
Function:		HardwareSetup
Description:	Configures the I/O ports
Input:			nothing
Output:			nothing
*******************************************************************************/
void HardwareSetup(void)
{

	// I/O ports first configuration

	// Port 0

	//PORT0.PIDR.BYTE					// port input data register
	//B7, .., B2
	//PORT0.PIDR.BIT.B1					// P01 p007 PM2_IO0
	//PORT0.PIDR.BIT.B0					// P00 p004 UB NU

	//PORT0.PODR.BYTE = 0;				// port output data register
	//B7, .., B2
	//PORT0.PODR.BIT.B1 = 0;			// P01 p007 PM2_IO0
	//PORT0.PODR.BIT.B0 = 0;			// P00 p004 UB NU

	//PORT0.PDR.BYTE = 0;				// port direction register
	//B7, .., B2
	//PORT0.PDR.BIT.B1 = 0;				// P01 p007 PM2_IO0
	//PORT0.PDR.BIT.B0 = 0;				// P00 p004 UB NU

	//PORT0.PMR.BYTE = 0;				// port mode register
	//B7, .., B2
	//PORT0.PMR.BIT.B1 = 0;				// P01 p007 PM2_IO0
	//PORT0.PMR.BIT.B0 = 0;				// P00 p004 UB NU

	//PORT0.PCR.BYTE = 0;				// pull-up control register
	//B7, .., B2
	//PORT0.PCR.BIT.B1 = 0;				// P01 p007 PM2_IO0
	//PORT0.PCR.BIT.B0 = 0;				// P00 p004 UB NU

	//PORT0.DSCR.BYTE = 0;				// drive capability control register
	//B7, .., B2
	//PORT0.DSCR.BIT.B1 = 0;			// P01 p007 PM2_IO0
	//PORT0.DSCR.BIT.B0 = 0;			// P00 p004 UB NU

	//PORT0.ODR0.BYTE = 0;				// open drain control register
	//B7, .., B3
	//PORT0.ODR0.BIT.B2 = 0;			// P01 p007 PM2_IO0
	//B1
	//PORT0.ODR0.BIT.B0 = 0;			// P00 p004 UB NU


	// Port 1

	//PORT1.PIDR.BYTE					// port input data register
	//B7, .., B2
	//PORT1.PIDR.BIT.B1					// P11 p099 OVC3 POE9
	//PORT1.PIDR.BIT.B0					// P10 p100 PM2_CTS CTS6

	//PORT1.PODR.BYTE = 0;				// port output data register
	//B7, .., B2
	//PORT1.PODR.BIT.B1 = 0;			// P11 p099 OVC3 POE9
	//PORT1.PODR.BIT.B0 = 0;			// P10 p100 PM2_CTS CTS6

	//PORT1.PDR.BYTE = 0;				// port direction register
	//B7, .., B2
	//PORT1.PDR.BIT.B1 = 0;				// P11 p099 OVC3 POE9
	//PORT1.PDR.BIT.B0 = 0;				// P10 p100 PM2_CTS CTS6

	//PORT1.PMR.BYTE = 0;				// port mode register
	//B7, .., B2
	//PORT1.PMR.BIT.B1 = 0;				// P11 p099 OVC3 POE9
	//PORT1.PMR.BIT.B0 = 0;				// P10 p100 PM2_CTS CTS6

	//PORT1.PCR.BYTE = 0;				// pull-up control register
	//B7, .., B2
	//PORT1.PCR.BIT.B1 = 0;				// P11 p099 OVC3 POE9
	//PORT1.PCR.BIT.B0 = 0;				// P10 p100 PM2_CTS CTS6

	//PORT1.DSCR.BYTE = 0;				// drive capability control register
	//B7, .., B2
	//PORT1.DSCR.BIT.B1 = 0;			// P11 p099 OVC3 POE9
	//PORT1.DSCR.BIT.B0 = 0;			// P10 p100 PM2_CTS CTS6

	//PORT1.ODR1.BYTE = 0;				// open drain control register 1
	//B7, .., B0

	//PORT1.ODR0.BYTE = 0;				// open drain control register
	//B7, .., B3
	//PORT1.ODR0.BIT.B2 = 0;			// P11 p099 OVC3 POE9
	//B1
	//PORT1.ODR0.BIT.B0 = 0;			// P10 p100 PM2_CTS CTS6


	// Port 2

	//PORT2.PIDR.BYTE					// port input data register
	//PORT2.PIDR.BIT.B7					// P27 p064 LD1
	//B6, B5
	//PORT2.PIDR.BIT.B4					// P24 p065 HALL2U MTIC5U
	//PORT2.PIDR.BIT.B3					// P23 p066 HALL2V MTIC5V
	//PORT2.PIDR.BIT.B2					// P22 p067 HALL2W MTIC5W
	//PORT2.PIDR.BIT.B1					// P21 p068 ENC1A MTCLKA
	//PORT2.PIDR.BIT.B0					// P20 p069 ENC1B MTCLKB

	PORT2.PODR.BYTE = 0x00;				// port output data register
	//PORT2.PODR.BIT.B7 = 0;			// P27 p064 LD1
	//B6, B5
	//PORT2.PODR.BIT.B4 = 0;			// P24 p065 HALL2U MTIC5U
	//PORT2.PODR.BIT.B3 = 0;			// P23 p066 HALL2V MTIC5V
	//PORT2.PODR.BIT.B2 = 0;			// P22 p067 HALL2W MTIC5W
	//PORT2.PODR.BIT.B1 = 0;			// P21 p068 ENC1A MTCLKA
	//PORT2.PODR.BIT.B0 = 0;			// P20 p069 ENC1B MTCLKB

	PORT2.PDR.BYTE = 0x80;				// port direction register
	//PORT2.PDR.BIT.B7 = 1;				// P27 p064 LD1
	//B6, B5
	//PORT2.PDR.BIT.B4 = 0;				// P24 p065 HALL2U MTIC5U
	//PORT2.PDR.BIT.B3 = 0;				// P23 p066 HALL2V MTIC5V
	//PORT2.PDR.BIT.B2 = 0;				// P22 p067 HALL2W MTIC5W
	//PORT2.PDR.BIT.B1 = 0;				// P21 p068 ENC1A MTCLKA
	//PORT2.PDR.BIT.B0 = 0;				// P20 p069 ENC1B MTCLKB

	//PORT2.PMR.BYTE = 0;				// port mode register
	//PORT2.PMR.BIT.B7 = 0;				// P27 p064 LD1
	//B6, B5
	//PORT2.PMR.BIT.B4 = 0;				// P24 p065 HALL2U MTIC5U
	//PORT2.PMR.BIT.B3 = 0;				// P23 p066 HALL2V MTIC5V
	//PORT2.PMR.BIT.B2 = 0;				// P22 p067 HALL2W MTIC5W
	//PORT2.PMR.BIT.B1 = 0;				// P21 p068 ENC1A MTCLKA
	//PORT2.PMR.BIT.B0 = 0;				// P20 p069 ENC1B MTCLKB

	//PORT2.PCR.BYTE = 0;				// pull-up control register
	//PORT2.PCR.BIT.B7 = 0;				// P27 p064 LD1
	//B6, B5
	//PORT2.PCR.BIT.B4 = 0;				// P24 p065 HALL2U MTIC5U
	//PORT2.PCR.BIT.B3 = 0;				// P23 p066 HALL2V MTIC5V
	//PORT2.PCR.BIT.B2 = 0;				// P22 p067 HALL2W MTIC5W
	//PORT2.PCR.BIT.B1 = 0;				// P21 p068 ENC1A MTCLKA
	//PORT2.PCR.BIT.B0 = 0;				// P20 p069 ENC1B MTCLKB

	//PORT2.DSCR.BYTE = 0;				// drive capability control register
	//PORT2.DSCR.BIT.B7 = 0;			// P27 p064 LD1
	//B6, B5
	//PORT2.DSCR.BIT.B4 = 0;			// P24 p065 HALL2U MTIC5U
	//PORT2.DSCR.BIT.B3 = 0;			// P23 p066 HALL2V MTIC5V
	//PORT2.DSCR.BIT.B2 = 0;			// P22 p067 HALL2W MTIC5W
	//PORT2.DSCR.BIT.B1 = 0;			// P21 p068 ENC1A MTCLKA
	//PORT2.DSCR.BIT.B0 = 0;			// P20 p069 ENC1B MTCLKB

	//PORT2.ODR1.BYTE = 0;				// open drain control register 1
	//B7, B6, B5
	//PORT2.ODR1.BIT.B4 = 0;			// P27 p064 LD1
	//B3, B2, B1
	//PORT2.ODR1.BIT.B0 = 0;			// P24 p065 HALL2U MTIC5U

	//PORT2.ODR0.BYTE = 0;				// open drain control register
	//B7
	//PORT2.ODR0.BIT.B6 = 0;			// P23 p066 HALL2V MTIC5V
	//B5
	//PORT2.ODR0.BIT.B4 = 0;			// P22 p067 HALL2W MTIC5W
	//B3
	//PORT2.ODR0.BIT.B2 = 0;			// P21 p068 ENC1A MTCLKA
	//B1
	//PORT2.ODR0.BIT.B0 = 0;			// P20 p069 ENC1B MTCLKB


	// Port 3

	//PORT3.PIDR.BYTE					// port input data register
	//PORT3.PIDR.BIT.B7					// P37 p011 XTAL NU
	//PORT3.PIDR.BIT.B6					// P36 p013 EXTAL NU
	//B5, B4
	//PORT3.PIDR.BIT.B3					// P33 p058 LIM_OFF
	//PORT3.PIDR.BIT.B2					// P32 p059 EXT_SUP
	//PORT3.PIDR.BIT.B1					// P31 p061 HALL1W IRQ6
	//PORT3.PIDR.BIT.B0					// P30 p063 LD2

	PORT3.PODR.BYTE = 0x00;				// port output data register
	//PORT3.PODR.BIT.B7 = 0;			// P37 p011 XTAL NU
	//PORT3.PODR.BIT.B6 = 0;			// P36 p013 EXTAL NU
	//B5, B4
	//PORT3.PODR.BIT.B3 = 0;			// P33 p058 LIM_OFF
	//PORT3.PODR.BIT.B2 = 0;			// P32 p059 EXT_SUP
	//PORT3.PODR.BIT.B1 = 0;			// P31 p061 HALL1W IRQ6
	//PORT3.PODR.BIT.B0 = 0;			// P30 p063 LD2

	PORT3.PDR.BYTE = 0x09;				// port direction register
	//PORT3.PDR.BIT.B7 = 0;				// P37 p011 XTAL NU
	//PORT3.PDR.BIT.B6 = 0;				// P36 p013 EXTAL NU
	//B5, B4
	//PORT3.PDR.BIT.B3 = 1;				// P33 p058 LIM_OFF
	//PORT3.PDR.BIT.B2 = 0;				// P32 p059 EXT_SUP
	//PORT3.PDR.BIT.B1 = 0;				// P31 p061 HALL1W IRQ6
	//PORT3.PDR.BIT.B0 = 1;				// P30 p063 LD2

	//PORT3.PMR.BYTE = 0;				// port mode register
	//PORT3.PMR.BIT.B7 = 0;				// P37 p011 XTAL NU
	//PORT3.PMR.BIT.B6 = 0;				// P36 p013 EXTAL NU
	//B5, B4
	//PORT3.PMR.BIT.B3 = 0;				// P33 p058 LIM_OFF
	//PORT3.PMR.BIT.B2 = 0;				// P32 p059 EXT_SUP
	//PORT3.PMR.BIT.B1 = 0;				// P31 p061 HALL1W IRQ6
	//PORT3.PMR.BIT.B0 = 0;				// P30 p063 LD2

	//PORT3.PCR.BYTE = 0;				// pull-up control register
	//PORT3.PCR.BIT.B7 = 0;				// P37 p011 XTAL NU
	//PORT3.PCR.BIT.B6 = 0;				// P36 p013 EXTAL NU
	//B5, B4
	//PORT3.PCR.BIT.B3 = 0;				// P33 p058 LIM_OFF
	//PORT3.PCR.BIT.B2 = 0;				// P32 p059 EXT_SUP
	//PORT3.PCR.BIT.B1 = 0;				// P31 p061 HALL1W IRQ6
	//PORT3.PCR.BIT.B0 = 0;				// P30 p063 LD2

	//PORT3.DSCR.BYTE = 0;				// drive capability control register
	//PORT3.DSCR.BIT.B7 = 0;			// P37 p011 XTAL NU
	//PORT3.DSCR.BIT.B6 = 0;			// P36 p013 EXTAL NU
	//B5, B4
	//PORT3.DSCR.BIT.B3 = 0;			// P33 p058 LIM_OFF
	//PORT3.DSCR.BIT.B2 = 0;			// P32 p059 EXT_SUP
	//PORT3.DSCR.BIT.B1 = 0;			// P31 p061 HALL1W IRQ6
	//PORT3.DSCR.BIT.B0 = 0;			// P30 p063 LD2

	//PORT3.ODR1.BYTE = 0;				// open drain control register 1
	//B7
	//PORT3.ODR1.BIT.B6 = 0;			// P37 p011 XTAL NU
	//B5
	//PORT3.ODR1.BIT.B4 = 0;			// P36 p013 EXTAL NU
	//B3, .., B0

	//PORT3.ODR0.BYTE = 0;				// open drain control register
	//B7
	//PORT3.ODR0.BIT.B6 = 0;			// P33 p058 LIM_OFF
	//B5
	//PORT3.ODR0.BIT.B4 = 0;			// P32 p059 EXT_SUP
	//B3
	//PORT3.ODR0.BIT.B2 = 0;			// P31 p061 HALL1W IRQ6
	//B1
	//PORT3.ODR0.BIT.B0 = 0;			// P30 p063 LD2


	// Port 4

	//PORT4.PIDR.BYTE					// port input data register
	//PORT4.PIDR.BIT.B7					// P47 p082 VB2 AN103
	//PORT4.PIDR.BIT.B6					// P46 p083 IW2 AN102
	//PORT4.PIDR.BIT.B5					// P45 p084 IV2 AN101
	//PORT4.PIDR.BIT.B4					// P44 p085 IU2 AN100
	//PORT4.PIDR.BIT.B3					// P43 p087 VB1 AN003
	//PORT4.PIDR.BIT.B2					// P42 p088 IW1 AN002
	//PORT4.PIDR.BIT.B1					// P41 p089 IV1 AN001
	//PORT4.PIDR.BIT.B0					// P40 p090 IU1 AN000

	//PORT4.PODR.BYTE = 0;				// port output data register
	//PORT4.PODR.BIT.B7 = 0;			// P47 p082 VB2 AN103
	//B6, .., B4
	//PORT4.PODR.BIT.B3 = 0;			// P43 p087 VB1 AN003
	//B2, .., B0

	//PORT4.PDR.BYTE = 0;				// port direction register
	//PORT4.PDR.BIT.B7 = 0;				// P47 p082 VB2 AN103
	//B6, .., B4
	//PORT4.PDR.BIT.B3 = 0;				// P43 p087 VB1 AN003
	//B2, .., B0

	//PORT4.PMR.BYTE = 0;				// port mode register
	//PORT4.PMR.BIT.B7 = 0;				// P47 p082 VB2 AN103
	//PORT4.PMR.BIT.B6 = 0;				// P46 p083 IW2 AN102
	//PORT4.PMR.BIT.B5 = 0;				// P45 p084 IV2 AN101
	//PORT4.PMR.BIT.B4 = 0;				// P44 p085 IU2 AN100
	//PORT4.PMR.BIT.B3 = 0;				// P43 p087 VB1 AN003
	//PORT4.PMR.BIT.B2 = 0;				// P42 p088 IW1 AN002
	//PORT4.PMR.BIT.B1 = 0;				// P41 p089 IV1 AN001
	//PORT4.PMR.BIT.B0 = 0;				// P40 p090 IU1 AN000

	//PORT4.PCR.BYTE = 0;				// pull-up control register
	//PORT4.PCR.BIT.B7 = 0;				// P47 p082 VB2 AN103
	//B6, .., B4
	//PORT4.PCR.BIT.B3 = 0;				// P43 p087 VB1 AN003
	//B2, .., B0

	//PORT4.ODR1.BYTE = 0;				// open drain control register 1
	//B7
	//PORT4.ODR1.BIT.B6 = 0;			// P47 p082 VB2 AN103
	//B5, .., B0

	//PORT4.ODR0.BYTE = 0;				// open drain control register
	//B7
	//PORT4.ODR0.BIT.B6 = 0;			// P43 p087 VB1 AN003
	//B5, .., B0


	// Port 5

	//PORT5.PIDR.BYTE					// port input data register
	//B7, B6
	//PORT5.PIDR.BIT.B5					// P55 p078 VB3 AN203
	//PORT5.PIDR.BIT.B4					// P54 p079 IW3 AN202
	//PORT5.PIDR.BIT.B3					// P53 p080 IV3 AN201
	//PORT5.PIDR.BIT.B2					// P52 p081 IU3 AN200
	//B1, B0

	//PORT5.PODR.BYTE = 0;				// port output data register
	//B7, B6
	//PORT5.PODR.BIT.B5 = 0;			// P55 p078 VB3 AN203
	//PORT5.PODR.BIT.B4 = 0;			// P54 p079 IW3 AN202
	//PORT5.PODR.BIT.B3 = 0;			// P53 p080 IV3 AN201
	//PORT5.PODR.BIT.B2 = 0;			// P52 p081 IU3 AN200
	//B1, B0

	//PORT5.PDR.BYTE = 0;				// port direction register
	//B7, B6
	//PORT5.PDR.BIT.B5 = 0;				// P55 p078 VB3 AN203
	//PORT5.PDR.BIT.B4 = 0;				// P54 p079 IW3 AN202
	//PORT5.PDR.BIT.B3 = 0;				// P53 p080 IV3 AN201
	//PORT5.PDR.BIT.B2 = 0;				// P52 p081 IU3 AN200
	//B1, B0

	//PORT5.PMR.BYTE = 0;				// port mode register
	//B7, B6
	//PORT5.PMR.BIT.B5 = 0;				// P55 p078 VB3 AN203
	//PORT5.PMR.BIT.B4 = 0;				// P54 p079 IW3 AN202
	//PORT5.PMR.BIT.B3 = 0;				// P53 p080 IV3 AN201
	//PORT5.PMR.BIT.B2 = 0;				// P52 p081 IU3 AN200
	//B1, B0

	//PORT5.PCR.BYTE = 0;				// pull-up control register
	//B7, B6
	//PORT5.PCR.BIT.B5 = 0;				// P55 p078 VB3 AN203
	//PORT5.PCR.BIT.B4 = 0;				// P54 p079 IW3 AN202
	//PORT5.PCR.BIT.B3 = 0;				// P53 p080 IV3 AN201
	//PORT5.PCR.BIT.B2 = 0;				// P52 p081 IU3 AN200
	//B1, B0

	//PORT5.ODR1.BYTE = 0;				// open drain control register 1
	//B7, .., B3
	//PORT5.ODR1.BIT.B2 = 0;			// P55 p078 VB3 AN203
	//B1
	//PORT5.ODR1.BIT.B0 = 0;			// P54 p079 IW3 AN202

	//PORT5.ODR0.BYTE = 0;				// open drain control register
	//B7
	//PORT5.ODR0.BIT.B6 = 0;			// P53 p080 IV3 AN201
	//B5
	//PORT5.ODR0.BIT.B4 = 0;			// P52 p081 IU3 AN200
	//B3, .., B0


	// Port 6

	//PORT6.PIDR.BYTE					// port input data register
	//B7, B6
	//PORT6.PIDR.BIT.B5					// P65 p070 TP_AN1 DA1
	//PORT6.PIDR.BIT.B4					// P64 p071 TP_AN0 DA0
	//PORT6.PIDR.BIT.B3					// P63 p074 POT AN209
	//PORT6.PIDR.BIT.B2					// P62 p075 TE3 AN208
	//PORT6.PIDR.BIT.B1					// P61 p076 HALL1V IRQ5
	//PORT6.PIDR.BIT.B0					// P60 p077 HALL1U IRQ4

	//PORT6.PODR.BYTE = 0;				// port output data register
	//B7, B6
	//PORT6.PODR.BIT.B5 = 0;			// P65 p070 TP_AN1 DA1
	//PORT6.PODR.BIT.B4 = 0;			// P64 p071 TP_AN0 DA0
	//PORT6.PODR.BIT.B3 = 0;			// P63 p074 POT AN209
	//PORT6.PODR.BIT.B2 = 0;			// P62 p075 TE3 AN208
	//PORT6.PODR.BIT.B1 = 0;			// P61 p076 HALL1V IRQ5
	//PORT6.PODR.BIT.B0 = 0;			// P60 p077 HALL1U IRQ4

	//PORT6.PDR.BYTE = 0;				// port direction register
	//B7, B6
	//PORT6.PDR.BIT.B5 = 0;				// P65 p070 TP_AN1 DA1
	//PORT6.PDR.BIT.B4 = 0;				// P64 p071 TP_AN0 DA0
	//PORT6.PDR.BIT.B3 = 0;				// P63 p074 POT AN209
	//PORT6.PDR.BIT.B2 = 0;				// P62 p075 TE3 AN208
	//PORT6.PDR.BIT.B1 = 0;				// P61 p076 HALL1V IRQ5
	//PORT6.PDR.BIT.B0 = 0;				// P60 p077 HALL1U IRQ4

	//PORT6.PMR.BYTE = 0;				// port mode register
	//B7, B6
	//PORT6.PMR.BIT.B5 = 0;				// P65 p070 TP_AN1 DA1
	//PORT6.PMR.BIT.B4 = 0;				// P64 p071 TP_AN0 DA0
	//PORT6.PMR.BIT.B3 = 0;				// P63 p074 POT AN209
	//PORT6.PMR.BIT.B2 = 0;				// P62 p075 TE3 AN208
	//PORT6.PMR.BIT.B1 = 0;				// P61 p076 HALL1V IRQ5
	//PORT6.PMR.BIT.B0 = 0;				// P60 p077 HALL1U IRQ4

	//PORT6.PCR.BYTE = 0;				// pull-up control register
	//B7, B6
	//PORT6.PCR.BIT.B5 = 0;				// P65 p070 TP_AN1 DA1
	//PORT6.PCR.BIT.B4 = 0;				// P64 p071 TP_AN0 DA0
	//PORT6.PCR.BIT.B3 = 0;				// P63 p074 POT AN209
	//PORT6.PCR.BIT.B2 = 0;				// P62 p075 TE3 AN208
	//PORT6.PCR.BIT.B1 = 0;				// P61 p076 HALL1V IRQ5
	//PORT6.PCR.BIT.B0 = 0;				// P60 p077 HALL1U IRQ4

	//PORT6.ODR1.BYTE = 0;				// open drain control register 1
	//B7, .., B3
	//PORT6.ODR1.BIT.B2 = 0;			// P65 p070 TP_AN1 DA1
	//B1
	//PORT6.ODR1.BIT.B0 = 0;			// P64 p071 TP_AN0 DA0

	//PORT6.ODR0.BYTE = 0;				// open drain control register
	//B7
	//PORT6.ODR0.BIT.B6 = 0;			// P63 p074 POT AN209
	//B5
	//PORT6.ODR0.BIT.B4 = 0;			// P62 p075 TE3 AN208
	//B3
	//PORT6.ODR0.BIT.B2 = 0;			// P61 p076 HALL1V IRQ5
	//B1
	//PORT6.ODR0.BIT.B0 = 0;			// P60 p077 HALL1U IRQ4


	// Port 7

	//PORT7.PIDR.BYTE					// port input data register
	//B7
	//PORT7.PIDR.BIT.B6					// P76 p051 WL1 MTIOC4D
	//PORT7.PIDR.BIT.B5					// P75 p052 VL1 MTIOC4C
	//PORT7.PIDR.BIT.B4					// P74 p053 UL1 MTIOC3D
	//PORT7.PIDR.BIT.B3					// P73 p054 WH1 MTIOC4B
	//PORT7.PIDR.BIT.B2					// P72 p055 VH1 MTIOC4A
	//PORT7.PIDR.BIT.B1					// P71 p056 UH1 MTIOC3B
	//PORT7.PIDR.BIT.B0					// P70 p057 OVC1 POE0

	PORT7.PODR.BYTE = 0x00;				// port output data register
	//B7
	//PORT7.PODR.BIT.B6 = 0;			// P76 p051 WL1 MTIOC4D
	//PORT7.PODR.BIT.B5 = 0;			// P75 p052 VL1 MTIOC4C
	//PORT7.PODR.BIT.B4 = 0;			// P74 p053 UL1 MTIOC3D
	//PORT7.PODR.BIT.B3 = 0;			// P73 p054 WH1 MTIOC4B
	//PORT7.PODR.BIT.B2 = 0;			// P72 p055 VH1 MTIOC4A
	//PORT7.PODR.BIT.B1 = 0;			// P71 p056 UH1 MTIOC3B
	//PORT7.PODR.BIT.B0 = 0;			// P70 p057 OVC1 POE0

	PORT7.PDR.BYTE = 0x7E;				// port direction register
	//B7
	//PORT7.PDR.BIT.B6 = 1;				// P76 p051 WL1 MTIOC4D
	//PORT7.PDR.BIT.B5 = 1;				// P75 p052 VL1 MTIOC4C
	//PORT7.PDR.BIT.B4 = 1;				// P74 p053 UL1 MTIOC3D
	//PORT7.PDR.BIT.B3 = 1;				// P73 p054 WH1 MTIOC4B
	//PORT7.PDR.BIT.B2 = 1;				// P72 p055 VH1 MTIOC4A
	//PORT7.PDR.BIT.B1 = 1;				// P71 p056 UH1 MTIOC3B
	//PORT7.PDR.BIT.B0 = 0;				// P70 p057 OVC1 POE0

	//PORT7.PMR.BYTE = 0;				// port mode register
	//B7
	//PORT7.PMR.BIT.B6 = 0;				// P76 p051 WL1 MTIOC4D
	//PORT7.PMR.BIT.B5 = 0;				// P75 p052 VL1 MTIOC4C
	//PORT7.PMR.BIT.B4 = 0;				// P74 p053 UL1 MTIOC3D
	//PORT7.PMR.BIT.B3 = 0;				// P73 p054 WH1 MTIOC4B
	//PORT7.PMR.BIT.B2 = 0;				// P72 p055 VH1 MTIOC4A
	//PORT7.PMR.BIT.B1 = 0;				// P71 p056 UH1 MTIOC3B
	//PORT7.PMR.BIT.B0 = 0;				// P70 p057 OVC1 POE0

	//PORT7.PCR.BYTE = 0;				// pull-up control register
	//B7
	//PORT7.PCR.BIT.B6 = 0;				// P76 p051 WL1 MTIOC4D
	//PORT7.PCR.BIT.B5 = 0;				// P75 p052 VL1 MTIOC4C
	//PORT7.PCR.BIT.B4 = 0;				// P74 p053 UL1 MTIOC3D
	//PORT7.PCR.BIT.B3 = 0;				// P73 p054 WH1 MTIOC4B
	//PORT7.PCR.BIT.B2 = 0;				// P72 p055 VH1 MTIOC4A
	//PORT7.PCR.BIT.B1 = 0;				// P71 p056 UH1 MTIOC3B
	//PORT7.PCR.BIT.B0 = 0;				// P70 p057 OVC1 POE0

	//PORT7.DSCR.BYTE = 0;				// drive capability control register
	//B7
	//PORT7.DSCR.BIT.B6 = 0;			// P76 p051 WL1 MTIOC4D
	//PORT7.DSCR.BIT.B5 = 0;			// P75 p052 VL1 MTIOC4C
	//PORT7.DSCR.BIT.B4 = 0;			// P74 p053 UL1 MTIOC3D
	//PORT7.DSCR.BIT.B3 = 0;			// P73 p054 WH1 MTIOC4B
	//PORT7.DSCR.BIT.B2 = 0;			// P72 p055 VH1 MTIOC4A
	//PORT7.DSCR.BIT.B1 = 0;			// P71 p056 UH1 MTIOC3B
	//PORT7.DSCR.BIT.B0 = 0;			// P70 p057 OVC1 POE0

	//PORT7.ODR1.BYTE = 0;				// open drain control register 1
	//B7, .., B5
	//PORT7.ODR1.BIT.B4 = 0;			// P76 p051 WL1 MTIOC4D
	//B3
	//PORT7.ODR1.BIT.B2 = 0;			// P75 p052 VL1 MTIOC4C
	//B1
	//PORT7.ODR1.BIT.B0 = 0;			// P74 p053 UL1 MTIOC3D

	//PORT7.ODR0.BYTE = 0;				// open drain control register
	//B7
	//PORT7.ODR0.BIT.B6 = 0;			// P73 p054 WH1 MTIOC4B
	//B5
	//PORT7.ODR0.BIT.B4 = 0;			// P72 p055 VH1 MTIOC4A
	//B3
	//PORT7.ODR0.BIT.B2 = 0;			// P71 p056 UH1 MTIOC3B
	//B1
	//PORT7.ODR0.BIT.B0 = 0;			// P70 p057 OVC1 POE0


	// Port 8

	//PORT8.PIDR.BYTE					// port input data register
	//B7, .., B3
	//PORT8.PIDR.BIT.B2					// P82 p096 PM2_SK SCK6
	//PORT8.PIDR.BIT.B1					// P81 p097 PM2_TX TXD6
	//PORT8.PIDR.BIT.B0					// P80 p098 PM2_RX RXD6

	PORT8.PODR.BYTE = 0x02;				// port output data register
	//B7, .., B3
	//PORT8.PODR.BIT.B2 = 0;			// P82 p096 PM2_SK SCK6
	//PORT8.PODR.BIT.B1 = 1;			// P81 p097 PM2_TX TXD6
	//PORT8.PODR.BIT.B0 = 0;			// P80 p098 PM2_RX RXD6

	PORT8.PDR.BYTE = 0x02;				// port direction register
	//B7, .., B3
	//PORT8.PDR.BIT.B2 = 0;				// P82 p096 PM2_SK SCK6
	//PORT8.PDR.BIT.B1 = 1;				// P81 p097 PM2_TX TXD6
	//PORT8.PDR.BIT.B0 = 0;				// P80 p098 PM2_RX RXD6

	//PORT8.PMR.BYTE = 0;				// port mode register
	//B7, .., B3
	//PORT8.PMR.BIT.B2 = 0;				// P82 p096 PM2_SK SCK6
	//PORT8.PMR.BIT.B1 = 0;				// P81 p097 PM2_TX TXD6
	//PORT8.PMR.BIT.B0 = 0;				// P80 p098 PM2_RX RXD6

	//PORT8.PCR.BYTE = 0;				// pull-up control register
	//B7, .., B3
	//PORT8.PCR.BIT.B2 = 0;				// P82 p096 PM2_SK SCK6
	//PORT8.PCR.BIT.B1 = 0;				// P81 p097 PM2_TX TXD6
	//PORT8.PCR.BIT.B0 = 0;				// P80 p098 PM2_RX RXD6

	//PORT8.DSCR.BYTE = 0;				// drive capability control register
	//B7, .., B3
	//PORT8.DSCR.BIT.B2 = 0;			// P82 p096 PM2_SK SCK6
	//PORT8.DSCR.BIT.B1 = 0;			// P81 p097 PM2_TX TXD6
	//PORT8.DSCR.BIT.B0 = 0;			// P80 p098 PM2_RX RXD6

	//PORT8.ODR0.BYTE = 0;				// open drain control register
	//B7, .., B5
	//PORT8.ODR0.BIT.B4 = 0;			// P82 p096 PM2_SK SCK6
	//B3
	//PORT8.ODR0.BIT.B2 = 0;			// P81 p097 PM2_TX TXD6
	//B1
	//PORT8.ODR0.BIT.B0 = 0;			// P80 p098 PM2_RX RXD6


	// Port 9

	//PORT9.PIDR.BYTE					// port input data register
	//B7
	//PORT9.PIDR.BIT.B6					// P96 p043 OVC2 POE4
	//PORT9.PIDR.BIT.B5					// P95 p045 UH2 MTIOC6B
	//PORT9.PIDR.BIT.B4					// P94 p046 VH2 MTIOC7A
	//PORT9.PIDR.BIT.B3					// P93 p047 WH2 MTIOC7B
	//PORT9.PIDR.BIT.B2					// P92 p048 UL2 MTIOC6D
	//PORT9.PIDR.BIT.B1					// P91 p049 VL2 MTIOC7C
	//PORT9.PIDR.BIT.B0					// P90 p050 WL2 MTIOC7D

	PORT9.PODR.BYTE = 0x00;				// port output data register
	//B7
	//PORT9.PODR.BIT.B6 = 0;			// P96 p043 OVC2 POE4
	//PORT9.PODR.BIT.B5 = 0;			// P95 p045 UH2 MTIOC6B
	//PORT9.PODR.BIT.B4 = 0;			// P94 p046 VH2 MTIOC7A
	//PORT9.PODR.BIT.B3 = 0;			// P93 p047 WH2 MTIOC7B
	//PORT9.PODR.BIT.B2 = 0;			// P92 p048 UL2 MTIOC6D
	//PORT9.PODR.BIT.B1 = 0;			// P91 p049 VL2 MTIOC7C
	//PORT9.PODR.BIT.B0 = 0;			// P90 p050 WL2 MTIOC7D

	PORT9.PDR.BYTE = 0x3F;				// port direction register
	//B7
	//PORT9.PDR.BIT.B6 = 0;				// P96 p043 OVC2 POE4
	//PORT9.PDR.BIT.B5 = 1;				// P95 p045 UH2 MTIOC6B
	//PORT9.PDR.BIT.B4 = 1;				// P94 p046 VH2 MTIOC7A
	//PORT9.PDR.BIT.B3 = 1;				// P93 p047 WH2 MTIOC7B
	//PORT9.PDR.BIT.B2 = 1;				// P92 p048 UL2 MTIOC6D
	//PORT9.PDR.BIT.B1 = 1;				// P91 p049 VL2 MTIOC7C
	//PORT9.PDR.BIT.B0 = 1;				// P90 p050 WL2 MTIOC7D

	//PORT9.PMR.BYTE = 0;				// port mode register
	//B7
	//PORT9.PMR.BIT.B6 = 0;				// P96 p043 OVC2 POE4
	//PORT9.PMR.BIT.B5 = 0;				// P95 p045 UH2 MTIOC6B
	//PORT9.PMR.BIT.B4 = 0;				// P94 p046 VH2 MTIOC7A
	//PORT9.PMR.BIT.B3 = 0;				// P93 p047 WH2 MTIOC7B
	//PORT9.PMR.BIT.B2 = 0;				// P92 p048 UL2 MTIOC6D
	//PORT9.PMR.BIT.B1 = 0;				// P91 p049 VL2 MTIOC7C
	//PORT9.PMR.BIT.B0 = 0;				// P90 p050 WL2 MTIOC7D

	//PORT9.PCR.BYTE = 0;				// pull-up control register
	//B7
	//PORT9.PCR.BIT.B6 = 0;				// P96 p043 OVC2 POE4
	//PORT9.PCR.BIT.B5 = 0;				// P95 p045 UH2 MTIOC6B
	//PORT9.PCR.BIT.B4 = 0;				// P94 p046 VH2 MTIOC7A
	//PORT9.PCR.BIT.B3 = 0;				// P93 p047 WH2 MTIOC7B
	//PORT9.PCR.BIT.B2 = 0;				// P92 p048 UL2 MTIOC6D
	//PORT9.PCR.BIT.B1 = 0;				// P91 p049 VL2 MTIOC7C
	//PORT9.PCR.BIT.B0 = 0;				// P90 p050 WL2 MTIOC7D

	//PORT9.DSCR.BYTE = 0;				// drive capability control register
	//B7
	//PORT9.DSCR.BIT.B6 = 0;			// P96 p043 OVC2 POE4
	//PORT9.DSCR.BIT.B5 = 0;			// P95 p045 UH2 MTIOC6B
	//PORT9.DSCR.BIT.B4 = 0;			// P94 p046 VH2 MTIOC7A
	//PORT9.DSCR.BIT.B3 = 0;			// P93 p047 WH2 MTIOC7B
	//PORT9.DSCR.BIT.B2 = 0;			// P92 p048 UL2 MTIOC6D
	//PORT9.DSCR.BIT.B1 = 0;			// P91 p049 VL2 MTIOC7C
	//PORT9.DSCR.BIT.B0 = 0;			// P90 p050 WL2 MTIOC7D

	//PORT9.ODR1.BYTE = 0;				// open drain control register 1
	//B7, .., B5
	//PORT9.ODR1.BIT.B4 = 0;			// P96 p043 OVC2 POE4
	//B3
	//PORT9.ODR1.BIT.B2 = 0;			// P95 p045 UH2 MTIOC6B
	//B1
	//PORT9.ODR1.BIT.B0 = 0;			// P94 p046 VH2 MTIOC7A

	//PORT9.ODR0.BYTE = 0;				// open drain control register
	//B7
	//PORT9.ODR0.BIT.B6 = 0;			// P93 p047 WH2 MTIOC7B
	//B5
	//PORT9.ODR0.BIT.B4 = 0;			// P92 p048 UL2 MTIOC6D
	//B3
	//PORT9.ODR0.BIT.B2 = 0;			// P91 p049 VL2 MTIOC7C
	//B1
	//PORT9.ODR0.BIT.B0 = 0;			// P90 p050 WL2 MTIOC7D


	// Port A

	//PORTA.PIDR.BYTE					// port input data register
	//B7, B6
	//PORTA.PIDR.BIT.B5					// PA5 p036 PM1_IRQ IRQ1
	//PORTA.PIDR.BIT.B4					// PA4 p037 PM1_IO0
	//PORTA.PIDR.BIT.B3					// PA3 p038 TX_USB TXD9
	//PORTA.PIDR.BIT.B2					// PA2 p039 RX_USB RXD9
	//PORTA.PIDR.BIT.B1					// PA1 p040 PM1_RX RX11
	//PORTA.PIDR.BIT.B0					// PA0 p041 PM1_TX TX11

	PORTA.PODR.BYTE = 0x09;				// port output data register
	//B7, B6
	//PORTA.PODR.BIT.B5 = 0;			// PA5 p036 PM1_IRQ IRQ1
	//PORTA.PODR.BIT.B4 = 0;			// PA4 p037 PM1_IO0
	//PORTA.PODR.BIT.B3 = 1;			// PA3 p038 TX_USB TXD9
	//PORTA.PODR.BIT.B2 = 0;			// PA2 p039 RX_USB RXD9
	//PORTA.PODR.BIT.B1 = 0;			// PA1 p040 PM1_RX RX11
	//PORTA.PODR.BIT.B0 = 1;			// PA0 p041 PM1_TX TX11

	PORTA.PDR.BYTE = 0x09;				// port direction register
	//B7, B6
	//PORTA.PDR.BIT.B5 = 0;				// PA5 p036 PM1_IRQ IRQ1
	//PORTA.PDR.BIT.B4 = 0;				// PA4 p037 PM1_IO0
	//PORTA.PDR.BIT.B3 = 1;				// PA3 p038 TX_USB TXD9
	//PORTA.PDR.BIT.B2 = 0;				// PA2 p039 RX_USB RXD9
	//PORTA.PDR.BIT.B1 = 0;				// PA1 p040 PM1_RX RX11
	//PORTA.PDR.BIT.B0 = 1;				// PA0 p041 PM1_TX TX11

	//PORTA.PMR.BYTE = 0;				// port mode register
	//B7, B6
	//PORTA.PMR.BIT.B5 = 0;				// PA5 p036 PM1_IRQ IRQ1
	//PORTA.PMR.BIT.B4 = 0;				// PA4 p037 PM1_IO0
	//PORTA.PMR.BIT.B3 = 0;				// PA3 p038 TX_USB TXD9
	//PORTA.PMR.BIT.B2 = 0;				// PA2 p039 RX_USB RXD9
	//PORTA.PMR.BIT.B1 = 0;				// PA1 p040 PM1_RX RX11
	//PORTA.PMR.BIT.B0 = 0;				// PA0 p041 PM1_TX TX11

	//PORTA.PCR.BYTE = 0;				// pull-up control register
	//B7, B6
	//PORTA.PCR.BIT.B5 = 0;				// PA5 p036 PM1_IRQ IRQ1
	//PORTA.PCR.BIT.B4 = 0;				// PA4 p037 PM1_IO0
	//PORTA.PCR.BIT.B3 = 0;				// PA3 p038 TX_USB TXD9
	//PORTA.PCR.BIT.B2 = 0;				// PA2 p039 RX_USB RXD9
	//PORTA.PCR.BIT.B1 = 0;				// PA1 p040 PM1_RX RX11
	//PORTA.PCR.BIT.B0 = 0;				// PA0 p041 PM1_TX TX11

	//PORTA.DSCR.BYTE = 0;				// drive capability control register
	//B7, B6
	//PORTA.DSCR.BIT.B5 = 0;			// PA5 p036 PM1_IRQ IRQ1
	//PORTA.DSCR.BIT.B4 = 0;			// PA4 p037 PM1_IO0
	//PORTA.DSCR.BIT.B3 = 0;			// PA3 p038 TX_USB TXD9
	//PORTA.DSCR.BIT.B2 = 0;			// PA2 p039 RX_USB RXD9
	//PORTA.DSCR.BIT.B1 = 0;			// PA1 p040 PM1_RX RX11
	//PORTA.DSCR.BIT.B0 = 0;			// PA0 p041 PM1_TX TX11

	//PORTA.ODR1.BYTE = 0;				// open drain control register 1
	//B7, .., B3
	//PORTA.ODR1.BIT.B2 = 0;			// PA5 p036 PM1_IRQ IRQ1
	//B1
	//PORTA.ODR1.BIT.B0 = 0;			// PA4 p037 PM1_IO0

	//PORTA.ODR0.BYTE = 0;				// open drain control register
	//B7
	//PORTA.ODR0.BIT.B6 = 0;			// PA3 p038 TX_USB TXD9
	//B5
	//PORTA.ODR0.BIT.B4 = 0;			// PA2 p039 RX_USB RXD9
	//B3
	//PORTA.ODR0.BIT.B2 = 0;			// PA1 p040 PM1_RX RX11
	//B1
	//PORTA.ODR0.BIT.B0 = 0;			// PA0 p041 PM1_TX TX11


	// Port B

	//PORTB.PIDR.BYTE					// port input data register
	//PORTB.PIDR.BIT.B7					// PB7 p026 VL3 GTIOC1B
	//PORTB.PIDR.BIT.B6					// PB6 p027 WH3 GTIOC2A
	//PORTB.PIDR.BIT.B5					// PB5 p028 WL3 GTIOC2B
	//PORTB.PIDR.BIT.B4					// PB4 p030 PM1_SK SCK11
	//PORTB.PIDR.BIT.B3					// PB3 p032 PM1_IO1
	//PORTB.PIDR.BIT.B2					// PB2 p033 EEP_SDA SDA
	//PORTB.PIDR.BIT.B1					// PB1 p034 EEP_SCL SCL
	//PORTB.PIDR.BIT.B0					// PB0 p035 PM1_CTS CTS11

	PORTB.PODR.BYTE = 0x00;				// port output data register
	//PORTB.PODR.BIT.B7 = 0;			// PB7 p026 VL3 GTIOC1B
	//PORTB.PODR.BIT.B6 = 0;			// PB6 p027 WH3 GTIOC2A
	//PORTB.PODR.BIT.B5 = 0;			// PB5 p028 WL3 GTIOC2B
	//PORTB.PODR.BIT.B4 = 0;			// PB4 p030 PM1_SK SCK11
	//PORTB.PODR.BIT.B3 = 0;			// PB3 p032 PM1_IO1
	//PORTB.PODR.BIT.B2 = 0;			// PB2 p033 EEP_SDA SDA
	//PORTB.PODR.BIT.B1 = 0;			// PB1 p034 EEP_SCL SCL
	//PORTB.PODR.BIT.B0 = 0;			// PB0 p035 PM1_CTS CTS11

	PORTB.PDR.BYTE = 0x0E;				// port direction register
	//PORTB.PDR.BIT.B7 = 1;				// PB7 p026 VL3 GTIOC1B
	//PORTB.PDR.BIT.B6 = 1;				// PB6 p027 WH3 GTIOC2A
	//PORTB.PDR.BIT.B5 = 1;				// PB5 p028 WL3 GTIOC2B
	//PORTB.PDR.BIT.B4 = 0;				// PB4 p030 PM1_SK SCK11
	//PORTB.PDR.BIT.B3 = 0;				// PB3 p032 PM1_IO1
	//PORTB.PDR.BIT.B2 = 0;				// PB2 p033 EEP_SDA SDA
	//PORTB.PDR.BIT.B1 = 0;				// PB1 p034 EEP_SCL SCL
	//PORTB.PDR.BIT.B0 = 0;				// PB0 p035 PM1_CTS CTS11

	//PORTB.PMR.BYTE = 0;				// port mode register
	//PORTB.PMR.BIT.B7 = 0;				// PB7 p026 VL3 GTIOC1B
	//PORTB.PMR.BIT.B6 = 0;				// PB6 p027 WH3 GTIOC2A
	//PORTB.PMR.BIT.B5 = 0;				// PB5 p028 WL3 GTIOC2B
	//PORTB.PMR.BIT.B4 = 0;				// PB4 p030 PM1_SK SCK11
	//PORTB.PMR.BIT.B3 = 0;				// PB3 p032 PM1_IO1
	//PORTB.PMR.BIT.B2 = 0;				// PB2 p033 EEP_SDA SDA
	//PORTB.PMR.BIT.B1 = 0;				// PB1 p034 EEP_SCL SCL
	//PORTB.PMR.BIT.B0 = 0;				// PB0 p035 PM1_CTS CTS11

	//PORTB.PCR.BYTE = 0;				// pull-up control register
	//PORTB.PCR.BIT.B7 = 0;				// PB7 p026 VL3 GTIOC1B
	//PORTB.PCR.BIT.B6 = 0;				// PB6 p027 WH3 GTIOC2A
	//PORTB.PCR.BIT.B5 = 0;				// PB5 p028 WL3 GTIOC2B
	//PORTB.PCR.BIT.B4 = 0;				// PB4 p030 PM1_SK SCK11
	//PORTB.PCR.BIT.B3 = 0;				// PB3 p032 PM1_IO1
	//PORTB.PCR.BIT.B2 = 0;				// PB2 p033 EEP_SDA SDA
	//PORTB.PCR.BIT.B1 = 0;				// PB1 p034 EEP_SCL SCL
	//PORTB.PCR.BIT.B0 = 0;				// PB0 p035 PM1_CTS CTS11

	//PORTB.DSCR.BYTE = 0;				// drive capability control register
	//PORTB.DSCR.BIT.B7 = 0;			// PB7 p026 VL3 GTIOC1B
	//PORTB.DSCR.BIT.B6 = 0;			// PB6 p027 WH3 GTIOC2A
	//PORTB.DSCR.BIT.B5 = 0;			// PB5 p028 WL3 GTIOC2B
	//PORTB.DSCR.BIT.B4 = 0;			// PB4 p030 PM1_SK SCK11
	//PORTB.DSCR.BIT.B3 = 0;			// PB3 p032 PM1_IO1
	//PORTB.DSCR.BIT.B2 = 0;			// PB2 p033 EEP_SDA SDA
	//PORTB.DSCR.BIT.B1 = 0;			// PB1 p034 EEP_SCL SCL
	//PORTB.DSCR.BIT.B0 = 0;			// PB0 p035 PM1_CTS CTS11

	//PORTB.ODR1.BYTE = 0;				// open drain control register 1
	//B7
	//PORTB.ODR1.BIT.B6 = 0;			// PB7 p026 VL3 GTIOC1B
	//B5
	//PORTB.ODR1.BIT.B4 = 0;			// PB6 p027 WH3 GTIOC2A
	//B3
	//PORTB.ODR1.BIT.B2 = 0;			// PB5 p028 WL3 GTIOC2B
	//B1
	//PORTB.ODR1.BIT.B0 = 0;			// PB4 p030 PM1_SK SCK11

	//PORTB.ODR0.BYTE = 0;				// open drain control register
	//B7
	//PORTB.ODR0.BIT.B6 = 0;			// PB3 p032 PM1_IO1
	//B5
	//PORTB.ODR0.BIT.B4 = 0;			// PB2 p033 EEP_SDA SDA
	//B3
	//PORTB.ODR0.BIT.B2 = 0;			// PB1 p034 EEP_SCL SCL
	//B1
	//PORTB.ODR0.BIT.B0 = 0;			// PB0 p035 PM1_CTS CTS11


	// Port D

	//PORTD.PIDR.BYTE					// port input data register
	//PORTD.PIDR.BIT.B7					// PD7 p018 TRST NU
	//PORTD.PIDR.BIT.B6					// PD6 p019 TMS NU
	//PORTD.PIDR.BIT.B5					// PD5 p020 TDI RX_OP RXD1  
	//PORTD.PIDR.BIT.B4					// PD4 p021 TCK NU     
	//PORTD.PIDR.BIT.B3					// PD3 p022 TDO TX_OP TXD1  
	//PORTD.PIDR.BIT.B2					// PD2 p023 UH3 GTIOC0A
	//PORTD.PIDR.BIT.B1					// PD1 p024 UL3 GTIOC0B
	//PORTD.PIDR.BIT.B0					// PD0 p025 VH3 GTIOC1A

	PORTD.PODR.BYTE = 0x08;				// port output data register
	//PORTD.PODR.BIT.B7 = 0;			// PD7 p018 TRST NU
	//PORTD.PODR.BIT.B6 = 0;			// PD6 p019 TMS NU
	//PORTD.PODR.BIT.B5 = 0;			// PD5 p020 TDI RX_OP RXD1  
	//PORTD.PODR.BIT.B4 = 0;			// PD4 p021 TCK NU     
	//PORTD.PODR.BIT.B3 = 1;			// PD3 p022 TDO TX_OP TXD1  
	//PORTD.PODR.BIT.B2 = 0;			// PD2 p023 UH3 GTIOC0A
	//PORTD.PODR.BIT.B1 = 0;			// PD1 p024 UL3 GTIOC0B
	//PORTD.PODR.BIT.B0 = 0;			// PD0 p025 VH3 GTIOC1A

	PORTD.PDR.BYTE = 0x0F;				// port direction register
	//PORTD.PDR.BIT.B7 = 0;				// PD7 p018 TRST NU
	//PORTD.PDR.BIT.B6 = 0;				// PD6 p019 TMS NU
	//PORTD.PDR.BIT.B5 = 0;				// PD5 p020 TDI RX_OP RXD1  
	//PORTD.PDR.BIT.B4 = 0;				// PD4 p021 TCK NU     
	//PORTD.PDR.BIT.B3 = 1;				// PD3 p022 TDO TX_OP TXD1  
	//PORTD.PDR.BIT.B2 = 1;				// PD2 p023 UH3 GTIOC0A
	//PORTD.PDR.BIT.B1 = 1;				// PD1 p024 UL3 GTIOC0B
	//PORTD.PDR.BIT.B0 = 1;				// PD0 p025 VH3 GTIOC1A

	//PORTD.PMR.BYTE = 0;				// port mode register
	//PORTD.PMR.BIT.B7 = 0;				// PD7 p018 TRST NU
	//PORTD.PMR.BIT.B6 = 0;				// PD6 p019 TMS NU
	//PORTD.PMR.BIT.B5 = 0;				// PD5 p020 TDI RX_OP RXD1  
	//PORTD.PMR.BIT.B4 = 0;				// PD4 p021 TCK NU     
	//PORTD.PMR.BIT.B3 = 0;				// PD3 p022 TDO TX_OP TXD1  
	//PORTD.PMR.BIT.B2 = 0;				// PD2 p023 UH3 GTIOC0A
	//PORTD.PMR.BIT.B1 = 0;				// PD1 p024 UL3 GTIOC0B
	//PORTD.PMR.BIT.B0 = 0;				// PD0 p025 VH3 GTIOC1A

	//PORTD.PCR.BYTE = 0;				// pull-up control register
	//PORTD.PCR.BIT.B7 = 0;				// PD7 p018 TRST NU
	//PORTD.PCR.BIT.B6 = 0;				// PD6 p019 TMS NU
	//PORTD.PCR.BIT.B5 = 0;				// PD5 p020 TDI RX_OP RXD1  
	//PORTD.PCR.BIT.B4 = 0;				// PD4 p021 TCK NU     
	//PORTD.PCR.BIT.B3 = 0;				// PD3 p022 TDO TX_OP TXD1  
	//PORTD.PCR.BIT.B2 = 0;				// PD2 p023 UH3 GTIOC0A
	//PORTD.PCR.BIT.B1 = 0;				// PD1 p024 UL3 GTIOC0B
	//PORTD.PCR.BIT.B0 = 0;				// PD0 p025 VH3 GTIOC1A

	//PORTD.DSCR.BYTE = 0;				// drive capability control register
	//PORTD.DSCR.BIT.B7 = 0;			// PD7 p018 TRST NU
	//PORTD.DSCR.BIT.B6 = 0;			// PD6 p019 TMS NU
	//PORTD.DSCR.BIT.B5 = 0;			// PD5 p020 TDI RX_OP RXD1
	//PORTD.DSCR.BIT.B4 = 0;			// PD4 p021 TCK NU
	//PORTD.DSCR.BIT.B3 = 0;			// PD3 p022 TDO TX_OP TXD1
	//PORTD.DSCR.BIT.B2 = 0;			// PD2 p023 UH3 GTIOC0A
	//PORTD.DSCR.BIT.B1 = 0;			// PD1 p024 UL3 GTIOC0B
	//PORTD.DSCR.BIT.B0 = 0;			// PD0 p025 VH3 GTIOC1A

	//PORTD.DSCR2.BYTE = 0;				// drive capability control register 2
	//B7, .., B4
	//PORTD.DSCR2.BIT.B3 = 0;			// PD3 p022 TDO TX_OP TXD1
	//B2, .., B0

	//PORTD.ODR1.BYTE = 0;
	//B7
	//PORTD.ODR1.BIT.B6 = 0;			// PD7 p018 TRST NU
	//B5
	//PORTD.ODR1.BIT.B4 = 0;			// PD6 p019 TMS NU
	//B3
	//PORTD.ODR1.BIT.B2 = 0;			// PD5 p020 TDI RX_OP RXD1
	//B1
	//PORTD.ODR1.BIT.B0 = 0;			// PD4 p021 TCK NU

	//PORTD.ODR0.BYTE = 0;				// open drain control register
	//B7
	//PORTD.ODR0.BIT.B6 = 0;			// PD3 p022 TDO TX_OP TXD1
	//B5
	//PORTD.ODR0.BIT.B4 = 0;			// PD2 p023 UH3 GTIOC0A
	//B3
	//PORTD.ODR0.BIT.B2 = 0;			// PD1 p024 UL3 GTIOC0B
	//B1
	//PORTD.ODR0.BIT.B0 = 0;			// PD0 p025 VH3 GTIOC1A


	// Port E

	//PORTE.PIDR.BYTE					// port input data register
	//B7, B6
	//PORTE.PIDR.BIT.B5					// PE5 p001 PM2_IRQ IRQ0
	//PORTE.PIDR.BIT.B4					// PE4 p008 ENC2A MTCLKC
	//PORTE.PIDR.BIT.B3					// PE3 p009 ENC2B MTCLKD
	//PORTE.PIDR.BIT.B2					// PE2 p015 NMI TP16
	//PORTE.PIDR.BIT.B1					// PE1 p016 PM2_IO2
	//PORTE.PIDR.BIT.B0					// PE0 p017 PM2_IO1

	//PORTE.PODR.BYTE = 0;				// port output data register
	//B7, B6
	//PORTE.PODR.BIT.B5 = 0;			// PE5 p001 PM2_IRQ IRQ0
	//PORTE.PODR.BIT.B4 = 0;			// PE4 p008 ENC2A MTCLKC
	//PORTE.PODR.BIT.B3 = 0;			// PE3 p009 ENC2B MTCLKD
	//PORTE.PODR.BIT.B2 = 0;			// PE2 p015 NMI TP16
	//PORTE.PODR.BIT.B1 = 0;			// PE1 p016 PM2_IO2
	//PORTE.PODR.BIT.B0 = 0;			// PE0 p017 PM2_IO1

	//PORTE.PDR.BYTE = 0;				// port direction register
	//B7, B6
	//PORTE.PDR.BIT.B5 = 0;				// PE5 p001 PM2_IRQ IRQ0
	//PORTE.PDR.BIT.B4 = 0;				// PE4 p008 ENC2A MTCLKC
	//PORTE.PDR.BIT.B3 = 0;				// PE3 p009 ENC2B MTCLKD
	//PORTE.PDR.BIT.B2 = 0;				// PE2 p015 NMI TP16
	//PORTE.PDR.BIT.B1 = 0;				// PE1 p016 PM2_IO2
	//PORTE.PDR.BIT.B0 = 0;				// PE0 p017 PM2_IO1

	//PORTE.PMR.BYTE = 0;				// port mode register
	//B7, B6
	//PORTE.PMR.BIT.B5 = 0;				// PE5 p001 PM2_IRQ IRQ0
	//PORTE.PMR.BIT.B4 = 0;				// PE4 p008 ENC2A MTCLKC
	//PORTE.PMR.BIT.B3 = 0;				// PE3 p009 ENC2B MTCLKD
	//PORTE.PMR.BIT.B2 = 0;				// PE2 p015 NMI TP16
	//PORTE.PMR.BIT.B1 = 0;				// PE1 p016 PM2_IO2
	//PORTE.PMR.BIT.B0 = 0;				// PE0 p017 PM2_IO1

	//PORTE.PCR.BYTE = 0;				// pull-up control register
	//B7, B6
	//PORTE.PCR.BIT.B5 = 0;				// PE5 p001 PM2_IRQ IRQ0
	//PORTE.PCR.BIT.B4 = 0;				// PE4 p008 ENC2A MTCLKC
	//PORTE.PCR.BIT.B3 = 0;				// PE3 p009 ENC2B MTCLKD
	//PORTE.PCR.BIT.B2 = 0;				// PE2 p015 NMI TP16
	//PORTE.PCR.BIT.B1 = 0;				// PE1 p016 PM2_IO2
	//PORTE.PCR.BIT.B0 = 0;				// PE0 p017 PM2_IO1

	//PORTE.DSCR.BYTE = 0;				// drive capability control register
	//B7, B6
	//PORTE.DSCR.BIT.B5 = 0;			// PE5 p001 PM2_IRQ IRQ0
	//PORTE.DSCR.BIT.B4 = 0;			// PE4 p008 ENC2A MTCLKC
	//PORTE.DSCR.BIT.B3 = 0;			// PE3 p009 ENC2B MTCLKD
	//PORTE.DSCR.BIT.B2 = 0;			// PE2 p015 NMI TP16
	//PORTE.DSCR.BIT.B1 = 0;			// PE1 p016 PM2_IO2
	//PORTE.DSCR.BIT.B0 = 0;			// PE0 p017 PM2_IO1

	//PORTE.ODR1.BYTE = 0;				// open drain control register 1
	//B7, .., B3
	//PORTE.ODR1.BIT.B2 = 0;			// PE5 p001 PM2_IRQ IRQ0
	//B1
	//PORTE.ODR1.BIT.B0 = 0;			// PE4 p008 ENC2A MTCLKC

	//PORTE.ODR0.BYTE = 0;				// open drain control register
	//B7
	//PORTE.ODR0.BIT.B6 = 0;			// PE3 p009 ENC2B MTCLKD
	//B5, .., B3
	//PORTE.ODR0.BIT.B2 = 0;			// PE1 p016 PM2_IO2
	//B1
	//PORTE.ODR0.BIT.B0 = 0;			// PE0 p017 PM2_IO1


	// Port H

	//PORTH.PIDR.BYTE					// port input data register
	//B7, .., B5
	//PORTH.PIDR.BIT.B4					// PH4 p086 TE2 AN107
	//B3, .., B1
	//PORTH.PIDR.BIT.B0					// PH0 p091 AN007	TE1

	//PORTH.PODR.BYTE = 0;				// port output data register
	//B7, .., B5
	//PORTH.PODR.BIT.B4 = 0;			// PH4 p086 TE2 AN107
	//B3, .., B1
	//PORTH.PODR.BIT.B0 = 0;			// PH0 p091 AN007	TE1

	//PORTH.PDR.BYTE = 0;				// port direction register
	//B7, .., B5
	//PORTH.PDR.BIT.B4 = 0;				// PH4 p086 TE2 AN107
	//B3, .., B1
	//PORTH.PDR.BIT.B0 = 0;				// PH0 p091 AN007	TE1

	//PORTH.PMR.BYTE = 0;				// port mode register
	//B7, .., B5
	//PORTH.PMR.BIT.B4 = 0;				// PH4 p086 TE2 AN107
	//B3, .., B1
	//PORTH.PMR.BIT.B0 = 0;				// PH0 p091 AN007	TE1

	//PORTH.PCR.BYTE = 0;				// pull-up control register
	//B7, .., B5
	//PORTH.PCR.BIT.B4 = 0;				// PH4 p086 TE2 AN107
	//B3, .., B1
	//PORTH.PCR.BIT.B0 = 0;				// PH0 p091 AN007	TE1

	//PORTH.ODR1.BYTE = 0;				// open drain control register 1
	//B7, .., B1
	//PORTH.ODR1.BIT.B0 = 0;			// PH4 p086 TE2 AN107

	//PORTH.ODR0.BYTE = 0;				// open drain control register
	//B7, .., B1
	//PORTH.ODR0.BIT.B0 = 0;			// PH0 p091 AN007	TE1

}

// EOF hwsetup.c
