
/*******************************************************************************
DISCLAIMER

THIS SOFTWARE IS PROVIDED "AS IS" AND BFG ENGINEERING MAKES NO WARRANTIES
REGARDING THIS SOFTWARE, WHETHER EXPRESS, IMPLIED OR STATUTORY, INCLUDING
BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
PURPOSE AND NON-INFRINGEMENT. ALL SUCH WARRANTIES ARE EXPRESSLY DISCLAIMED.

WE (BFG ENGINEERING) DO NOT WARRANT THAT THIS SOFTWARE IS FREE FROM CLAIMS
BY A THIRD PARTY OF COPYRIGHT, PATENT, TRADEMARK, TRADE SECRET OR ANY OTHER
INTELLECTUAL PROPERTY INFRINGIMENT.

TO THE MAXIMUM EXTENT PERMITTED NOT PROHIBITED BY LAW, BFG ENGINEERING
SHALL NOT BE LIABLE FOR ANY DIRECT, INDIRECT, SPECIAL, INCIDENTAL OR
CONSEQUENTIAL DAMAGES FOR ANY REASON RELATED TO THIS SOFTWARE, EVEN IF BFG
ENGINEERING HAS BEEN ADVISED OF THE POSSIBILITY OF SUCH DAMAGES.
PARTICULARLY, UNDER NO CIRCUMSTANCES ARE WE LIABLE FOR ANY OF THE FOLLOWING:
- THIRD PARTY CLAIMS AGAINST YOU FOR LOSSES OR DAMAGES;
- LOSS OF, OR DAMAGE TO YOUR RECORDS OR DATA; OR
- ECONOMIC CONSEQUENTIAL DAMAGES (INCLUDING LOST PROFITS OR SAVINGS) OR
  INCIDENTAL DAMAGES, EVEN IF WE ARE INFORMED OF THEIR POSSIBILITY.

BFG ENGINEERING DOES NOT WARRANT UNINTERRUPTED OR ERROR_FREE OPERATION OF
THIS SOFTWARE.
BFG ENGINEERING HAS NO OBLIGATION TO PROVIDE SERVICE, DEFECT CORRECTION OR
ANY MANTEINANCE OF THIS SOFTWARE; OR TO SUPPLY ANY UPDATES OR ENHANCEMENTS
EVEN IF SUCH ARE, OR LATER BECOME, AVAILABLE.

IF YOU DOWNLOAD OR USE THIS SOFTWARE YOU AGREE TO THESE TERMS, AND DO IT AT
YOUR OWN RISK.
*******************************************************************************/

/*******************************************************************************
File:		pws_EBRX66T.h
Project:	YRotateItRX66T
Revision:	1.0
Date:		2019-04-04 (YYYY-MM-DD)
Author:		Andrea Ghirardello
Contents:	Internal power stage (EBRX66T) related definitions
*******************************************************************************/
#ifndef	_PWS_EBRX66T_H
#define _PWS_EBRX66T_H

// power stage choice: uncomment the one you are using
#define INTERNAL_PS_1
#define INTERNAL_PS_2
#define INTERNAL_PS_3

#ifndef INTERNAL_PS_1
#define HIV_PS_1
//#define LOV_PS_1
#endif	// ifndef INTERNAL_PS_1
#ifndef INTERNAL_PS_2
#define HIV_PS_2
//#define LOV_PS_2
#endif	// ifndef INTERNAL_PS_1
#ifndef INTERNAL_PS_3
#define HIV_PS_3
//#define LOV_PS_3
#endif	// ifndef INTERNAL_PS_1

#ifdef INTERNAL_PS_1
/* LOW VOLTAGE POWER STAGE */
// current conversion
// NOTE: the current is considered positive if going out from the inverter
#define RSHUNT_OHM1			(      0.1 )	// shunt value [Ohm]
#define PUP1				(   1200.0 )	// pull-up resistor [Ohm]
#define SER1				(    220.0 )	// series resistor [Ohm]
#define VPUP1				(      5.0 )	// voltage of pull-up [V]
#define IPGAG1				(      3.636 )	// internal PGA gain
#define RSGAIN1				(-IPGAG1 * (PUP1 - SER1) / (PUP1 + SER1))	// total circuit gain

// DC bus voltage (and output voltages) conversion
#define RVBUSH_OHM1			( 100000.0 )	// high side split resistor [Ohm]
#define RVBUSL_OHM1			(  10000.0 )	// low side split resistor [Ohm]

// deadtimes to be inserted by MTU
#define DEADTIM_NS1			(    800 )		// deatimes [ns]

// minimum on time of low arms (one half of), to guarantee good current reading
// this time should guarantee that the lower switch commutates effectively for enough time to
// sample the current for A/D conversion (added to deadtimes, it gives the minimum duty-cycle value)
#define MIN_TON_LOW_NS1		(    300 )		// [ns]

// current conversion delay respect pwm trough
#define CON_DELAY_NS1		(     20 )		// [ns] lesser than MIN_TON_LOW

// voltages
#define VB_NOM_VOL1			(     48 )		// nominal bus voltage [V]

#else	// ifdef INTERNAL_PS_1
#ifdef HIV_PS_1
/* HIGH VOLTAGE POWER STAGE E6140 */
// current conversion
// NOTE: the current is considered positive if going out from the inverter
#define RSHUNT_OHM1			(      0.05 )	// shunt value [Ohm]
#define RSGAIN1				(      5.0 )	// circuit gain

// DC bus voltage conversion
#define RVBUSH_OHM1			( 400000.0 )	// high side split resistor [Ohm]
#define RVBUSL_OHM1			(   4700.0 )	// low side split resistor [Ohm]

// deadtimes to be inserted by MTU
#define DEADTIM_NS1			(   1000 )		// deatimes [ns]

// minimum on time of low arms (one half of), to guarantee good current reading
// this time should guarantee that the lower switch commutates effectively for enough time to
// sample the current for A/D conversion (added to deadtimes, it gives the minimum duty-cycle value)
#define MIN_TON_LOW_NS1		(    300 )		// [ns]

// current conversion delay respect pwm trough
#define CON_DELAY_NS1		(     20 )		// [ns] lesser than MIN_TON_LOW

// voltages
#define VB_NOM_VOL1			(    311 )		// nominal bus voltage [V]

#endif	// ifdef HIV_PS_1

#ifdef LOV_PS_1
/* LOW VOLTAGE POWER STAGE */
#define LEM_ON1

// NOTE: the current is considered positive if going out from the inverter
#ifndef LEM_ON1
#define RSHUNT_OHM1			(     0.001 )	// shunt value [Ohm]
#define RSGAIN1				(    31.0 )		// circuit gain				-> total 0.031
#else	// ifndef LEM_ON1
//#define RSHUNT_OHM1			(0.625 / 20)	// LEM gain HXS 20-NP	-> total 0.03125
#define RSHUNT_OHM1			(0.625 / 50)	// LEM gain HXS 50-NP		-> total 0.0125
#define RSGAIN1				(     1.0 )		// circuit gain if LEM used
#endif	// else ifndef LEM_ON1

// DC bus voltage conversion
#define RVBUSH_OHM1			(  82000.0 )	// high side split resistor [Ohm]
#define RVBUSL_OHM1			(   6200.0 )	// low side split resistor [Ohm]

// deadtimes to be inserted by MTU
#define DEADTIM_NS1			(   1000 )		// deatimes [ns]

// minimum on time of low arms (one half of), to guarantee good current reading
// this time should guarantee that the lower switch commutates effectively for enough time to
// sample the current for A/D conversion (added to deadtimes, it gives the minimum duty-cycle value)
#define MIN_TON_LOW_NS1		(    300 )		// [ns]

// current conversion delay respect pwm trough
#define CON_DELAY_NS1		(     30 )		// [ns] lesser than MIN_TON_LOW

// voltages
#define VB_NOM_VOL1			(     48 )		// nominal bus voltage [V]

#endif	// ifdef LOV_PS_1

#endif	// else ifdef INTERNAL_PS_1

#ifdef INTERNAL_PS_2
/* LOW VOLTAGE POWER STAGE */
// current conversion
// NOTE: the current is considered positive if going out from the inverter
#define RSHUNT_OHM2			(      0.1 )	// shunt value [Ohm]
#define PUP2				(   1200.0 )	// pull-up resistor [Ohm]
#define SER2				(    220.0 )	// series resistor [Ohm]
#define VPUP2				(      5.0 )	// voltage of pull-up [V]
#define IPGAG2				(      3.636 )	// internal PGA gain
#define RSGAIN2				(-IPGAG2 * (PUP2 - SER2) / (PUP2 + SER2))	// total circuit gain

// DC bus voltage (and output voltages) conversion
#define RVBUSH_OHM2			( 100000.0 )	// high side split resistor [Ohm]
#define RVBUSL_OHM2			(  10000.0 )	// low side split resistor [Ohm]

// deadtimes to be inserted by MTU
#define DEADTIM_NS2			(    800 )		// deatimes [ns]

// minimum on time of low arms (one half of), to guarantee good current reading
// this time should guarantee that the lower switch commutates effectively for enough time to
// sample the current for A/D conversion (added to deadtimes, it gives the minimum duty-cycle value)
#define MIN_TON_LOW_NS2		(    300 )		// [ns]

// current conversion delay respect pwm trough
#define CON_DELAY_NS2		(     20 )		// [ns] lesser than MIN_TON_LOW

// voltages
#define VB_NOM_VOL2			(     48 )		// nominal bus voltage [V]

#else	// ifdef INTERNAL_PS_2

#ifdef HIV_PS_2
/* HIGH VOLTAGE POWER STAGE E6140 */
// current conversion
// NOTE: the current is considered positive if going out from the inverter
#define RSHUNT_OHM2			(      0.05 )	// shunt value [Ohm]
#define RSGAIN2				(      5.0 )	// circuit gain

// DC bus voltage conversion
#define RVBUSH_OHM2			( 400000.0 )	// high side split resistor [Ohm]
#define RVBUSL_OHM2			(   4700.0 )	// low side split resistor [Ohm]

// deadtimes to be inserted by MTU
#define DEADTIM_NS2			(   1000 )		// deatimes [ns]

// minimum on time of low arms (one half of), to guarantee good current reading
// this time should guarantee that the lower switch commutates effectively for enough time to
// sample the current for A/D conversion (added to deadtimes, it gives the minimum duty-cycle value)
#define MIN_TON_LOW_NS2		(    300 )		// [ns]

// current conversion delay respect pwm trough
#define CON_DELAY_NS2		(     20 )		// [ns] lesser than MIN_TON_LOW

// voltages
#define VB_NOM_VOL2			(    311 )		// nominal bus voltage [V]

#endif	// ifdef HIV_PS_2

#ifdef LOV_PS_2
/* LOW VOLTAGE POWER STAGE */
#define LEM_ON2

// NOTE: the current is considered positive if going out from the inverter
#ifndef LEM_ON2
#define RSHUNT_OHM2			(     0.001 )	// shunt value [Ohm]
#define RSGAIN2				(    31.0 )		// circuit gain				-> total 0.031
#else	// ifndef LEM_ON2
//#define RSHUNT_OHM2			(0.625 / 20)	// LEM gain HXS 20-NP	-> total 0.03125
#define RSHUNT_OHM2			(0.625 / 50)	// LEM gain HXS 50-NP		-> total 0.0125
#define RSGAIN2				(     1.0 )		// circuit gain if LEM used
#endif	// else ifndef LEM_ON2

// DC bus voltage conversion
#define RVBUSH_OHM2			(  82000.0 )	// high side split resistor [Ohm]
#define RVBUSL_OHM2			(   6200.0 )	// low side split resistor [Ohm]

// deadtimes to be inserted by MTU
#define DEADTIM_NS2			(   1000 )		// deatimes [ns]

// minimum on time of low arms (one half of), to guarantee good current reading
// this time should guarantee that the lower switch commutates effectively for enough time to
// sample the current for A/D conversion (added to deadtimes, it gives the minimum duty-cycle value)
#define MIN_TON_LOW_NS2		(    300 )		// [ns]

// current conversion delay respect pwm trough
#define CON_DELAY_NS2		(     30 )		// [ns] lesser than MIN_TON_LOW

// voltages
#define VB_NOM_VOL2			(     48 )		// nominal bus voltage [V]

#endif	// ifdef LOV_PS_2

#endif	// else	ifdef INTERNAL_PS_2

#ifdef INTERNAL_PS_3
/* LOW VOLTAGE POWER STAGE */
// current conversion
// NOTE: the current is considered positive if going out from the inverter
#define RSHUNT_OHM3			(      0.1 )	// shunt value [Ohm]
#define RSGAIN3				(      5.0 )	// total circuit gain

// DC bus voltage (and output voltages) conversion
#define RVBUSH_OHM3			( 100000.0 )	// high side split resistor [Ohm]
#define RVBUSL_OHM3			(  10000.0 )	// low side split resistor [Ohm]

// deadtimes to be inserted by MTU
#define DEADTIM_NS3			(    800 )		// deatimes [ns]

// minimum on time of low arms (one half of), to guarantee good current reading
// this time should guarantee that the lower switch commutates effectively for enough time to
// sample the current for A/D conversion (added to deadtimes, it gives the minimum duty-cycle value)
#define MIN_TON_LOW_NS3		(    300 )		// [ns]

// current conversion delay respect pwm trough
#define CON_DELAY_NS3		(     20 )		// [ns] lesser than MIN_TON_LOW

// voltages
#define VB_NOM_VOL3			(     48 )		// nominal bus voltage [V]

#else	// ifdef INTERNAL_PS_3

#ifdef HIV_PS_3
/* HIGH VOLTAGE POWER STAGE E6140 */
// current conversion
// NOTE: the current is considered positive if going out from the inverter
#define RSHUNT_OHM3			(      0.05 )	// shunt value [Ohm]
#define RSGAIN3				(      5.0 )	// circuit gain

// DC bus voltage conversion
#define RVBUSH_OHM3			( 400000.0 )	// high side split resistor [Ohm]
#define RVBUSL_OHM3			(   4700.0 )	// low side split resistor [Ohm]

// deadtimes to be inserted by MTU
#define DEADTIM_NS3			(   1000 )		// deatimes [ns]

// minimum on time of low arms (one half of), to guarantee good current reading
// this time should guarantee that the lower switch commutates effectively for enough time to
// sample the current for A/D conversion (added to deadtimes, it gives the minimum duty-cycle value)
#define MIN_TON_LOW_NS3		(    300 )		// [ns]

// current conversion delay respect pwm trough
#define CON_DELAY_NS3		(     20 )		// [ns] lesser than MIN_TON_LOW

// voltages
#define VB_NOM_VOL3			(    311 )		// nominal bus voltage [V]

#endif	// ifdef HIV_PS_3

#ifdef LOV_PS_3
/* LOW VOLTAGE POWER STAGE */
#define LEM_ON3

// NOTE: the current is considered positive if going out from the inverter
#ifndef LEM_ON3
#define RSHUNT_OHM3			(     0.001 )	// shunt value [Ohm]
#define RSGAIN3				(    31.0 )		// circuit gain				-> total 0.031
#else	// ifndef LEM_ON3
//#define RSHUNT_OHM3			(0.625 / 20)	// LEM gain HXS 20-NP	-> total 0.03125
#define RSHUNT_OHM3			(0.625 / 50)	// LEM gain HXS 50-NP		-> total 0.0125
#define RSGAIN3				(     1.0 )		// circuit gain if LEM used
#endif	// else ifndef LEM_ON3

// DC bus voltage conversion
#define RVBUSH_OHM3			(  82000.0 )	// high side split resistor [Ohm]
#define RVBUSL_OHM3			(   6200.0 )	// low side split resistor [Ohm]

// deadtimes to be inserted by MTU
#define DEADTIM_NS3			(   1000 )		// deatimes [ns]

// minimum on time of low arms (one half of), to guarantee good current reading
// this time should guarantee that the lower switch commutates effectively for enough time to
// sample the current for A/D conversion (added to deadtimes, it gives the minimum duty-cycle value)
#define MIN_TON_LOW_NS3		(    300 )		// [ns]

// current conversion delay respect pwm trough
#define CON_DELAY_NS3		(     30 )		// [ns] lesser than MIN_TON_LOW

// voltages
#define VB_NOM_VOL3			(     48 )		// nominal bus voltage [V]

#endif	// ifdef LOV_PS_3

#endif	// else ifdef INTERNAL_PS_3


#endif	// ifndef _PWS_EBRX66T_H

// EOF pws_E6132.h
