
/*******************************************************************************
DISCLAIMER

THIS SOFTWARE IS PROVIDED "AS IS" AND BFG ENGINEERING MAKES NO WARRANTIES
REGARDING THIS SOFTWARE, WHETHER EXPRESS, IMPLIED OR STATUTORY, INCLUDING
BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
PURPOSE AND NON-INFRINGEMENT. ALL SUCH WARRANTIES ARE EXPRESSLY DISCLAIMED.

WE (BFG ENGINEERING) DO NOT WARRANT THAT THIS SOFTWARE IS FREE FROM CLAIMS
BY A THIRD PARTY OF COPYRIGHT, PATENT, TRADEMARK, TRADE SECRET OR ANY OTHER
INTELLECTUAL PROPERTY INFRINGIMENT.

TO THE MAXIMUM EXTENT PERMITTED NOT PROHIBITED BY LAW, BFG ENGINEERING
SHALL NOT BE LIABLE FOR ANY DIRECT, INDIRECT, SPECIAL, INCIDENTAL OR
CONSEQUENTIAL DAMAGES FOR ANY REASON RELATED TO THIS SOFTWARE, EVEN IF BFG
ENGINEERING HAS BEEN ADVISED OF THE POSSIBILITY OF SUCH DAMAGES.
PARTICULARLY, UNDER NO CIRCUMSTANCES ARE WE LIABLE FOR ANY OF THE FOLLOWING:
- THIRD PARTY CLAIMS AGAINST YOU FOR LOSSES OR DAMAGES;
- LOSS OF, OR DAMAGE TO YOUR RECORDS OR DATA; OR
- ECONOMIC CONSEQUENTIAL DAMAGES (INCLUDING LOST PROFITS OR SAVINGS) OR
  INCIDENTAL DAMAGES, EVEN IF WE ARE INFORMED OF THEIR POSSIBILITY.

BFG ENGINEERING DOES NOT WARRANT UNINTERRUPTED OR ERROR_FREE OPERATION OF
THIS SOFTWARE.
BFG ENGINEERING HAS NO OBLIGATION TO PROVIDE SERVICE, DEFECT CORRECTION OR
ANY MANTEINANCE OF THIS SOFTWARE; OR TO SUPPLY ANY UPDATES OR ENHANCEMENTS
EVEN IF SUCH ARE, OR LATER BECOME, AVAILABLE.

IF YOU DOWNLOAD OR USE THIS SOFTWARE YOU AGREE TO THESE TERMS, AND DO IT AT
YOUR OWN RISK.
*******************************************************************************/

/*******************************************************************************
File:		motorcontrol.c
Project:	YRotateItRX66T
Revision:	1.0
Date:		2019-04-04 (YYYY-MM-DD)
Author:		Andrea Ghirardello
Contents:	Motor control algorithm
*******************************************************************************/

#define _MOTORCONTROL_C		// insert define BEFORE including header files

#include "globdef.h"
#include "ges_eqp.h"
#include "userif.h"
#include "motorcontrol.h"
#include ".\Library\mcrplibf.h"
#ifdef CPI_AUT
#include ".\Library\PI_tun.h"
#endif	// ifdef CPI_AUT
#ifdef	MOT_IDENT
#include ".\Library\mot_ident.h"
#endif	// ifdef MOT_IDENT

// flags
#define	COM1_ON			( 0 != flgx1.bit.b0 )
#define	ALRM1_ON		( 0 != flgx1.bit.b1 )
#define	FREE12			( 0 != flgx1.bit.b2 )
#define	RAMPLIM1		( 0 != flgx1.bit.b3 )
#define	DECEL1			( 0 != flgx1.bit.b4 )
#define	FREE15			( 0 != flgx1.bit.b5 )
#define	STOPPED1		( 0 != flgx1.bit.b6 )
#define	STARTED1		( 0 != flgx1.bit.b7 )
#define	NOT_COM1_ON		( 0 == flgx1.bit.b0 )
#define	NOT_ALRM1_ON	( 0 == flgx1.bit.b1 )
#define	NOT_FREE12		( 0 == flgx1.bit.b2 )
#define	NOT_RAMPLIM1	( 0 == flgx1.bit.b3 )
#define	NOT_DECEL1		( 0 == flgx1.bit.b4 )
#define	NOT_FREE15		( 0 == flgx1.bit.b5 )
#define	NOT_STOPPED1	( 0 == flgx1.bit.b6 )
#define	NOT_STARTED1	( 0 == flgx1.bit.b7 )
#define	SET_COM1_ON		{ flgx1.bit.b0 = 1; }
#define	SET_ALRM1_ON	{ flgx1.bit.b1 = 1; }
#define	SET_FREE12		{ flgx1.bit.b2 = 1; }
#define	SET_RAMPLIM1	{ flgx1.bit.b3 = 1; }
#define	SET_DECEL1		{ flgx1.bit.b4 = 1; }
#define	SET_FREE15		{ flgx1.bit.b5 = 1; }
#define	SET_STOPPED1	{ flgx1.bit.b6 = 1; }
#define	SET_STARTED1	{ flgx1.bit.b7 = 1; }
#define	RES_COM1_ON		{ flgx1.bit.b0 = 0; }
#define	RES_ALRM1_ON	{ flgx1.bit.b1 = 0; }
#define	RES_FREE12		{ flgx1.bit.b2 = 0; }
#define	RES_RAMPLIM1	{ flgx1.bit.b3 = 0; }
#define	RES_DECEL1		{ flgx1.bit.b4 = 0; }
#define	RES_FREE15		{ flgx1.bit.b5 = 0; }
#define	RES_STOPPED1	{ flgx1.bit.b6 = 0; }
#define	RES_STARTED1	{ flgx1.bit.b7 = 0; }

#define	COM2_ON			( 0 != flgx2.bit.b0 )
#define	ALRM2_ON		( 0 != flgx2.bit.b1 )
#define	FREE22			( 0 != flgx2.bit.b2 )
#define	RAMPLIM2		( 0 != flgx2.bit.b3 )
#define	DECEL2			( 0 != flgx2.bit.b4 )
#define	FREE25			( 0 != flgx2.bit.b5 )
#define	STOPPED2		( 0 != flgx2.bit.b6 )
#define	STARTED2		( 0 != flgx2.bit.b7 )
#define	NOT_COM2_ON		( 0 == flgx2.bit.b0 )
#define	NOT_ALRM2_ON	( 0 == flgx2.bit.b1 )
#define	NOT_FREE22		( 0 == flgx2.bit.b2 )
#define	NOT_RAMPLIM2	( 0 == flgx2.bit.b3 )
#define	NOT_DECEL2		( 0 == flgx2.bit.b4 )
#define	NOT_FREE25		( 0 == flgx2.bit.b5 )
#define	NOT_STOPPED2	( 0 == flgx2.bit.b6 )
#define	NOT_STARTED2	( 0 == flgx2.bit.b7 )
#define	SET_COM2_ON		{ flgx2.bit.b0 = 1; }
#define	SET_ALRM2_ON	{ flgx2.bit.b1 = 1; }
#define	SET_FREE22		{ flgx2.bit.b2 = 1; }
#define	SET_RAMPLIM2	{ flgx2.bit.b3 = 1; }
#define	SET_DECEL2		{ flgx2.bit.b4 = 1; }
#define	SET_FREE25		{ flgx2.bit.b5 = 1; }
#define	SET_STOPPED2	{ flgx2.bit.b6 = 1; }
#define	SET_STARTED2	{ flgx2.bit.b7 = 1; }
#define	RES_COM2_ON		{ flgx2.bit.b0 = 0; }
#define	RES_ALRM2_ON	{ flgx2.bit.b1 = 0; }
#define	RES_FREE22		{ flgx2.bit.b2 = 0; }
#define	RES_RAMPLIM2	{ flgx2.bit.b3 = 0; }
#define	RES_DECEL2		{ flgx2.bit.b4 = 0; }
#define	RES_FREE25		{ flgx2.bit.b5 = 0; }
#define	RES_STOPPED2	{ flgx2.bit.b6 = 0; }
#define	RES_STARTED2	{ flgx2.bit.b7 = 0; }

#define	COM3_ON			( 0 != flgx3.bit.b0 )
#define	ALRM3_ON		( 0 != flgx3.bit.b1 )
#define	FREE32			( 0 != flgx3.bit.b2 )
#define	RAMPLIM3		( 0 != flgx3.bit.b3 )
#define	DECEL3			( 0 != flgx3.bit.b4 )
#define	FREE35			( 0 != flgx3.bit.b5 )
#define	STOPPED3		( 0 != flgx3.bit.b6 )
#define	STARTED3		( 0 != flgx3.bit.b7 )
#define	NOT_COM3_ON		( 0 == flgx3.bit.b0 )
#define	NOT_ALRM3_ON	( 0 == flgx3.bit.b1 )
#define	NOT_FREE32		( 0 == flgx3.bit.b2 )
#define	NOT_RAMPLIM3	( 0 == flgx3.bit.b3 )
#define	NOT_DECEL3		( 0 == flgx3.bit.b4 )
#define	NOT_FREE35		( 0 == flgx3.bit.b5 )
#define	NOT_STOPPED3	( 0 == flgx3.bit.b6 )
#define	NOT_STARTED3	( 0 == flgx3.bit.b7 )
#define	SET_COM3_ON		{ flgx3.bit.b0 = 1; }
#define	SET_ALRM3_ON	{ flgx3.bit.b1 = 1; }
#define	SET_FREE32		{ flgx3.bit.b2 = 1; }
#define	SET_RAMPLIM3	{ flgx3.bit.b3 = 1; }
#define	SET_DECEL3		{ flgx3.bit.b4 = 1; }
#define	SET_FREE35		{ flgx3.bit.b5 = 1; }
#define	SET_STOPPED3	{ flgx3.bit.b6 = 1; }
#define	SET_STARTED3	{ flgx3.bit.b7 = 1; }
#define	RES_COM3_ON		{ flgx3.bit.b0 = 0; }
#define	RES_ALRM3_ON	{ flgx3.bit.b1 = 0; }
#define	RES_FREE32		{ flgx3.bit.b2 = 0; }
#define	RES_RAMPLIM3	{ flgx3.bit.b3 = 0; }
#define	RES_DECEL3		{ flgx3.bit.b4 = 0; }
#define	RES_FREE35		{ flgx3.bit.b5 = 0; }
#define	RES_STOPPED3	{ flgx3.bit.b6 = 0; }
#define	RES_STARTED3	{ flgx3.bit.b7 = 0; }

// internal filters (main interrupt) time constants	[sec]
#define VISU_KT			( 0.3f )	// visualization filters
#define	VB_KT_FAST		( 0.002f )	// bus voltage filter fast
#define	VB_KT_SLOW		( 0.2f )	// bus voltage filter slow
#define	OMR_KT			( 0.05f )	// speed reference filter
#define	OFF_KT			( 0.5f )	// A/D offsets filters
#define	TEM_KT			( 0.5f )	// temperature filters
#define POT_KT			( 0.2f )	// potenziometer filter

// speed ramp state machine
#define STOP_0			( 0 )
#define STOP_W			( 1 )
#define START_P			( 2 )
#define START_N			( 3 )
#define GO_P			( 4 )
#define GO_N			( 5 )

// alarm counter
#define MAX_ALL_CNT	(   500 )		// 5sec

// internal variables
byte_t
	flgx1,				// flags
	flgx2,				// flags
	flgx3,				// flags
	flgy;				// flags

uint16_t
	cnt_int,			// counter for main loop synchronization
	ramp1_status,		// speed ramp state machine status memory
	ramp2_status,		// speed ramp state machine status memory
	ramp3_status,		// speed ramp state machine status memory
	all1_cnt,			// alarm counter motor 1
	all2_cnt,			// alarm counter motor 2
	all3_cnt;			// alarm counter motor 3

int16_t
	trip1_cnt,			// counter for trip alarm
	duty1_u,			// u phase duty cycle
	duty1_v,			// v phase duty cycle
	duty1_w,			// w phase duty cycle
	iu1_ad,				// iu A/D conversion value
	iv1_ad,				// iv A/D conversion value
	iw1_ad,				// iw A/D conversion value
	vb1_ad;				// bus voltage A/D conversion value

int16_t
	trip2_cnt,			// counter for trip alarm
	duty2_u,			// u phase duty cycle
	duty2_v,			// v phase duty cycle
	duty2_w,			// w phase duty cycle
	iu2_ad,				// iu A/D conversion value
	iv2_ad,				// iv A/D conversion value
	iw2_ad,				// iw A/D conversion value
	vb2_ad,				// bus voltage A/D conversion value
	te2_ad;				// temperature A/D conversion value

int16_t
	trip3_cnt,			// counter for trip alarm
	duty3_u,			// u phase duty cycle
	duty3_v,			// v phase duty cycle
	duty3_w,			// w phase duty cycle
	iu3_ad,				// iu A/D conversion value
	iv3_ad,				// iv A/D conversion value
	iw3_ad,				// iw A/D conversion value
	vb3_ad,				// bus voltage A/D conversion value
	te3_ad,				// temperature A/D conversion value
	pot_ad;				// potenziometer A/D conversion value

int32_t
	startup_cnt1,		// startup counter
	startup_cnt2,		// startup counter
	startup_cnt3;		// startup counter

float32_t
	ref1,				// reference motor 1
	ium1_off,			// IU analog channel offset
	ivm1_off,			// IV analog channel offset
	iwm1_off,			// IW analog channel offset
	r_sta1,				// stator resistance						[Ohm]
	l_sq1,				// q synchronous inductance					[Hen]
	pm_fl1,				// permanent magnets flux amplitude			[Web]
	fb_gain1,			// flux amplitude feedback gain
	c_poli1,			// number of polar couples
	krpmocp1,			// conversion constant between mechanical speed and electrical speed
	ukrpmocp1,			// 1/krpmocp
	i_start1,			// startup current (peak)					[Amp]
	sup_tim1,			// startup acceleration time (eeprom copy)	[sec]
	delta_om1,			// speed variation (during startup)
	is_rup1,			// startup current increasing rate
	is_rdw1,			// startup current decreasing rate
	vbus1,				// bus voltage								[Volt]
	vbusf1,				// bus voltage (filtered)					[Volt]
	vbus_minf1,			// filtered available bus voltage (min val)	[Volt]
	vfmax1,				// max phase voltage (star)					[Volt]
	//vdmax1,				// maximum d voltage					[Volt]
	//vqmax1,				// maximum q voltage					[Volt]
	i_max1,				// maximum total current					[Amp]
	iqmax1,				// maximum q current						[Amp]
	vdc1,				// reference d voltage						[Volt]
	vqc1,				// reference q voltage						[Volt]
	vdx1,				// applied d voltage						[Volt]
	vqx1,				// applied q voltage						[Volt]
	vdm1,				// applied d voltage (prev. step)			[Volt]
	vqm1,				// applied q voltage (prev. step)			[Volt]
	vdmf1,				// applied d voltage (filtered)				[Volt]
	vqmf1,				// applied q voltage (filtered)				[Volt]
	vac1,				// reference alpha voltage (star)			[Volt]
	vbc1,				// reference beta voltage (star)			[Volt]
	vax1,				// applied alpha voltage					[Volt]
	vbx1,				// applied beta voltage						[Volt]
	vam1,				// applied alpha voltage (prev. step)		[Volt]
	vbm1,				// applied beta voltage (prev. step)		[Volt]
	vuc1,				// reference u voltage (star)				[Volt]
	vvc1,				// reference v voltage (star)				[Volt]
	vwc1,				// reference w voltage (star)				[Volt]
	vux1,				// applied u voltage (star)					[Volt]
	vvx1,				// applied v voltage (star)					[Volt]
	vwx1,				// applied w voltage (star)					[Volt]
#ifdef FLUXWEAK
	idmax1,				// maximum d current						[Amp]
	vmarg1,				// voltage margin for flux weakening
	intid_rup1,			// id integral variation ramp up in FW
	intid_rdw1,			// id integral variation ramp dw in FW
#endif	// ifdef FLUXWEAK
	ium1,				// u current (measured)						[Amp]
	ivm1,				// v current (measured)						[Amp]
	iwm1,				// w current (measured)						[Amp]
	iam1,				// alpha current (measured)					[Amp]
	ibm1,				// beta current (measured)					[Amp]
	idm1,				// d current (measured)						[Amp]
	iqm1,				// q current (measured)						[Amp]
	idmf1,				// d current (filtered)						[Amp]
	iqmf1,				// q current (filtered)						[Amp]
	itr1,				// total current ref (used in startup)		[Amp]
	idr1,				// d current reference
	iqr1,				// q current reference
	iar1,				// alpha current reference
	ibr1,				// beta current reference
	idint1,				// d current error integral value
	iqint1,				// q current error integral value
	iaint1,				// a current error integral value
	ibint1,				// b current error integral value
	idrvar1,			// d current reference
	errint1,			// speed error integral memory
	kp_cur1,			// current PI proportional gain [Ohm]
	ki_cur1,			// current PI integral gain (internal - discrete time) [Ohm]
	kp_vel1,			// speed PI proportional gain [Ampere*sec/rad]
	ki_vel1,			// speed PI integral gain (internal - discrete time) [Ampere*sec/rad]
	freq1,				// electrical frequency [Hz/10]
	mec_rpm1,			// mechanical speed [rpm]
	rpmrif_x1,			// speed reference (ramp input)				[rpm]
	rpmrif_y1,			// speed reference (ramp output)			[rpm]
	r_acc_ep1,			// acceleration ramp (eeprom copy) [rpm/sec]
	r_dec_ep1,			// deceleration ramp (eeprom copy) [rpm/sec]
	r_acc1,				// acceleration ramp [rpm/main_loop_duration]
	r_dec1,				// deceleration ramp [rpm/main_loop_duration]
	rpm_max1,			// maximum speed [rpm]
	rpm_min1,			// minimum speed [rpm]
	min_speed1,			// minimum speed [rad/s]
	max_speed1,			// maximum speed [rad/s]
	min_speed_trip1,	// clamp val for minimum speed (for trip detection) [rad/s]
	max_speed_trip1,	// clamp val for maximum speed (for trip detection) [rad/s]
	min_s_trip1,		// minimum speed (for trip detection) [rad/s]
	max_s_trip1,		// maximum speed (for trip detection) [rad/s]
	Speed_est1,			// estimated speed [rad/s]
	omrif1,				// reference speed [rad/s]
	omrif_abs1,			// |reference speed| [rad/s]
	f_omrif1,			// reference speed (filtered) [rad/s]
	omegae1,			// electrical angular speed [rad/s]
	omf1,				// electrical angular speed (filtered) [rad/s]
	omf_abs1,			// |electrical angular speed (filtered)| [rad/s]
	maxerr1,			// maximum speed error [rad/s]
	//amp_i1,				// current vector amplitude (derived from iam, ibm) [A]
	amp_v1,				// voltage vector amplitude (derived from vam, vbm) [V]
	//arg_i1,				// current vector phase (derived from iam, ibm) [rad]
	//arg_v1,				// voltage vector phase (derived from vam, vbm) [rad]
	f_amp_i1,			// filtered current vector amplitude (derived from idmf, iqmf) [A]
	f_arg_i1,			// filtered current vector phase (derived from idmf, iqmf) [A]
	f_amp_v1,			// filtered voltage vector amplitude (derived from vdmf, vqmf) [V]
	f_arg_v1,			// filtered voltage vector phase (derived from vdmf, vqmf) [V]
	delta_ph1,			// phase variation (during startup) [rad]
	SystemPhase1,		// rotating reference system angular position [rad]
	Phase_est1,			// estimated electrical phase [rad]
	Phase_offset1,		// optional phase offset [rad]
	FluxAmp1,			// flux vector amplitude estimation [Web]
	FluxPhase1,			// flux vector phase first estimation (not compensated) [rad]
	tem1,				// temperature motor 1 [bit]
	temf1;				// filtered temperature motor 1 [bit]

float32_t
	ref2,				// reference motor 2
	ium2_off,			// IU analog channel offset
	ivm2_off,			// IV analog channel offset
	iwm2_off,			// IW analog channel offset
	r_sta2,				// stator resistance						[Ohm]
	l_sq2,				// q synchronous inductance					[Hen]
	pm_fl2,				// permanent magnets flux amplitude			[Web]
	fb_gain2,			// flux amplitude feedback gain
	c_poli2,			// number of polar couples
	krpmocp2,			// conversion constant between mechanical speed and electrical speed
	ukrpmocp2,			// 1/krpmocp
	i_start2,			// startup current (peak)					[Amp]
	sup_tim2,			// startup acceleration time (eeprom copy)	[sec]
	delta_om2,			// speed variation (during startup)
	is_rup2,			// startup current increasing rate
	is_rdw2,			// startup current decreasing rate
	vbus2,				// bus voltage								[Volt]
	vbusf2,				// bus voltage (filtered)					[Volt]
	vbus_minf2,			// filtered available bus voltage (min val)	[Volt]
	vfmax2,				// max phase voltage (star)					[Volt]
	//vdmax2,				// maximum d voltage					[Volt]
	//vqmax2,				// maximum q voltage					[Volt]
	i_max2,				// maximum total current					[Amp]
	iqmax2,				// maximum q current						[Amp]
	vdc2,				// reference d voltage						[Volt]
	vqc2,				// reference q voltage						[Volt]
	vdx2,				// applied d voltage						[Volt]
	vqx2,				// applied q voltage						[Volt]
	vdm2,				// applied d voltage (prev. step)			[Volt]
	vqm2,				// applied q voltage (prev. step)			[Volt]
	vdmf2,				// applied d voltage (filtered)				[Volt]
	vqmf2,				// applied q voltage (filtered)				[Volt]
	vac2,				// reference alpha voltage (star)			[Volt]
	vbc2,				// reference beta voltage (star)			[Volt]
	vax2,				// applied alpha voltage					[Volt]
	vbx2,				// applied beta voltage						[Volt]
	vam2,				// applied alpha voltage (prev. step)		[Volt]
	vbm2,				// applied beta voltage (prev. step)		[Volt]
	vuc2,				// reference u voltage (star)				[Volt]
	vvc2,				// reference v voltage (star)				[Volt]
	vwc2,				// reference w voltage (star)				[Volt]
	vux2,				// applied u voltage (star)					[Volt]
	vvx2,				// applied v voltage (star)					[Volt]
	vwx2,				// applied w voltage (star)					[Volt]
#ifdef FLUXWEAK
	idmax2,				// maximum d current						[Amp]
	vmarg2,				// voltage margin for flux weakening
	intid_rup2,			// id integral variation ramp up in FW
	intid_rdw2,			// id integral variation ramp dw in FW
#endif	// ifdef FLUXWEAK
	ium2,				// u current (measured)						[Amp]
	ivm2,				// v current (measured)						[Amp]
	iwm2,				// w current (measured)						[Amp]
	iam2,				// alpha current (measured)					[Amp]
	ibm2,				// beta current (measured)					[Amp]
	idm2,				// d current (measured)						[Amp]
	iqm2,				// q current (measured)						[Amp]
	idmf2,				// d current (filtered)						[Amp]
	iqmf2,				// q current (filtered)						[Amp]
	itr2,				// total current ref (used in startup)		[Amp]
	idr2,				// d current reference
	iqr2,				// q current reference
	iar2,				// alpha current reference
	ibr2,				// beta current reference
	idint2,				// d current error integral value
	iqint2,				// q current error integral value
	iaint2,				// a current error integral value
	ibint2,				// b current error integral value
	idrvar2,			// d current reference
	errint2,			// speed error integral memory
	kp_cur2,			// current PI proportional gain [Ohm]
	ki_cur2,			// current PI integral gain (internal - discrete time) [Ohm]
	kp_vel2,			// speed PI proportional gain [Ampere*sec/rad]
	ki_vel2,			// speed PI integral gain (internal - discrete time) [Ampere*sec/rad]
	freq2,				// electrical frequency [Hz/10]
	mec_rpm2,			// mechanical speed [rpm]
	rpmrif_x2,			// speed reference (ramp input)				[rpm]
	rpmrif_y2,			// speed reference (ramp output)			[rpm]
	r_acc_ep2,			// acceleration ramp (eeprom copy) [rpm/sec]
	r_dec_ep2,			// deceleration ramp (eeprom copy) [rpm/sec]
	r_acc2,				// acceleration ramp [rpm/main_loop_duration]
	r_dec2,				// deceleration ramp [rpm/main_loop_duration]
	rpm_max2,			// maximum speed [rpm]
	rpm_min2,			// minimum speed [rpm]
	min_speed2,			// minimum speed [rad/s]
	max_speed2,			// maximum speed [rad/s]
	min_speed_trip2,	// clamp val for minimum speed (for trip detection) [rad/s]
	max_speed_trip2,	// clamp val for maximum speed (for trip detection) [rad/s]
	min_s_trip2,		// minimum speed (for trip detection) [rad/s]
	max_s_trip2,		// maximum speed (for trip detection) [rad/s]
	Speed_est2,			// estimated speed [rad/s]
	omrif2,				// reference speed [rad/s]
	omrif_abs2,			// |reference speed| [rad/s]
	f_omrif2,			// reference speed (filtered) [rad/s]
	omegae2,			// electrical angular speed [rad/s]
	omf2,				// electrical angular speed (filtered) [rad/s]
	omf_abs2,			// |electrical angular speed (filtered)| [rad/s]
	maxerr2,			// maximum speed error [rad/s]
	//amp_i2,				// current vector amplitude (derived from iam, ibm) [A]
	amp_v2,				// voltage vector amplitude (derived from vam, vbm) [V]
	//arg_i2,				// current vector phase (derived from iam, ibm) [rad]
	//arg_v2,				// voltage vector phase (derived from vam, vbm) [rad]
	f_amp_i2,			// filtered current vector amplitude (derived from idmf, iqmf) [A]
	f_arg_i2,			// filtered current vector phase (derived from idmf, iqmf) [A]
	f_amp_v2,			// filtered voltage vector amplitude (derived from vdmf, vqmf) [V]
	f_arg_v2,			// filtered voltage vector phase (derived from vdmf, vqmf) [V]
	delta_ph2,			// phase variation (during startup) [rad]
	SystemPhase2,		// rotating reference system angular position [rad]
	Phase_est2,			// estimated electrical phase [rad]
	Phase_offset2,		// optional phase offset [rad]
	FluxAmp2,			// flux vector amplitude estimation [Web]
	FluxPhase2,			// flux vector phase first estimation (not compensated) [rad]
	tem2,				// temperature motor 2 [bit]
	temf2;				// filtered temperature motor 2 [bit]

float32_t
	ref3,				// reference motor 3
	ium3_off,			// IU analog channel offset
	ivm3_off,			// IV analog channel offset
	iwm3_off,			// IW analog channel offset
	r_sta3,				// stator resistance						[Ohm]
	l_sq3,				// q synchronous inductance					[Hen]
	pm_fl3,				// permanent magnets flux amplitude			[Web]
	fb_gain3,			// flux amplitude feedback gain
	c_poli3,			// number of polar couples
	krpmocp3,			// conversion constant between mechanical speed and electrical speed
	ukrpmocp3,			// 1/krpmocp
	i_start3,			// startup current (peak)					[Amp]
	sup_tim3,			// startup acceleration time (eeprom copy)	[sec]
	delta_om3,			// speed variation (during startup)
	is_rup3,			// startup current increasing rate
	is_rdw3,			// startup current decreasing rate
	vbus3,				// bus voltage								[Volt]
	vbusf3,				// bus voltage (filtered)					[Volt]
	vbus_minf3,			// filtered available bus voltage (min val)	[Volt]
	vfmax3,				// max phase voltage (star)					[Volt]
	//vdmax3,				// maximum d voltage					[Volt]
	//vqmax3,				// maximum q voltage					[Volt]
	i_max3,				// maximum total current					[Amp]
	iqmax3,				// maximum q current						[Amp]
	vdc3,				// reference d voltage						[Volt]
	vqc3,				// reference q voltage						[Volt]
	vdx3,				// applied d voltage						[Volt]
	vqx3,				// applied q voltage						[Volt]
	vdm3,				// applied d voltage (prev. step)			[Volt]
	vqm3,				// applied q voltage (prev. step)			[Volt]
	vdmf3,				// applied d voltage (filtered)				[Volt]
	vqmf3,				// applied q voltage (filtered)				[Volt]
	vac3,				// reference alpha voltage (star)			[Volt]
	vbc3,				// reference beta voltage (star)			[Volt]
	vax3,				// applied alpha voltage					[Volt]
	vbx3,				// applied beta voltage						[Volt]
	vam3,				// applied alpha voltage (prev. step)		[Volt]
	vbm3,				// applied beta voltage (prev. step)		[Volt]
	vuc3,				// reference u voltage (star)				[Volt]
	vvc3,				// reference v voltage (star)				[Volt]
	vwc3,				// reference w voltage (star)				[Volt]
	vux3,				// applied u voltage (star)					[Volt]
	vvx3,				// applied v voltage (star)					[Volt]
	vwx3,				// applied w voltage (star)					[Volt]
#ifdef FLUXWEAK
	idmax3,				// maximum d current						[Amp]
	vmarg3,				// voltage margin for flux weakening
	intid_rup3,			// id integral variation ramp up in FW
	intid_rdw3,			// id integral variation ramp dw in FW
#endif	// ifdef FLUXWEAK
	ium3,				// u current (measured)						[Amp]
	ivm3,				// v current (measured)						[Amp]
	iwm3,				// w current (measured)						[Amp]
	iam3,				// alpha current (measured)					[Amp]
	ibm3,				// beta current (measured)					[Amp]
	idm3,				// d current (measured)						[Amp]
	iqm3,				// q current (measured)						[Amp]
	idmf3,				// d current (filtered)						[Amp]
	iqmf3,				// q current (filtered)						[Amp]
	itr3,				// total current ref (used in startup)		[Amp]
	idr3,				// d current reference
	iqr3,				// q current reference
	iar3,				// alpha current reference
	ibr3,				// beta current reference
	idint3,				// d current error integral value
	iqint3,				// q current error integral value
	iaint3,				// a current error integral value
	ibint3,				// b current error integral value
	idrvar3,			// d current reference
	errint3,			// speed error integral memory
	kp_cur3,			// current PI proportional gain [Ohm]
	ki_cur3,			// current PI integral gain (internal - discrete time) [Ohm]
	kp_vel3,			// speed PI proportional gain [Ampere*sec/rad]
	ki_vel3,			// speed PI integral gain (internal - discrete time) [Ampere*sec/rad]
	freq3,				// electrical frequency [Hz/10]
	mec_rpm3,			// mechanical speed [rpm]
	rpmrif_x3,			// speed reference (ramp input)				[rpm]
	rpmrif_y3,			// speed reference (ramp output)			[rpm]
	r_acc_ep3,			// acceleration ramp (eeprom copy) [rpm/sec]
	r_dec_ep3,			// deceleration ramp (eeprom copy) [rpm/sec]
	r_acc3,				// acceleration ramp [rpm/main_loop_duration]
	r_dec3,				// deceleration ramp [rpm/main_loop_duration]
	rpm_max3,			// maximum speed [rpm]
	rpm_min3,			// minimum speed [rpm]
	min_speed3,			// minimum speed [rad/s]
	max_speed3,			// maximum speed [rad/s]
	min_speed_trip3,	// clamp val for minimum speed (for trip detection) [rad/s]
	max_speed_trip3,	// clamp val for maximum speed (for trip detection) [rad/s]
	min_s_trip3,		// minimum speed (for trip detection) [rad/s]
	max_s_trip3,		// maximum speed (for trip detection) [rad/s]
	Speed_est3,			// estimated speed [rad/s]
	omrif3,				// reference speed [rad/s]
	omrif_abs3,			// |reference speed| [rad/s]
	f_omrif3,			// reference speed (filtered) [rad/s]
	omegae3,			// electrical angular speed [rad/s]
	omf3,				// electrical angular speed (filtered) [rad/s]
	omf_abs3,			// |electrical angular speed (filtered)| [rad/s]
	maxerr3,			// maximum speed error [rad/s]
	//amp_i3,				// current vector amplitude (derived from iam, ibm) [A]
	amp_v3,				// voltage vector amplitude (derived from vam, vbm) [V]
	//arg_i3,				// current vector phase (derived from iam, ibm) [rad]
	//arg_v3,				// voltage vector phase (derived from vam, vbm) [rad]
	f_amp_i3,			// filtered current vector amplitude (derived from idmf, iqmf) [A]
	f_arg_i3,			// filtered current vector phase (derived from idmf, iqmf) [A]
	f_amp_v3,			// filtered voltage vector amplitude (derived from vdmf, vqmf) [V]
	f_arg_v3,			// filtered voltage vector phase (derived from vdmf, vqmf) [V]
	delta_ph3,			// phase variation (during startup) [rad]
	SystemPhase3,		// rotating reference system angular position [rad]
	Phase_est3,			// estimated electrical phase [rad]
	Phase_offset3,		// optional phase offset [rad]
	FluxAmp3,			// flux vector amplitude estimation [Web]
	FluxPhase3,			// flux vector phase first estimation (not compensated) [rad]
	tem3,				// temperature motor 3 [bit]
	temf3,				// filtered temperature motor 3 [bit]
	pot,				// potenziometer [bit]
	potf;				// filtered potenziometer [bit]

// variables involved in sampling frequency adaptation
float32_t
	//pwm_per_s,			// true pwm period [s]
	pwm_fre_Hz,			// true pwm frequency [Hz]
	sam_per_s,			// true sampling period [s]
	sam_per_ms,			// true sampling period [ms]
	sam_fre_Hz,			// true sampling frequency [Hz]
	sam_fre_kHz,		// true sampling frequency [kHz]
	mloop_per_s,		// true main loop period [s]
	mloop_fre_Hz,		// true main loop frequency [Hz]
	comptime,			// phase compensation time
	uhalfper1,			// 1/halfper
	uhalfper2,			// 1/halfper
	uhalfper3,			// 1/halfper
	k_vout1,			// keeps into account modulation voltage losses
	k_vout2,			// keeps into account modulation voltage losses
	k_vout3,			// keeps into account modulation voltage losses
	visu_ukt,			// 1.0 / (1.0 + (VISU_KT / SAM_PER_S))
	vb_ukt_fast,		// 1.0 / (1.0 + (VB_KT_FAST / SAM_PER_S))
	vb_ukt_slow,		// 1.0 / (1.0 + (VB_KT_SLOW / SAM_PER_S))
	omr_ukt,			// 1.0 / (1.0 + (OMR_KT / SAM_PER_S))
	off_ukt,			// 1.0 / (1.0 + (OFF_KT / SAM_PER_S))
	tem_ukt,			// 1.0 / (1.0 + (TEM_KT / SAM_PER_S))
	pot_ukt;			// 1.0 / (1.0 + (POT_KT / SAM_PER_S))

uint16_t
	num_int,			// number of control interrupts for each main loop
	fre_ratio,			// ratio between pwm frequency and sampling frequency
	int_skip,			// interrupt skipping register value
	pwm_per_int,		// pwm period in MTU timer ticks
	pwm_halfper_int,	// half pwm period in MTU timer ticks
	pwm_hper_twoth_int,// (2/3) of half pwm period in MTU timer ticks
	sam_per_int,		// sampling period in MTU timer ticks
	halfper1,			// half pwm period in MTU timer ticks
	halfperdead1,		// half pwm period plus deadtimes in MTU timer ticks
	centre_pos1,		// pwm centre position in MTU timer ticks
	delmed1,			// maximum delta between maximum duty cycle and medium one
	delmax1,			// maximum delta between maximum duty cycle and minimum one
	halfper2,			// half pwm period in MTU timer ticks
	halfperdead2,		// half pwm period plus deadtimes in MTU timer ticks
	centre_pos2,		// pwm centre position in MTU timer ticks
	delmed2,			// maximum delta between maximum duty cycle and medium one
	delmax2,			// maximum delta between maximum duty cycle and minimum one
	halfper3,			// half pwm period in MTU timer ticks
	centre_pos3,		// pwm centre position in MTU timer ticks
	delmed3,			// maximum delta between maximum duty cycle and medium one
	delmax3;			// maximum delta between maximum duty cycle and minimum one
// end of variables involved in sampling frequency adjustment

#ifdef CPI_TUN
// current PI tuning
uint16_t
	pit_s,				// counter in tuning state machine
	pit_c;				// counter in tuning state machine
float32_t
	ratio,				// ratio between maximum current and current step amplitude
	cur_ampf;			// filtered measured current amplitude
#endif	// ifdef CPI_TUN

#ifdef CPI_AUT
// automatic current PI tuning
#define I_PIT_RATIO		( 0.8f )	// 80% of i_max
#define R_UP			( 0 )
#define R_MS			( 1 )
#define R_DW			( 2 )
#define R_ST			( 3 )
#define R_EN			( 4 )
float32_t
	v_req;				// required voltage
uint16_t
	pitun_status;		// state machine status
#endif	// ifdef CPI_AUT

// motor parameters identification
#ifdef MOT_IDENT
#define IDENT_SPEED_HZ	( 20.0f )
#define X_TIM1			((int32_t)(ID_TIM1_MS * sam_fre_kHz))	// current rising + alignment + stabilization
#define X_TIM2			((int32_t)(ID_TIM2_MS * sam_fre_kHz))	// first measurement step
#define X_TIM3			((int32_t)(ID_TIM3_MS * sam_fre_kHz))	// current falling + stabilization
#define X_TIM4			((int32_t)(ID_TIM4_MS * sam_fre_kHz))	// second measurement step
#define X_TIM5			((int32_t)(ID_TIM5_MS * sam_fre_kHz))	// speed rising + stabilization
#define X_TIM6			((int32_t)(ID_TIM6_MS * sam_fre_kHz))	// third measurement step
#define X_TIM7			((int32_t)(ID_TIM7_MS * sam_fre_kHz))	// current falling + stabilization
#define X_TIM8			((int32_t)(ID_TIM8_MS * sam_fre_kHz))	// fourth measurement step
#define X_TIM9			((int32_t)(ID_TIM9_MS * sam_fre_kHz))	// final wait
#define INI_IDENT		{x_cnt = 0; MC_Ident_IniVar(sam_fre_Hz);}
#define IDENT_ENDED		(X_TIM9 < x_cnt)
int32_t
	x_cnt;				// identification synchronization counter
float32_t
	iden_rs,			// identification stator resistance
	iden_ls,			// identification synchronous inductance
	iden_fl,			// identification permanent magnets flux
	iden_om,			// identification speed
	iden_or,			// identification speed ramp
	ial_1,				// identification current 1
	ial_2,				// identification current 2
	ial_3,				// identification current 3
	ial_r;				// identification current ramp
#endif	// ifdef MOT_IDENT

// oscilloscope window in GUI
#ifdef OSC_WIN
float32_t
	imax1000,			// 1000 / i_max, for normalization
	phmem;				// angular position memory
int16_t
	sample,				// measurement sample
	selmem,				// variable selection memory
	bcntm,				// counter memory
	bcnt0,				// counter
	bcnt1;				// counter
#endif	// ifdef OSC_WIN

#ifdef MACRO_DEBUG
float32_t
	p_mtu_fre_hz,		// MTU frequency in Hz
	p_deadtim,			// deadtimes
	p_min_ton_low,		// minimum on time of lower arms
	p_con_delay,		// conversion delay
	p_kfo,				// Omega[rad/sec]=KFO*Freq[Hertz]
	p_kof,				// Freq[Hertz]=KOF*Omega[rad/sec]
	p_krpmo,			// Omega[rad/sec]=KRPMO*velocita[rpm]
	p_korpm,			// speed[rpm]=KORPM*Omega[rad/sec]
	p_kadi,				// current A/D conversion constant
	p_kadv;				// voltage A/D conversion constant
void macro_debug(void)
{
	p_mtu_fre_hz = MTU_FRE_HZ;
	p_deadtim = DEADTIM1;
	p_min_ton_low = MIN_TON_LOW1;
	p_con_delay = CON_DELAY1;
	p_kfo = KFO;
	p_kof = KOF;
	p_krpmo = KRPMO;
	p_korpm = KORPM;
	p_kadi = KADI1;
	p_kadv = KADV1;
}
#endif	// ifdef MACRO_DEBUG

// clock control function
/*******************************************************************************
Function:		MC_CheckClock
Description:	generation of an interrupt used to check the clock
Input:			nothing
Output:			nothing
*******************************************************************************/
void MC_CheckClock(void)
{
	WAKEUP_CMT0
	DELAY1MS(10)
	CMT.CMSTR0.BIT.STR0 = 0;	// stop the timer
	CMT0.CMCOR = 1250;			// -> interrupt every 10000 ticks of PCLKB
	CMT0.CMCR.BIT.CKS = 0;		// PCLCB/8
	CMT0.CMCR.BIT.CMIE = 1;		// PCLCB/8
	IPR(CMT0, CMI0) = MC_INT_P;	// interrupt priority
	IR(CMT0, CMI0) = 0;			// reset interrupt request
	IEN(CMT0, CMI0) = 1;		// enable interrupt
	CMT.CMSTR0.BIT.STR0 = 1;	// start the timer
	while(1);					// enters in an infinite loop
}

/*******************************************************************************
Function:		MC_ClockInt
Description:	interrupt management routine
Input:			nothing
Output:			nothing
*******************************************************************************/
void MC_ClockInt(void)
{
	IR(CMT0, CMI0) = 0;			// reset interrupt request
	if(LD1_OFF)
	{
		SET_LD1
	}
	else
	{
		RES_LD1
	}
	return;
}
// end of clock control function

// sampling frequency related constants calculation
/*******************************************************************************
Function:		MC_SetPwmConst
Description:	calculation of constants related to sampling (and pwm) freq.
Input:			nothing
Output:			nothing
Modifies:		many global variables related to sampling frequency and used as
				constants
*******************************************************************************/
void MC_SetPwmConst(void)
{
	// getting parameters values
	sam_fre_Hz = SAM_FRE;
	fre_ratio = F_RATIO;

	// interrupt skipping
	if(1 == fre_ratio)
	{
		int_skip = 0;
	}
	else
	{
		int_skip = fre_ratio + 7;	// 8 (ena bit = 1) + (fre_ratio - 1) (number of skipped int)
	}

	// pwm and sampling period calc in internal timer ticks
	pwm_fre_Hz = fre_ratio * sam_fre_Hz;
	pwm_halfper_int = ((uint16_t)((0.5f * MTU_FRE_HZ) / pwm_fre_Hz));	// half pwm period in MTU ticks (int)
	pwm_hper_twoth_int = (uint16_t)(2 * pwm_halfper_int / 3);		// for synchronization
	pwm_per_int = pwm_halfper_int << 1;								// pwm period in MTU ticks (int)
	sam_per_int = fre_ratio * pwm_per_int;							// sampling period in MTU ticks (int)

	// pwm and sampling freq. re-calculation
	pwm_fre_Hz = ((float32_t)(MTU_FRE_HZ / pwm_per_int));			// true pwm frequency in Hz (float)
	//pwm_per_s = ((float32_t)(pwm_per_int / MTU_FRE_HZ));			// true pwm period in sec (float)
	sam_fre_Hz = ((float32_t)(MTU_FRE_HZ / sam_per_int));			// true sampling frequency in Hz (float)
	sam_per_s = ((float32_t)(sam_per_int / MTU_FRE_HZ));			// true sampling period in sec (float)

	// main loop timing
	num_int = ((uint16_t)(sam_fre_Hz / MLOOP_FRE_HZ));				// number of sampling periods in one main loop (int)
	//mloop_fre_Hz = sam_fre_Hz / num_int;							// true main loop frequency in Hz (float)
	mloop_per_s = num_int / sam_fre_Hz;								// true main loop period in sec (float)

	// control parameters
	comptime = K_COMPPH * sam_per_s;								// phase compensation time

	// other useful quantities
	sam_fre_kHz = sam_fre_Hz * 0.001f;								// true sampling frequency in kHz (float)
	sam_per_ms = 1000.0f * sam_per_s;								// true sampling period in ms (float)

	// pwm management parameters
	halfper1 = pwm_halfper_int;
	uhalfper1 = 1.0f / halfper1;
	halfperdead1 = halfper1 + DEADTIM1;								// half pwm period plus deadtimes in MTU ticks (int)
	delmax1 = halfper1 - DEADTIM1;									// max delta between max duty and min duty in MTU ticks (int)
	delmed1 = halfper1 - DMIN1;										// max delta between max duty and med duty in MTU ticks (int)
	k_vout1 = delmax1 * uhalfper1 * ((float32_t) SQRT3D3 * K_OVERMOD1);	// given VB, the max star vector is VB/SQRT3 (without hexagonal saturation)
	centre_pos1 = halfper1 - (((uint16_t)(CEN_POS1_K * delmax1)) >> 1);	// desired star centre position

	// pwm management parameters
	halfper2 = pwm_halfper_int;
	uhalfper2 = 1.0f / halfper2;
	halfperdead2 = halfper2 + DEADTIM2;								// half pwm period plus deadtimes in MTU ticks (int)
	delmax2 = halfper2 - DEADTIM2;									// max delta between max duty and min duty in MTU ticks (int)
	delmed2 = halfper2 - DMIN2;										// max delta between max duty and med duty in MTU ticks (int)
	k_vout2 = delmax2 * uhalfper2 * ((float32_t) SQRT3D3 * K_OVERMOD2);	// given VB, the max star vector is VB/SQRT3 (without hexagonal saturation)
	centre_pos2 = halfper2 - (((uint16_t)(CEN_POS2_K * delmax2)) >> 1);	// desired star centre position

	// pwm management parameters
	halfper3 = pwm_halfper_int;
	uhalfper3 = 1.0f / halfper3;
	delmax3 = halfper3 - 1 - DEADTIM3;									// max delta between max duty and min duty in MTU ticks (int)
	delmed3 = halfper3 - 1 - DMIN3;										// max delta between max duty and med duty in MTU ticks (int)
	k_vout3 = delmax3 * uhalfper3 * ((float32_t) SQRT3D3 * K_OVERMOD3);	// given VB, the max star vector is VB/SQRT3 (without hexagonal saturation)
	centre_pos3 = halfper3 - (((uint16_t)(CEN_POS3_K * delmax3)) >> 1);	// desired star centre position

	// filters time constants
	visu_ukt = 1.0f / (1.0f + (((float32_t)VISU_KT) * sam_fre_Hz));
	vb_ukt_fast = 1.0f / (1.0f + (((float32_t)VB_KT_FAST) * sam_fre_Hz));
	vb_ukt_slow = 1.0f / (1.0f + (((float32_t)VB_KT_SLOW) * sam_fre_Hz));
	omr_ukt = 1.0f / (1.0f + (((float32_t)OMR_KT) * sam_fre_Hz));
	off_ukt = 1.0f / (1.0f + (((float32_t)OFF_KT) * sam_fre_Hz));
	tem_ukt = 1.0f / (1.0f + (((float32_t)TEM_KT) * sam_fre_Hz));
	pot_ukt = 1.0f / (1.0f + (((float32_t)POT_KT) * sam_fre_Hz));

	// polar couples related constants
	c_poli1 = C_POLI1;
	krpmocp1 = c_poli1 * KRPMO;
	ukrpmocp1 = ((float32_t)(1.0f / krpmocp1));
	maxerr1 = krpmocp1 * MAXERR1_RPM;
#ifdef RAMP_CL1
	r_marg1 = R_MARG1 * krpmocp1;
#endif	// ifdef RAMP_CL1

	// polar couples related constants
	c_poli2 = C_POLI2;
	krpmocp2 = c_poli2 * KRPMO;
	ukrpmocp2 = ((float32_t)(1.0f / krpmocp2));
	maxerr2 = krpmocp2 * MAXERR2_RPM;
#ifdef RAMP_CL2
	r_marg2 = R_MARG2 * krpmocp2;
#endif	// ifdef RAMP_CL2

	// polar couples related constants
	c_poli3 = C_POLI3;
	krpmocp3 = c_poli3 * KRPMO;
	ukrpmocp3 = ((float32_t)(1.0f / krpmocp3));
	maxerr3 = krpmocp3 * MAXERR3_RPM;
#ifdef RAMP_CL3
	r_marg3 = R_MARG3 * krpmocp3;
#endif	// ifdef RAMP_CL3

}
// end of sampling frequency related constants calculation

/******************************************************************************
Function:		MC_WaitSync
Description:	time synchronization control function
Input:			nothing
Output:			0 if main loop time is elapsed, 1 if not
Modifies:		internal status variable
******************************************************************************/
uint16_t MC_WaitSync(void)
{
	if(0 != cnt_int)
	{
		return(1);
	}
	cnt_int = num_int;
	return(0);
}

// current reading functions
/******************************************************************************
Function:		MC_SetOff1
Description:	S12AD init and current offsets measurement (pseudo diff. PGA)
Input:			nothing
Output:			nothing
Modifies:		current reading offsets, filters init values
******************************************************************************/
void MC_SetOff1(void)
{
	uint32_t u32_ou, u32_ov, u32_ow, u32_vb;//, u32_te;
	uint16_t u16_i;

	// wake up A/D module before accessing registers
	WAKEUP_S12AD
	DELAY1MS(1)

	// pins assignment to the peripheral
	MPC.PWPR.BYTE = 0x00;			// enable writing BIT6
	MPC.PWPR.BYTE = 0x40;			// enable writing MPC registers
	MPC.P43PFS.BYTE = 0x80;			// P43 p087 VB1 AN003
	MPC.P42PFS.BYTE = 0x80;			// P42 p088 IW1 AN002
	MPC.P41PFS.BYTE = 0x80;			// P41 p089 IV1 AN001
	MPC.P40PFS.BYTE = 0x80;			// P40 p090 IU1 AN000
//	MPC.PH0PFS.BYTE = 0x80;			// PH0 p091 TE1 AN007
	MPC.PWPR.BYTE = 0x80;			// disable writing MPC registers

	// sampling times setting (18 states @25ns means 0.45us - minimum is 12 states)
	S12AD.ADSSTR0 = 0x18;			// pin56 P40 IU I AN0
	S12AD.ADSSTR1 = 0x18;			// pin55 P41 IV I AN1
	S12AD.ADSSTR2 = 0x18;			// pin54 P42 IW I AN2
	S12AD.ADSSTR3 = 0x18;			// pin53 P43 VB I AN3

	// AD Control register (reset 0x0000)
	S12AD.ADCSR.WORD = 0x0000;
	//S12AD.ADCSR.BIT.ADST = 0;		// B15		0  -> stopped
	//S12AD.ADCSR.BIT.ADCS = 0;		// B14, B13	00 -> single cycle scan mode
	//S12AD.ADCSR.BIT.ADIE = 0;		// B12		0  -> no int enabled
		// B11, B10                 
	//S12AD.ADCSR.BIT.TRGE = 0;		// B9		0  -> no start trigger enabled
	//S12AD.ADCSR.BIT.EXTRG = 0;	// B8		0  -> no external trigger selected
	//S12AD.ADCSR.BIT.DBLE = 0;		// B7
	//S12AD.ADCSR.BIT.GBADIE = 0;	// B6
		// B5
	//S12AD.ADCSR.BIT.DBLANS = 0;	// B4, .., B0

	// dedicated sample and hold setting
	S12AD.ADSHCR.WORD = 0x0712;		// AD Sample and Hold Circuit Control Register (reset 0x0000)
		// B15, .., B11
	//S12AD.ADSHCR.BIT.SHANS = 7;	// B10, B9, B8	7 -> all the three channels selected
	//S12AD.ADSHCR.BIT.SSTSH = 0x12;// B7, .., B0	18 states @25ns means 0.45us (16 states is the minimum @40MHz)

	// bits number and alignment: default value of ADCER (0) selects 12bit and right alignment
	S12AD.ADCER.WORD = 0x0000;		// AD Control Extended register

	// input path for the selected channels
#ifdef INTERNAL_PS_1
	S12AD.ADPGACR.WORD = 0x0EEE;	// means all the three PGAs enabled
	S12AD.ADPGAGS0.WORD = 0x0555;	// means all the three gains are 3.077
	S12AD.ADPGADCR0.WORD = 0x8000;	// means all the three PGA are in single ended mode
#else	// ifdef INTERNAL_PS_1
	S12AD.ADPGACR.WORD = 0x0111;	// means all the three PGAs disabled
	S12AD.ADPGADCR0.WORD = 0x8000;	// means all the three PGA are in single ended mode
#endif	// else ifdef INTERNAL_PS_1

	// select channels to be converted
	S12AD.ADANSA0.WORD = 0x000F;	// selects channels 0, 1, 2, 3

	// current offsets measurement cycle
	u32_ou = 0;
	u32_ov = 0;
	u32_ow = 0;
	u32_vb = 0;
//	u32_te = 0;
	for (u16_i = 0; 32 > u16_i; u16_i++)
	{
		S12AD_START
		WAIT_S12AD
		u32_ou += AN00_IU1;
		u32_ov += AN01_IV1;
		u32_ow += AN02_IW1;
		u32_vb += AN03_VB1;
//		u32_te += AN07_TE1;
		DELAY1MS(1)
	}
	ium1_off = u32_ou * ((float32_t)(1.0 / 32.0));
	ivm1_off = u32_ov * ((float32_t)(1.0 / 32.0));
	iwm1_off = u32_ow * ((float32_t)(1.0 / 32.0));
	vbus1 =  u32_vb * ((float32_t)(KADV1 / 32.0));	// dc bus voltage in Volt
	vbus_minf1 = vbus1;
	vbusf1 = vbus1;
//	tem1 = u32_te * ((float32_t)(1.0 / 32.0));
//	temf1 = tem1;
}

/******************************************************************************
Function:		MC_SetOff2
Description:	S12AD1 init and current offsets measurement
Input:			nothing
Output:			nothing
Modifies:		current reading offsets, filters init values
******************************************************************************/
void MC_SetOff2(void)
{
	uint32_t u32_ou, u32_ov, u32_ow, u32_vb;//, u32_te;
	uint16_t u16_i;

	// wake up A/D module before accessing registers
	WAKEUP_S12AD1
	DELAY1MS(1)

	// pins assignment to the peripheral
	MPC.PWPR.BYTE = 0x00;			// enable writing BIT6
	MPC.PWPR.BYTE = 0x40;			// enable writing MPC registers
	MPC.P44PFS.BYTE = 0x80;			// P44 p085 IU2 AN100
	MPC.P45PFS.BYTE = 0x80;			// P45 p084 IV2 AN101
	MPC.P46PFS.BYTE = 0x80;			// P46 p083 IW2 AN102
	MPC.P47PFS.BYTE = 0x80;			// P47 p082 VB2 AN103
//	MPC.PH4PFS.BYTE = 0x80;			// PH4 p086 TE2 AN107
	MPC.PWPR.BYTE = 0x80;			// disable writing MPC registers

	// sampling times setting (18 states @25ns means 0.45us - minimum is 12 states)
	S12AD1.ADSSTR0 = 0x18;			// pin56 P40 IU I AN0
	S12AD1.ADSSTR1 = 0x18;			// pin55 P41 IV I AN1
	S12AD1.ADSSTR2 = 0x18;			// pin54 P42 IW I AN2
	S12AD1.ADSSTR3 = 0x18;			// pin53 P43 VB I AN3

	// AD Control register (reset 0x0000)
	S12AD1.ADCSR.WORD = 0x0000;
	//S12AD1.ADCSR.BIT.ADST = 0;	// B15		0  -> stopped
	//S12AD1.ADCSR.BIT.ADCS = 0;	// B14, B13	00 -> single cycle scan mode
	//S12AD1.ADCSR.BIT.ADIE = 0;	// B12		0  -> no int enabled
		// B11, B10                 
	//S12AD1.ADCSR.BIT.TRGE = 0;	// B9		0  -> no start trigger enabled
	//S12AD1.ADCSR.BIT.EXTRG = 0;	// B8		0  -> no external trigger selected
	//S12AD1.ADCSR.BIT.DBLE = 0;	// B7
	//S12AD1.ADCSR.BIT.GBADIE = 0;	// B6
		// B5
	//S12AD1.ADCSR.BIT.DBLANS = 0;	// B4, .., B0

	// dedicated sample and hold setting
	S12AD1.ADSHCR.WORD = 0x0712;	// AD Sample and Hold Circuit Control Register (reset 0x0000)
		// B15, .., B11
	//S12AD1.ADSHCR.BIT.SHANS = 7;	// B10, B9, B8	7 -> all the three channels selected
	//S12AD1.ADSHCR.BIT.SSTSH = 0x12;// B7, .., B0	18 states @25ns means 0.45us (16 states is the minimum @40MHz)

	// bits number and alignment: default value of ADCER (0) selects 12bit and right alignment
	S12AD1.ADCER.WORD = 0x0000;		// AD Control Extended register

	// input path for the selected channels
#ifdef INTERNAL_PS_2
	S12AD1.ADPGACR.WORD = 0x0EEE;	// means all the three PGAs enabled
	S12AD1.ADPGAGS0.WORD = 0x0555;	// means all the three gains are 3.077
	S12AD1.ADPGADCR0.WORD = 0x8000;	// means all the three PGA are in single ended mode
#else	// ifdef INTERNAL_PS_2
	S12AD1.ADPGACR.WORD = 0x0111;	// means all the three PGAs disabled
	S12AD1.ADPGADCR0.WORD = 0x8000;	// means all the three PGA are in single ended mode
#endif	// else ifdef INTERNAL_PS_2

	// select channels to be converted
	S12AD1.ADANSA0.WORD = 0x000F;	// selects channels 0, 1, 2, 3

	// current offsets measurement cycle
	u32_ou = 0;
	u32_ov = 0;
	u32_ow = 0;
	u32_vb = 0;
//	u32_te = 0;
	for (u16_i = 0; 32 > u16_i; u16_i++)
	{
		S12AD1_START
		WAIT_S12AD1
		u32_ou += AN10_IU2;
		u32_ov += AN11_IV2;
		u32_ow += AN12_IW2;
		u32_vb += AN13_VB2;
//		u32_te += AN17_TE2;
		DELAY1MS(1)
	}
	ium2_off = u32_ou * ((float32_t)(1.0 / 32.0));
	ivm2_off = u32_ov * ((float32_t)(1.0 / 32.0));
	iwm2_off = u32_ow * ((float32_t)(1.0 / 32.0));
	vbus2 =  u32_vb * ((float32_t)(KADV2 / 32.0));	// dc bus voltage in Volt
	vbus_minf2 = vbus2;
	vbusf2 = vbus2;
//	tem2 = u32_te * ((float32_t)(1.0 / 32.0));
//	temf2 = tem2;
}

/******************************************************************************
Function:		MC_SetOff3
Description:	S12AD2 init and current offsets measurement
Input:			nothing
Output:			nothing
Modifies:		current reading offsets, filters init values
******************************************************************************/
void MC_SetOff3(void)
{
	uint32_t u32_ou, u32_ov, u32_ow, u32_vb, u32_te, u32_po;
	uint16_t u16_i;

	// wake up A/D module before accessing registers
	WAKEUP_S12AD2
	DELAY1MS(1)

	// pins assignment to the peripheral
	MPC.PWPR.BYTE = 0x00;			// enable writing BIT6
	MPC.PWPR.BYTE = 0x40;			// enable writing MPC registers
	MPC.P52PFS.BYTE = 0x80;			// P52 p081 IU3 AN200
	MPC.P53PFS.BYTE = 0x80;			// P53 p080 IV3 AN201
	MPC.P54PFS.BYTE = 0x80;			// P54 p079 IW3 AN202
	MPC.P55PFS.BYTE = 0x80;			// P55 p078 VB3 AN203
	MPC.P62PFS.BYTE = 0x80;			// P62 p075 TE3 AN208
	MPC.P63PFS.BYTE = 0x80;			// P63 p074 POT AN209
	MPC.PWPR.BYTE = 0x80;			// disable writing MPC registers

	// sampling times setting (18 states @25ns means 0.45us - minimum is 12 states)
	S12AD2.ADSSTR0 = 0x18;			// P52 p081 IU3 AN200
	S12AD2.ADSSTR1 = 0x18;			// P53 p080 IV3 AN201
	S12AD2.ADSSTR2 = 0x18;			// P54 p079 IW3 AN202
	S12AD2.ADSSTR3 = 0x18;			// P55 p078 VB3 AN203
	S12AD2.ADSSTR8 = 0x18;			// P62 p075 TE3 AN208
	S12AD2.ADSSTR9 = 0x18;			// P63 p074 POT AN209

	// AD Control register (reset 0x0000)
	S12AD2.ADCSR.WORD = 0x0000;
	//S12AD2.ADCSR.BIT.ADST = 0;	// B15		0  -> stopped
	//S12AD2.ADCSR.BIT.ADCS = 0;	// B14, B13	00 -> single cycle scan mode
	//S12AD2.ADCSR.BIT.ADIE = 0;	// B12		0  -> no int enabled
		// B11, B10                 
	//S12AD2.ADCSR.BIT.TRGE = 0;	// B9		0  -> no start trigger enabled
	//S12AD2.ADCSR.BIT.EXTRG = 0;	// B8		0  -> no external trigger selected
	//S12AD2.ADCSR.BIT.DBLE = 0;	// B7
	//S12AD2.ADCSR.BIT.GBADIE = 0;	// B6
		// B5
	//S12AD2.ADCSR.BIT.DBLANS = 0;	// B4, .., B0

	// bits number and alignment: default value of ADCER (0) selects 12bit and right alignment
	S12AD2.ADCER.WORD = 0x0000;		// AD Control Extended register

	// select channels to be converted
	S12AD2.ADANSA0.WORD = 0x030F;	// selects channels 0, 1, 2, 3, 8, 9

	// current offsets measurement cycle
	u32_ou = 0;
	u32_ov = 0;
	u32_ow = 0;
	u32_vb = 0;
	u32_te = 0;
	u32_po = 0;
	for (u16_i = 0; 32 > u16_i; u16_i++)
	{
		S12AD2_START
		WAIT_S12AD2
		u32_ou += AN20_IU3;
		u32_ov += AN21_IV3;
		u32_ow += AN22_IW3;
		u32_vb += AN23_VB3;
		u32_te += AN28_TE3;
		u32_po += AN29_POT;
		DELAY1MS(1)
	}
	ium3_off = u32_ou * ((float32_t)(1.0 / 32.0));
	ivm3_off = u32_ov * ((float32_t)(1.0 / 32.0));
	iwm3_off = u32_ow * ((float32_t)(1.0 / 32.0));
	vbus3 =  u32_vb * ((float32_t)(KADV3 / 32.0));	// dc bus voltage in Volt
	vbus_minf3 = vbus3;
	vbusf3 = vbus3;
	tem3 = u32_te * ((float32_t)(1.0 / 32.0));
	temf3 = tem3;
	pot = u32_po * ((float32_t)(1.0 / 32.0));
	potf = pot;
}

/******************************************************************************
Function:		MC_SetOff
Description:	S12AD init and current offsets measurement
Input:			nothing
Output:			nothing
Modifies:		current reading offsets, filters init values
******************************************************************************/
void MC_SetOff(void)
{
	MC_SetOff1();
	MC_SetOff2();
	MC_SetOff3();
}

/******************************************************************************
Function:		MC_ADMan1
Description:	management of triggered A/D conversions
Input:			nothing
Output:			nothing
Modifies:		global variables:
				vbus1, (bus voltage sample)
				ium1, ivm1, iwm1 (current samples in u, v, w frame)
				iam1, ibm1 (current samples in a, b frame)
******************************************************************************/
static void MC_ADMan1(void)
{
	uint16_t	u16_du, u16_dv, u16_dw;

	// converted values sampling
	iu1_ad = AN00_IU1;
	iv1_ad = AN01_IV1;
	iw1_ad = AN02_IW1;
	vb1_ad = AN03_VB1;
	//	te1_ad = AN07_TE1;

	// read currents AD conversion results and phase currents calculation
	if(OUT1_ENABLED)
	{

		// loading the actual duty-cycles values (they're the ones which have been used in
		// the last cycle) on which the A/D conversions are based
		u16_du = REG_U1;
		u16_dv = REG_V1;
		u16_dw = REG_W1;

		// finding duties order and minimum value, calculating current samples based on the two best readings
		// (low compare reg value -> high voltage -> short on time of the low arm -> bad reading)
		if (u16_du >= u16_dv)
		{										// du >= dv
			if (u16_dv >= u16_dw)
			{									// du >= dv >= dw (w is the min -> we choose iu and iv)
				ium1 = KADI1 * (iu1_ad - ium1_off);
				ivm1 = KADI1 * (iv1_ad - ivm1_off);
				iwm1 = -ium1 - ivm1;
			}
			else
			{									// du >= dv, dw > dv (v is the min -> we choose iw and iu)
				iwm1 = KADI1 * (iw1_ad - iwm1_off);
				ium1 = KADI1 * (iu1_ad - ium1_off);
				ivm1 = -iwm1 - ium1;
			}
		}
		else
		{										// dv > du
			if (u16_du >= u16_dw)
			{									// dv > du >= dw (w is the min -> we choose iu and iv)
				ium1 = KADI1 * (iu1_ad - ium1_off);
				ivm1 = KADI1 * (iv1_ad - ivm1_off);
				iwm1 = -ium1 - ivm1;
			}
			else
			{									// dv > du, dw > du (u is the min -> we choose iv and iw)
				ivm1 = KADI1 * (iv1_ad - ivm1_off);
				iwm1 = KADI1 * (iw1_ad - iwm1_off);
				ium1 = -ivm1 - iwm1;
			}
		}

		// alpha, beta currents calc
#ifndef REVERSED1
		McrpLibf_uv_alphabeta(ium1, ivm1, &iam1, &ibm1);
#else	// ifndef REVERSED1
		McrpLibf_uv_alphabeta(ium1, iwm1, &iam1, &ibm1);
#endif	// else ifndef REVERSED1
	}
	else
	{
#ifdef OFF_REFRESH1
		// current offsets refresh
		ium1_off += ((iu1_ad - ium1_off) * off_ukt);
		ivm1_off += ((iv1_ad - ivm1_off) * off_ukt);
		iwm1_off += ((iw1_ad - iwm1_off) * off_ukt);
#endif	// ifdef OFF_REFRESH1
		ium1 = ivm1 = iwm1 = 0.0f;
		iam1 = ibm1 = 0.0f;
	}

	// bus voltage calculation
	vbus1 = KADV1 * vb1_ad;				// dc bus voltage in Volt

	// temperature filter
//	temf1 += (te1_ad - temf1) * tem_ukt;

}	// end of function MC_ADMan1()

/******************************************************************************
Function:		MC_ADMan2
Description:	management of triggered A/D conversions
Input:			nothing
Output:			nothing
Modifies:		global variables:
				vbus2, (bus voltage sample)
				ium2, ivm2, iwm2 (current samples in u, v, w frame)
				iam2, ibm2 (current samples in a, b frame)
******************************************************************************/
static void MC_ADMan2(void)
{
	uint16_t	u16_du, u16_dv, u16_dw;

	// converted values sampling
	iu2_ad = AN10_IU2;
	iv2_ad = AN11_IV2;
	iw2_ad = AN12_IW2;
	vb2_ad = AN13_VB2;
//	te2_ad = AN17_TE2;

	// read currents AD conversion results and phase currents calculation
	if(OUT2_ENABLED)
	{

		// loading the actual duty-cycles values (they're the ones which have been used in
		// the last cycle) on which the A/D conversions are based
		u16_du = REG_U2;
		u16_dv = REG_V2;
		u16_dw = REG_W2;

		// finding duties order and minimum value, calculating current samples based on the two best readings
		// (low compare reg value -> high voltage -> short on time of the low arm -> bad reading)
		if (u16_du >= u16_dv)
		{										// du >= dv
			if (u16_dv >= u16_dw)
			{									// du >= dv >= dw (w is the min -> we choose iu and iv)
				ium2 = KADI2 * (iu2_ad - ium2_off);
				ivm2 = KADI2 * (iv2_ad - ivm2_off);
				iwm2 = -ium2 - ivm2;
			}
			else
			{									// du >= dv, dw > dv (v is the min -> we choose iw and iu)
				iwm2 = KADI2 * (iw2_ad - iwm2_off);
				ium2 = KADI2 * (iu2_ad - ium2_off);
				ivm2 = -iwm2 - ium2;
			}
		}
		else
		{										// dv > du
			if (u16_du >= u16_dw)
			{									// dv > du >= dw (w is the min -> we choose iu and iv)
				ium2 = KADI2 * (iu2_ad - ium2_off);
				ivm2 = KADI2 * (iv2_ad - ivm2_off);
				iwm2 = -ium2 - ivm2;
			}
			else
			{									// dv > du, dw > du (u is the min -> we choose iv and iw)
				ivm2 = KADI2 * (iv2_ad - ivm2_off);
				iwm2 = KADI2 * (iw2_ad - iwm2_off);
				ium2 = -ivm2 - iwm2;
			}
		}

		// alpha, beta currents calc
#ifndef REVERSED2
		McrpLibf_uv_alphabeta(ium2, ivm2, &iam2, &ibm2);
#else	// ifndef REVERSED2
		McrpLibf_uv_alphabeta(ium2, iwm2, &iam2, &ibm2);
#endif	// else ifndef REVERSED2
	}
	else
	{
#ifdef OFF_REFRESH2
		// current offsets refresh
		ium2_off += ((iu2_ad - ium2_off) * off_ukt);
		ivm2_off += ((iv2_ad - ivm2_off) * off_ukt);
		iwm2_off += ((iw2_ad - iwm2_off) * off_ukt);
#endif	// ifdef OFF_REFRESH2
		ium2 = ivm2 = iwm2 = 0.0f;
		iam2 = ibm2 = 0.0f;
	}

	// bus voltage calculation
	vbus2 = KADV2 * vb2_ad;				// dc bus voltage in Volt

	// temperature filter
//	temf2 += (te2_ad - temf2) * tem_ukt;

}	// end of function MC_ADMan2()

/******************************************************************************
Function:		MC_ADMan3
Description:	management of triggered A/D conversions
Input:			nothing
Output:			nothing
Modifies:		global variables:
				vbus3, (bus voltage sample)
				ium3, ivm3, iwm3 (current samples in u, v, w frame)
				iam3, ibm3 (current samples in a, b frame)
******************************************************************************/
static void MC_ADMan3(void)
{
	uint16_t	u16_du, u16_dv, u16_dw;

	// converted values sampling
	iu3_ad = AN20_IU3;
	iv3_ad = AN21_IV3;
	iw3_ad = AN22_IW3;
	vb3_ad = AN23_VB3;
	te3_ad = AN28_TE3;
	pot_ad = AN29_POT;

	// read currents AD conversion results and phase currents calculation
	if(OUT3_ENABLED)
	{

		// loading the actual duty-cycles values (they're the ones which have been used in
		// the last cycle) on which the A/D conversions are based
		u16_du = REG_U3;
		u16_dv = REG_V3;
		u16_dw = REG_W3;

		// finding duties order and minimum value, calculating current samples based on the two best readings
		// (low compare reg value -> high voltage -> short on time of the low arm -> bad reading)
		if (u16_du >= u16_dv)
		{										// du >= dv
			if (u16_dv >= u16_dw)
			{									// du >= dv >= dw (w is the min -> we choose iu and iv)
				ium3 = KADI3 * (iu3_ad - ium3_off);
				ivm3 = KADI3 * (iv3_ad - ivm3_off);
				iwm3 = -ium3 - ivm3;
			}
			else
			{									// du >= dv, dw > dv (v is the min -> we choose iw and iu)
				iwm3 = KADI3 * (iw3_ad - iwm3_off);
				ium3 = KADI3 * (iu3_ad - ium3_off);
				ivm3 = -iwm3 - ium3;
			}
		}
		else
		{										// dv > du
			if (u16_du >= u16_dw)
			{									// dv > du >= dw (w is the min -> we choose iu and iv)
				ium3 = KADI3 * (iu3_ad - ium3_off);
				ivm3 = KADI3 * (iv3_ad - ivm3_off);
				iwm3 = -ium3 - ivm3;
			}
			else
			{									// dv > du, dw > du (u is the min -> we choose iv and iw)
				ivm3 = KADI3 * (iv3_ad - ivm3_off);
				iwm3 = KADI3 * (iw3_ad - iwm3_off);
				ium3 = -ivm3 - iwm3;
			}
		}

		// alpha, beta currents calc
#ifndef REVERSED3
		McrpLibf_uv_alphabeta(ium3, ivm3, &iam3, &ibm3);
#else	// ifndef REVERSED3
		McrpLibf_uv_alphabeta(ium3, iwm3, &iam3, &ibm3);
#endif	// else ifndef REVERSED3
	}
	else
	{
#ifdef OFF_REFRESH3
		// current offsets refresh
		ium3_off += ((iu3_ad - ium3_off) * off_ukt);
		ivm3_off += ((iv3_ad - ivm3_off) * off_ukt);
		iwm3_off += ((iw3_ad - iwm3_off) * off_ukt);
#endif	// ifdef OFF_REFRESH3
		ium3 = ivm3 = iwm3 = 0.0f;
		iam3 = ibm3 = 0.0f;
	}

	// bus voltage calculation
	vbus3 = KADV3 * vb3_ad;				// dc bus voltage in Volt

	// temperature filter
	temf3 += (te3_ad - temf3) * tem_ukt;

	// potentiometer
	potf += (pot_ad - potf) * pot_ukt;

}	// end of function MC_ADMan3()
// end of current reading functions

// PWM management functions
/******************************************************************************
Function:		MC_GesComFlg
Description:	management of COM flags
Input:			nothing
Output:			nothing
******************************************************************************/
void MC_GesComFlg(void)
{
	if(COM1_ON || COM2_ON || COM3_ON)
	{
		SET_COM_ON
	}
	else
	{
		RES_COM_ON
	}
	if(ALRM1_ON || ALRM2_ON || ALRM3_ON)
	{
		SET_ALRM_ON
	}
	else
	{
		RES_ALRM_ON
	}
}

/******************************************************************************
Function:		MC_StopOut1
Description:	disable pwm outputs
Input:			nothing
Output:			nothing
******************************************************************************/
void MC_StopOut1(void)
{
	DISABLE_OUT1			// all outputs disabled (at inactive level)
	RES_COM1_ON
}

/******************************************************************************
Function:		MC_StartOut2
Description:	enables pwm outputs and insert a loop for bootstrap
Input:			nothing
Output:			nothing
******************************************************************************/
void MC_StartOut1(void)
{
	if(OUT1_ENABLED)
	{
		SET_COM1_ON		// set the flag after one main loop (bootstrap)
	}
	else
	{
		RES_COM1_ON
		ENABLE_OUT1		// all outputs enabled
	}
}

/******************************************************************************
Function:		MC_IniPWM1
Description:	pwm initialization
Input:			nothing
Output:			nothing
******************************************************************************/
void MC_IniPWM1(void)
{

	// wake up module before accessing registers
	WAKEUP_MTU
	DELAY1MS(1)

	// enable writing, stop timers
	MTU.TRWERA.BIT.RWE = 1;			// MTU registers writing enable
	MTU.TSTRA.BIT.CST3 = 0;			// stop timer 3
	MTU.TSTRA.BIT.CST4 = 0;			// stop timer 4

	// general settings
	MTU3.TCR.BYTE = 0x00;			//
	//MTU3.TCR.BIT.CCLR = 0;		// synchronous clearing
	//MTU3.TCR.BIT.CKEG = 0;		// count at rising edge
	//MTU3.TCR.BIT.TPSC = 0;		// no peripheral clock frequency divider
	MTU4.TCR.BYTE = 0x00;			//
	//MTU4.TCR.BIT.CCLR = 0;		// synchronous clearing
	//MTU4.TCR.BIT.CKEG = 0;		// count at rising edge
	//MTU4.TCR.BIT.TPSC = 0;		// no peripheral clock frequency divider

	// registers and buffers setting
	MTU3.TCNT = DEADTIM1;			// deadtime in TCNT3
	MTU4.TCNT = 0;					// 0 in TCNT4
	MTU.TDDRA = DEADTIM1;			// deadtime in TDDRA
	MTU.TCDRA = halfper1;			// half pwm period in TCDRA (note: MUST be > (TDDRA*2+2)
	MTU.TCBRA = halfper1;			// buffer for TCDRA
	MTU3.TGRA = halfperdead1;		// halfper + deadtime in TGRA3
	MTU3.TGRB = halfperdead1;		// duty U (0%, low arms always on)
	MTU4.TGRA = halfperdead1;		// duty V (0%, low arms always on)
	MTU4.TGRB = halfperdead1;		// duty W (0%, low arms always on)
	MTU3.TGRC = halfperdead1;		// buffer for TGRA3
	MTU3.TGRD = halfperdead1;		// buffer for TGRB3
	MTU4.TGRC = halfperdead1;		// buffer for TGRA4
	MTU4.TGRD = halfperdead1;		// buffer for TGRB4 (LAST TO BE WRITTEN!)

	// pwm frequency output enable and active levels setting
	MTU.TOCR1A.BIT.PSYE = 0;		// disable output of pwm frequency
	MTU.TOCR1A.BIT.OLSN = 1;		// select high-active output level
	MTU.TOCR1A.BIT.OLSP = 1;		// select high-active output level

	// buffer setting
	MTU3.TMDR1.BIT.BFB = 1;			// TGRD3 is a buffer for TGRB3
	MTU3.TMDR1.BIT.BFA = 1;			// TGRC3 is a buffer for TGRA3
	//MTU4.TMDR1.BIT.BFB = 1;		// TGRD4 is a buffer for TGRB4
	//MTU4.TMDR1.BIT.BFA = 1;		// TGRC4 is a buffer for TGRA4

	// complementary pwm mode setting
	MTU3.TMDR1.BIT.MD = 0x0D;		// complementary PWM mode, transmit at crest
	//MTU3.TMDR1.BIT.MD = 0x0E;		// complementary PWM mode, transmit at trough
	//MTU3.TMDR1.BIT.MD = 0x0F;		// complementary PWM mode, transmit at crest and trough
	//MTU4.TMDR1.BIT.MD = 0;		// do not set here, but only in MTU3.TMDR1

	// output disable
	MTU.TOERA.BYTE = 0xC0;			// all outputs disabled (at inactive level)
	//MTU.TOERA.BYTE = 0xFF;		// all outputs enabled

	// pins assignment to the peripheral
	// NOW the pin configuration is all outputs (at not active level) I/O ports (from hwsetup.c)
	MPC.PWPR.BYTE = 0x00;			// enable writing BIT6
	MPC.PWPR.BYTE = 0x40;			// enable writing MPC registers
	MPC.P76PFS.BYTE = 0x01;			// P76 p051 WL1 MTIOC4D
	MPC.P75PFS.BYTE = 0x01;			// P75 p052 VL1 MTIOC4C
	MPC.P74PFS.BYTE = 0x01;			// P74 p053 UL1 MTIOC3D
	MPC.P73PFS.BYTE = 0x01;			// P73 p054 WH1 MTIOC4B
	MPC.P72PFS.BYTE = 0x01;			// P72 p055 VH1 MTIOC4A
	MPC.P71PFS.BYTE = 0x01;			// P71 p056 UH1 MTIOC3B
	MPC.PWPR.BYTE = 0x80;			// disable writing MPC registers

	// port mode registers setting
	PORT7.PMR.BYTE = 0x7E;			// port mode register
	// B7
	//PORT7.PMR.BIT.B6 = 1;			// P76 p051 WL1 MTIOC4D
	//PORT7.PMR.BIT.B5 = 1;			// P75 p052 VL1 MTIOC4C
	//PORT7.PMR.BIT.B4 = 1;			// P74 p053 UL1 MTIOC3D
	//PORT7.PMR.BIT.B3 = 1;			// P73 p054 WH1 MTIOC4B
	//PORT7.PMR.BIT.B2 = 1;			// P72 p055 VH1 MTIOC4A
	//PORT7.PMR.BIT.B1 = 1;			// P71 p056 UH1 MTIOC3B
	//PORT7.PMR.BIT.B0 = 0;			// P70 p057 OVC1 POE0

	// POE pin status check before POE init
	if(0 == PORT7.PIDR.BIT.B0)		// P70 p057 OVC1 POE0
	{
		UIF_R.var.all = FAULT1_ALL;
		SET_ALRM1_ON
	}

	// POE init for pwm pins protection (WARNING: many registers can be set only once after reset)
	//POE.ALR1.WORD = 0x0000;		// active level setting register (modif. only once)
	//POE.ALR1.BIT.OLGnx = 0x3F;	// B0, .., B5 active levels setting (valid only if B7 is 1)
	//POE.ALR1.BIT.OLSEN = 0;		// B7 0 -> active levels determined by TOCR1A
	POE.ICSR1.WORD = 0x0000;		// INPUT level control/status register 1 (modif. only once)
	//POE.ICSR1.BIT.POE0M = 0;		// B1, B0 POE0 Mode	00 -> Falling edge
	//POE.ICSR1.BIT.PIE1 = 0;		// B8 Port interrupt enable
	//POE.ICSR1.BIT.POE0F = 0;		// B12 POE0 Flag
	POE.OCSR1.WORD = 0x0200;		// OUTPUT level control/status register 1 (modif. only once)
	//POE.OCSR1.BIT.OSF1 = 0;		// B15 output short circuit Flag 1
	//POE.OCSR1.BIT.OCE1 = 1;		// B9 output short circuit high impedance control 1
	//POE.OCSR1.BIT.OIE1 = 0;		// B8 output short circuit interrupt enable 1
	POE.POECR2.WORD |= 0x0700;		// Port output enable control register 2 (modif. only once)
	//POE.POECR2.BIT.MTU3BDZE = 1;	// B10 P71-P74	UH-UL
	//POE.POECR2.BIT.MTU4ACZE = 1;	// B9  P72-P75	VH-VL
	//POE.POECR2.BIT.MTU4BDZE = 1;	// B8  P73-P76	WH-WL

	// pin assignment to the peripheral
	MPC.PWPR.BYTE = 0x00;			// enable writing BIT6
	MPC.PWPR.BYTE = 0x40;			// enable writing MPC registers
	MPC.P70PFS.BYTE = 0x07;			// P70 p057 OVC1 POE0
	MPC.PWPR.BYTE = 0x80;			// disable writing MPC registers

	// port mode register setting
	PORT7.PMR.BIT.B0 = 1;			// P70 p057 OVC1 POE0

}

/******************************************************************************
Function:		MC_StartPWM1
Description:	starts pwm and main interrupt (but not the outputs)
Input:			nothing
Output:			nothing
******************************************************************************/
void MC_StartPWM1(void)
{

	// A/D converter start trigger selection
	MTU4.TADCR.WORD = 0x8080;		// Timer A/D Converter Start Request Control Register (Reset val 0x0000)
	//MTU4.TADCR.BIT.BF = 2;		// B15, B14		10 -> transfer at trough
	//MTU4.TADCR.BIT.UT4AE = 1;		// B7			1  -> trigger enabled in up counting (after trough)
	//MTU4.TADCR.BIT.DT4AE = 0;		// B6
	//MTU4.TADCR.BIT.UT4BE = 0;		// B5
	//MTU4.TADCR.BIT.DT4BE = 0;		// B4
	//MTU4.TADCR.BIT.ITA3AE = 0;	// B3
	//MTU4.TADCR.BIT.ITA4VE = 0;	// B2			int skipping still NOT linked
	//MTU4.TADCR.BIT.ITB3AE = 0;	// B1
	//MTU4.TADCR.BIT.ITB4VE = 0;	// B0
	MTU4.TADCOBRA = CON_DELAY1;		// Timer A/D Converter Start Request Cycle Set Buffer Register (Reset val 0xFFFF)
	MTU4.TADCORA = CON_DELAY1;		// Timer A/D Converter Start Request Cycle Set Register (Reset val 0xFFFF)

	// interrupt skipping (Timer 4 underflow -> trough)
	MTU.TITCR1A.BYTE = 0x00;		// Timer Interrupt Skipping Set Register 1A (Reset val 0x00)
	//MTU.TITCR1A.BIT.T3AEN = 0;	// B7
	//MTU.TITCR1A.BIT.T3ACOR = 0;	// B6, B5, B4
	//MTU.TITCR1A.BIT.T4VEN = 0;	// B3
	//MTU.TITCR1A.BIT.T4VCOR = 0;	// B2,B1, B0
	if(0 != int_skip)
	{
		MTU.TITCR1A.BYTE |= int_skip;
		MTU4.TADCR.BIT.ITA4VE = 1;	// B2			1  -> int skipping is linked
	}

	// A/D converter configuration for triggered single scan conversion
	// of currents and bus voltage
	S12AD.ADSTRGR.BIT.TRSA = 9;		// select TRG4AN (MTU4.TCNT and MTU4.TADCORA compare match) as trigger source
	S12AD.ADANSA0.WORD = 0x000F;	// selects channels 0, 1, 2, 3

	// interrupt setup
	S12AD.ADCSR.WORD = 0x1200; 		// ADIE, TRGE are 1
	IPR(S12AD, S12ADI) = MC_INT_P;	// interrupt priority (S12ADI)
//NOT NOW	IR(S12AD, S12ADI) = 0;			// reset interrupt request
//NOT NOW	IEN(S12AD, S12ADI) = 1;			// enable interrupt

	// timer start
//NOT NOW	MTU.TSTRA.BYTE |= 0xC0;			// simultaneously start timer 3 and 4

	// stop outputs for safety
	MC_StopOut1();
}

/******************************************************************************
Function:		MC_CheckPOEFlags1
Description:	check POE flags and eventually set an alarm; in case reset
				the flags
Input:			nothing
Output:			nothing
******************************************************************************/
static void MC_CheckPOEFlags1(void)
{
	if (OUT1_ENABLED)
	{
		if ((0 != POE.ICSR1.BIT.POE0F)	||	// B12
			(0 != POE.OCSR1.BIT.OSF1)	||	// B15
			(0 == PORT7.PIDR.BIT.B0)	)	// P70 p057 OVC1 POE0
		{
			MC_StopOut1();					// all outputs disabled (at inactive level)
			UIF_R.var.all = FAULT1_ALL;
			SET_ALRM1_ON
		}	
	}
	else
	{
	}
	POE.ICSR1.WORD &= 0xEFFF;			// reset B12 (POE0F) after reading it 1
	POE.OCSR1.WORD &= 0x7FFF;			// reset B15 (OSF1) after reading it 1
}

/******************************************************************************
Function:		MC_PWMGen1
Description:	output duties calc
Input:			nothing
Note:			uses global variables vuc1, vvc1 and vwc1 (requested voltages),
				global variable vbus1 (bus voltage)
Output:			nothing
Modifies:		global variables duty1_u, duty1_v, duty1_w, vux1, vvx1, vwx1
******************************************************************************/
void MC_PWMGen1(void)
{
	float32_t	f32a;
	int32_t		s32a;
	int16_t		*amin, *amed, *amax;
	int16_t		s16a, dmin, hmed, hmax;

	if(VBMIN > vbus1)
	{
		duty1_u = duty1_v = duty1_w = halfperdead1;
		vux1 = vvx1 = vwx1 = 0.0f;
		return;
	}

	// duty-cycles calculation
	// note: no problems if halfper1 is summed to all the three duties
	f32a = halfper1 / (-vbus1);				// f32a = halfper1 / vbus;
	duty1_u = f32a * vuc1;					// duty1_u = f32a * (vbus - vuc1);
	duty1_v = f32a * vvc1;					// duty1_v = f32a * (vbus - vvc1);
	duty1_w = f32a * vwc1;					// duty1_w = f32a * (vbus - vwc1);

	// finding duties order and limits
	if(duty1_u >= duty1_v)
	{										// du >= dv
		if(duty1_v >= duty1_w)
		{									// du >= dv >= dw
			amin = (&duty1_w);
			amed = (&duty1_v);
			amax = (&duty1_u);
		}
		else
		{									// du >= dv, dw > dv
			amin = (&duty1_v);
			if(duty1_u >= duty1_w)
			{								// du >= dw > dv
				amed = (&duty1_w);
				amax = (&duty1_u);
			}
			else
			{								// dw > du > dv
				amed = (&duty1_u);
				amax = (&duty1_w);
			}
		}
	}
	else
	{										// dv > du
		if(duty1_u >= duty1_w)
		{									// dv > du >= dw
			amin = (&duty1_w);
			amed = (&duty1_u);
			amax = (&duty1_v);
		}
		else
		{									// dv > du, dw > du
			amin = (&duty1_u);
			if(duty1_v >= duty1_w)
			{								// dv > dw > du
				amed = (&duty1_w);
				amax = (&duty1_v);
			}
			else
			{								// dw > dv > du
				amed = (&duty1_v);
				amax = (&duty1_w);
			}
		}
	}

	// duties differences calculation
	hmed = (*amed) - (*amin);
	hmax = (*amax) - (*amin);

	// maximum limit control (and saturation)
	if(hmax > delmax1)		// delmax1 is max delta between max duty and min duty
	{
		s32a = mul_w(hmed, delmax1);
		hmed = div_w(s32a, hmax);
		hmax = delmax1;
	}

	// medium limit control (and saturation)
	s16a = hmax - hmed;		// (*amax) - (*amed)
	if(s16a > delmed1)		// delmed1 is max delta between max duty and med duty
	{
		s32a = mul_w(hmax, delmed1);
		hmax = div_w(s32a, s16a);
		s32a = mul_w(hmed, delmed1);
		hmed = div_w(s32a, s16a);
	}

	// minimum duty (corresponding to maximum voltage) calculation
	dmin = halfper1 - hmax;

// now we have min_duty equal to dmin, med_duty equal to (dmin + hmed), and max_duty equal to (dmin + hmax)
// the maximum duty is at its maximum value halfper1, that is, the modulation is clamped at the minimum voltage
// at least two duty cycles are greater than the minimum value needed for good current reading due to the previous clamping (delmed)
// the duty corresponding to the voltage average (star-centre) is: dmin + ((hmed + hmax) / 3)

	// duties update
#ifdef CENTRED1
	// moving the duties to obtain centred modulation
	s32a = mul_w((hmed + hmax), 5461);			// 5461/16384 ~ 1/3
	s16a = dmin + (s32a >> 14);					// star centre equivalent duty
	if(s16a > centre_pos1)						// we can only decrease the duties (increase the voltages)
	{
		dmin = dmin + centre_pos1 - s16a;
		if(dmin < DMIN1)
		{
			dmin = DMIN1;						// cannot go under the minimum
		}
	}
	(*amax) = dmin + hmax;
#else	// ifdef CENTRED1
	// keeping clamped position
	(*amax) = halfper1;
#endif	// else ifdef CENTRED1
	(*amed) = dmin + hmed;
	(*amin) = dmin;

	// output voltages calculation after clamping
	f32a = vbus1 * uhalfper1;
	vux1 = (halfper1 - duty1_u) * f32a;
	vvx1 = (halfper1 - duty1_v) * f32a;
	vwx1 = (halfper1 - duty1_w) * f32a;

	// commutations number reducing
#ifdef COMMRED1
	if(halfper1 <= (*amax))
	{
		(*amax) = halfperdead1;
		if(halfper1 <= (*amed))
		{
			(*amed) = halfperdead1;
			if(halfper1 <= (*amin))
			{
				(*amin) = halfperdead1;
			}
		}
	}
#endif	// ifdef COMMRED1

}	// end of function MC_PWMGen()

/******************************************************************************
Function:		MC_StopOut2
Description:	disable pwm outputs
Input:			nothing
Output:			nothing
******************************************************************************/
void MC_StopOut2(void)
{
	DISABLE_OUT2			// all outputs disabled (at inactive level)
	RES_COM2_ON
}

/******************************************************************************
Function:		MC_StartOut2
Description:	enables pwm outputs and insert a loop for bootstrap
Input:			nothing
Output:			nothing
******************************************************************************/
void MC_StartOut2(void)
{
	if(OUT2_ENABLED)
	{
		SET_COM2_ON		// set the flag after one main loop (bootstrap)
	}
	else
	{
		RES_COM2_ON
		ENABLE_OUT2		// all outputs enabled
	}
}

/******************************************************************************
Function:		MC_IniPWM2
Description:	pwm initialization
Input:			nothing
Output:			nothing
******************************************************************************/
void MC_IniPWM2(void)
{

	// enable writing, stop timers
	MTU.TRWERB.BIT.RWE = 1;			// MTU registers writing enable
	MTU.TSTRB.BIT.CST6 = 0;			// stop timer 6
	MTU.TSTRB.BIT.CST7 = 0;			// stop timer 7

	// general settings
	MTU6.TCR.BYTE = 0x00;			//
	//MTU6.TCR.BIT.CCLR = 0;		// synchronous clearing
	//MTU6.TCR.BIT.CKEG = 0;		// count at rising edge
	//MTU6.TCR.BIT.TPSC = 0;		// no peripheral clock frequency divider
	MTU7.TCR.BYTE = 0x00;			//
	//MTU7.TCR.BIT.CCLR = 0;		// synchronous clearing
	//MTU7.TCR.BIT.CKEG = 0;		// count at rising edge
	//MTU7.TCR.BIT.TPSC = 0;		// no peripheral clock frequency divider

	// registers and buffers setting
	MTU6.TCNT = DEADTIM2;			// deadtime in TCNT6
	MTU7.TCNT = 0;					// 0 in TCNT7
	MTU.TDDRB = DEADTIM2;			// deadtime in TDDRB
	MTU.TCDRB = halfper2;			// half pwm period in TCDRB (note: MUST be > (TDDRB*2+2)
	MTU.TCBRB = halfper2;			// buffer for TCDRB
	MTU6.TGRA = halfperdead2;		// halfper + deadtime in TGRA6
	MTU6.TGRB = halfperdead2;		// duty U (0%, low arms always on)
	MTU7.TGRA = halfperdead2;		// duty V (0%, low arms always on)
	MTU7.TGRB = halfperdead2;		// duty W (0%, low arms always on)
	MTU6.TGRC = halfperdead2;		// buffer for TGRA6
	MTU6.TGRD = halfperdead2;		// buffer for TGRB6
	MTU7.TGRC = halfperdead2;		// buffer for TGRA7
	MTU7.TGRD = halfperdead2;		// buffer for TGRB7 (LAST TO BE WRITTEN!)

	// pwm frequency output enable and active levels setting
	MTU.TOCR1B.BIT.PSYE = 0;		// disable output of pwm frequency
	MTU.TOCR1B.BIT.OLSN = 1;		// select high-active output level
	MTU.TOCR1B.BIT.OLSP = 1;		// select high-active output level

	// buffer setting
	MTU6.TMDR1.BIT.BFB = 1;			// TGRD6 is a buffer for TGRB6
	MTU6.TMDR1.BIT.BFA = 1;			// TGRC6 is a buffer for TGRA6
	//MTU7.TMDR1.BIT.BFB = 1;		// TGRD7 is a buffer for TGRB7
	//MTU7.TMDR1.BIT.BFA = 1;		// TGRC7 is a buffer for TGRA7

	// complementary pwm mode setting
	MTU6.TMDR1.BIT.MD = 0x0D;		// complementary PWM mode, transmit at crest
	//MTU6.TMDR1.BIT.MD = 0x0E;		// complementary PWM mode, transmit at trough
	//MTU6.TMDR1.BIT.MD = 0x0F;		// complementary PWM mode, transmit at crest and trough
	//MTU7.TMDR1.BIT.MD = 0;		// do not set here, but only in MTU6.TMDR1

	// output disable
	MTU.TOERB.BYTE = 0xC0;			// all outputs disabled (at inactive level)
	//MTU.TOERB.BYTE = 0xFF;		// all outputs enabled

	// pins assignment to the peripheral
	// NOW the pin configuration is all outputs (at not active level) I/O ports (from hwsetup.c)
	MPC.PWPR.BYTE = 0x00;			// enable writing BIT6
	MPC.PWPR.BYTE = 0x40;			// enable writing MPC registers
	MPC.P95PFS.BYTE = 0x01;			// P95 p045 UH2 MTIOC6B
	MPC.P94PFS.BYTE = 0x01;			// P94 p046 VH2 MTIOC7A
	MPC.P93PFS.BYTE = 0x01;			// P93 p047 WH2 MTIOC7B
	MPC.P92PFS.BYTE = 0x01;			// P92 p048 UL2 MTIOC6D
	MPC.P91PFS.BYTE = 0x01;			// P91 p049 VL2 MTIOC7C
	MPC.P90PFS.BYTE = 0x01;			// P90 p050 WL2 MTIOC7D
	MPC.PWPR.BYTE = 0x80;			// disable writing MPC registers

	// port mode registers setting
	PORT9.PMR.BYTE = 0x3F;			// port mode register
	//B7
	//PORT9.PMR.B6 = 0;				// P96 p043 OVC2 POE4
	//PORT9.PMR.B5 = 0;				// P95 p045 UH2 MTIOC6B
	//PORT9.PMR.B4 = 0;				// P94 p046 VH2 MTIOC7A
	//PORT9.PMR.B3 = 0;				// P93 p047 WH2 MTIOC7B
	//PORT9.PMR.B2 = 0;				// P92 p048 UL2 MTIOC6D
	//PORT9.PMR.B1 = 0;				// P91 p049 VL2 MTIOC7C
	//PORT9.PMR.B0 = 0;				// P90 p050 WL2 MTIOC7D

	// POE pin status check before POE init
	if(0 == PORT9.PIDR.BIT.B6)		// P96 p043 OVC2 POE4
	{
		UIF_R.var.all = FAULT2_ALL;
		SET_ALRM2_ON
	}

	// POE init for pwm pins protection (WARNING: many registers can be set only once after reset)
	//POE.ALR2.WORD = 0x0000;		// active level setting register (modif. only once)
	//POE.ALR2.BIT.OLGnx = 0x3F;	// B0, .., B5 active levels setting (valid only if B7 is 1)
	//POE.ALR2.BIT.OLSEN = 0;		// B7 0 -> active levels determined by TOCR1B
	POE.ICSR2.WORD = 0x0000;		// INPUT level control/status register 2 (modif. only once)
	//POE.ICSR2.BIT.POE4M = 0;		// B1, B0 POE4 Mode	00 -> Falling edge
	//POE.ICSR2.BIT.PIE2 = 0;		// B8 Port interrupt enable
	//POE.ICSR2.BIT.POE4F = 0;		// B12 POE4 Flag
	POE.OCSR2.WORD = 0x0200;		// OUTPUT level control/status register 2 (modif. only once)
	//POE.OCSR2.BIT.OSF2 = 0;		// B15 output short circuit Flag 2
	//POE.OCSR2.BIT.OCE2 = 1;		// B9 output short circuit high impedance control 2
	//POE.OCSR2.BIT.OIE2 = 0;		// B8 output short circuit interrupt enable 2
	POE.POECR2.WORD |= 0x0700;		// Port output enable control register 2 (modif. only once)
	//POE.POECR2.BIT.MTU6BDZE = 1;	// B10 P95-P92	UH-UL
	//POE.POECR2.BIT.MTU7ACZE = 1;	// B9  P94-P91	VH-VL
	//POE.POECR2.BIT.MTU7BDZE = 1;	// B8  P93-P90	WH-WL

	// pin assignment to the peripheral
	MPC.PWPR.BYTE = 0x00;			// enable writing BIT6
	MPC.PWPR.BYTE = 0x40;			// enable writing MPC registers
	MPC.P96PFS.BYTE = 0x07;			// P96 p043 OVC2 POE4
	MPC.PWPR.BYTE = 0x80;			// disable writing MPC registers

	// port mode register setting
	PORT9.PMR.BIT.B6 = 1;			// P96 p043 OVC2 POE4

}

/******************************************************************************
Function:		MC_StartPWM2
Description:	starts pwm and main interrupt (but not the outputs)
Input:			nothing
Output:			nothing
******************************************************************************/
void MC_StartPWM2(void)
{

	// A/D converter start trigger selection
	MTU7.TADCR.WORD = 0x8080;		// Timer A/D Converter Start Request Control Register (Reset val 0x0000)
	//MTU7.TADCR.BIT.BF = 2;		// B15, B14		10 -> transfer at trough
	//MTU7.TADCR.BIT.UT7AE = 1;		// B7			1  -> trigger enabled in up counting (after trough)
	//MTU7.TADCR.BIT.DT7AE = 0;		// B6
	//MTU7.TADCR.BIT.UT7BE = 0;		// B5
	//MTU7.TADCR.BIT.DT7BE = 0;		// B4
	//MTU7.TADCR.BIT.ITA6AE = 0;	// B3
	//MTU7.TADCR.BIT.ITA7VE = 0;	// B2			int skipping still NOT linked
	//MTU7.TADCR.BIT.ITB6AE = 0;	// B1
	//MTU7.TADCR.BIT.ITB7VE = 0;	// B0
	MTU7.TADCOBRA = CON_DELAY2;		// Timer A/D Converter Start Request Cycle Set Buffer Register (Reset val 0xFFFF)
	MTU7.TADCORA = CON_DELAY2;		// Timer A/D Converter Start Request Cycle Set Register (Reset val 0xFFFF)

	// interrupt skipping (Timer 4 underflow -> trough)
	MTU.TITCR1B.BYTE = 0x00;		// Timer Interrupt Skipping Set Register 1B (Reset val 0x00)
	//MTU.TITCR1B.BIT.T6AEN = 0;	// B7
	//MTU.TITCR1B.BIT.T6ACOR = 0;	// B6, B5, B4
	//MTU.TITCR1B.BIT.T7VEN = 0;	// B3
	//MTU.TITCR1B.BIT.T7VCOR = 0;	// B2,B1, B0
	if(0 != int_skip)
	{
		MTU.TITCR1B.BYTE |= int_skip;
		MTU7.TADCR.BIT.ITA7VE = 1;	// B2			1  -> int skipping is linked
	}

	// A/D converter configuration for triggered single scan conversion
	// of currents and bus voltage
	S12AD1.ADSTRGR.BIT.TRSA = 0x0F;	// select TRG7AN (MTU7.TCNT and MTU7.TADCORA compare match) as trigger source
	S12AD1.ADANSA0.WORD = 0x000F;	// selects channels 0, 1, 2, 3

	// interrupt setup
	S12AD1.ADCSR.WORD = 0x1200; 	// ADIE, TRGE are 1
	IPR(S12AD1, S12ADI1) = MC_INT_P;	// interrupt priority (S12ADI)
//NOT NOW	IR(S12AD1, S12ADI) = 0;			// reset interrupt request
//NOT NOW	IEN(S12AD1, S12ADI) = 1;		// enable interrupt

	// timer start
//NOT NOW	MTU.TSTRB.BYTE |= 0xC0;			// simultaneously start timer 6 and 7

	// stop outputs for safety
	MC_StopOut2();
}

/******************************************************************************
Function:		MC_CheckPOEFlags2
Description:	check POE flags and eventually set an alarm; in case reset
				the flags
Input:			nothing
Output:			nothing
******************************************************************************/
static void MC_CheckPOEFlags2(void)
{
	if(OUT2_ENABLED)
	{
		if ((0 != POE.ICSR2.BIT.POE4F)	||	// B12
			(0 != POE.OCSR2.BIT.OSF2)	||	// B15
			(0 == PORT9.PIDR.BIT.B6)	)	// P96 p043 OVC2 POE4
		{
			MC_StopOut2();					// all outputs disabled (at inactive level)
			UIF_R.var.all = FAULT2_ALL;
			SET_ALRM2_ON
		}	
	}
	else
	{
	}
	POE.ICSR2.WORD &= 0xEFFF;			// reset B12 (POE4F) after reading it 1
	POE.OCSR2.WORD &= 0x7FFF;			// reset B15 (OSF1) after reading it 1
}

/******************************************************************************
Function:		MC_PWMGen2
Description:	output duties calc
Input:			nothing
Note:			uses global variables vuc1, vvc1 and vwc1 (requested voltages),
				global variable vbus2 (bus voltage)
Output:			nothing
Modifies:		global variables duty2_u, duty2_v, duty2_w, vux2, vvx2, vwx2
******************************************************************************/
void MC_PWMGen2(void)
{
	float32_t	f32a;
	int32_t		s32a;
	int16_t		*amin, *amed, *amax;
	int16_t		s16a, dmin, hmed, hmax;

	if(VBMIN > vbus2)
	{
		duty2_u = duty2_v = duty2_w = halfperdead2;
		vux2 = vvx2 = vwx2 = 0.0f;
		return;
	}

	// duty-cycles calculation
	// note: no problems if halfper is summed to all the three duties
	f32a = halfper2 / (-vbus2);				// f32a = halfper2 / vbus2;
	duty2_u = f32a * vuc2;					// duty2_u = f32a * (vbus - vuc2);
	duty2_v = f32a * vvc2;					// duty2_v = f32a * (vbus - vvc2);
	duty2_w = f32a * vwc2;					// duty2_w = f32a * (vbus - vwc2);

	// finding duties order and limits
	if(duty2_u >= duty2_v)
	{										// du >= dv
		if(duty2_v >= duty2_w)
		{									// du >= dv >= dw
			amin = (&duty2_w);
			amed = (&duty2_v);
			amax = (&duty2_u);
		}
		else
		{									// du >= dv, dw > dv
			amin = (&duty2_v);
			if(duty2_u >= duty2_w)
			{								// du >= dw > dv
				amed = (&duty2_w);
				amax = (&duty2_u);
			}
			else
			{								// dw > du > dv
				amed = (&duty2_u);
				amax = (&duty2_w);
			}
		}
	}
	else
	{										// dv > du
		if(duty2_u >= duty2_w)
		{									// dv > du >= dw
			amin = (&duty2_w);
			amed = (&duty2_u);
			amax = (&duty2_v);
		}
		else
		{									// dv > du, dw > du
			amin = (&duty2_u);
			if(duty2_v >= duty2_w)
			{								// dv > dw > du
				amed = (&duty2_w);
				amax = (&duty2_v);
			}
			else
			{								// dw > dv > du
				amed = (&duty2_v);
				amax = (&duty2_w);
			}
		}
	}

	// duties differences calculation
	hmed = (*amed) - (*amin);
	hmax = (*amax) - (*amin);

	// maximum limit control (and saturation)
	if(hmax > delmax2)		// delmax is max delta between max duty and min duty
	{
		s32a = mul_w(hmed, delmax2);
		hmed = div_w(s32a, hmax);
		hmax = delmax2;
	}

	// medium limit control (and saturation)
	s16a = hmax - hmed;		// (*amax) - (*amed)
	if(s16a > delmed2)		// delmed is max delta between max duty and med duty
	{
		s32a = mul_w(hmax, delmed2);
		hmax = div_w(s32a, s16a);
		s32a = mul_w(hmed, delmed2);
		hmed = div_w(s32a, s16a);
	}

	// minimum duty (corresponding to maximum voltage) calculation
	dmin = halfper2 - hmax;

// now we have min_duty equal to dmin, med_duty equal to (dmin + hmed), and max_duty equal to (dmin + hmax)
// the maximum duty is at its maximum value halfper, that is, the modulation is clamped at the minimum voltage
// at least two duty cycles are greater than the minimum value needed for good current reading due to the previous clamping (delmed)
// the duty corresponding to the voltage average (star-centre) is: dmin + ((hmed + hmax) / 3)

	// duties update
#ifdef CENTRED2
	// moving the duties to obtain centred modulation
	s32a = mul_w((hmed + hmax), 5461);			// 5461/16384 ~ 1/3
	s16a = dmin + (s32a >> 14);					// star centre equivalent duty
	if(s16a > centre_pos2)						// we can only decrease the duties (increase the voltages)
	{
		dmin = dmin + centre_pos2 - s16a;
		if(dmin < DMIN2)
		{
			dmin = DMIN2;						// cannot go under the minimum
		}
	}
	(*amax) = dmin + hmax;
#else	// ifdef CENTRED2
	// keeping clamped position
	(*amax) = halfper2;
#endif	// else ifdef CENTRED2
	(*amed) = dmin + hmed;
	(*amin) = dmin;

	// output voltages calculation after clamping
	f32a = vbus2 * uhalfper2;
	vux2 = (halfper2 - duty2_u) * f32a;
	vvx2 = (halfper2 - duty2_v) * f32a;
	vwx2 = (halfper2 - duty2_w) * f32a;

	// commutations number reducing
#ifdef COMMRED2
	if(halfper2 <= (*amax))
	{
		(*amax) = halfperdead2;
		if(halfper1 <= (*amed))
		{
			(*amed) = halfperdead2;
			if(halfper2 <= (*amin))
			{
				(*amin) = halfperdead2;
			}
		}
	}
#endif	// ifdef COMMRED2

}	// end of function MC_PWMGen2()

/******************************************************************************
Function:		MC_StopOut3
Description:	disable pwm outputs
Input:			nothing
Output:			nothing
******************************************************************************/
void MC_StopOut3(void)
{
	DISABLE_OUT3			// all outputs disabled (at inactive level)
	RES_COM3_ON
}

/******************************************************************************
Function:		MC_StartOut3
Description:	enables pwm outputs and insert a loop for bootstrap
Input:			nothing
Output:			nothing
******************************************************************************/
void MC_StartOut3(void)
{
	if(OUT3_ENABLED)
	{
		SET_COM3_ON		// set the flag after one main loop (bootstrap)
	}
	else
	{
		RES_COM3_ON
		ENABLE_OUT3		// all outputs enabled
	}
}

/******************************************************************************
Function:		MC_IniPWM3
Description:	pwm initialization
Input:			nothing
Output:			nothing
******************************************************************************/
void MC_IniPWM3(void)
{

	// Cancel GPT module stop state
	WAKEUP_GPT
	DELAY1MS(1)

	// enable/disable GPT0, 1, 2 control registers write protect (reset -> disabled)
	//GPTW0.GTWP.LONG = 0x0000A500;		// Write-Protection Register, resetval = 0x00000000

	// Control Register
	GPTW0.GTCR.LONG = 0x00050000;		// Control Register, resetval = 0x00000000
	GPTW1.GTCR.LONG = 0x00050000;		// Control Register, resetval = 0x00000000
	GPTW2.GTCR.LONG = 0x00050000;		// Control Register, resetval = 0x00000000
	//GPTW0.GTCR.BIT.TPCS = 0;			// B23, B22, B21, B20 timer prescaler select: 0 -> TCLKC
	//GPTW0.GTCR.BIT.MD = 5;			// B10, B9, B8	mode: 5 -> triangle wave pwm mode 2, transfer at crest and through

	// Set GPTW0, 1, 2 cycles
	GPTW0.GTPR = halfper3;				// Cycle Setting Register, resetval = 0xFFFFFFFF
	GPTW1.GTPR = halfper3;				// Cycle Setting Register, resetval = 0xFFFFFFFF
	GPTW2.GTPR = halfper3;				// Cycle Setting Register, resetval = 0xFFFFFFFF

	// Set GPTW0, 1, 2 counter initial value
	GPTW0.GTCNT = 0x00000000;			// Counter, resetval = 0x00000000
	GPTW1.GTCNT = 0x00000000;			// Counter, resetval = 0x00000000
	GPTW2.GTCNT = 0x00000000;			// Counter, resetval = 0x00000000

	// Set GTIOCA, GTIOCB pins function
	// General PWM Timer I/O Control Register (GTIOR) (Set GTIOCA, GTIOCB pin function)
	GPTW0.GTIOR.LONG = 0x02130203;		// I/O Control Register, resetval = 0x00000000
	GPTW1.GTIOR.LONG = 0x02130203;		// I/O Control Register, resetval = 0x00000000
	GPTW2.GTIOR.LONG = 0x02130203;		// I/O Control Register, resetval = 0x00000000
	//GPTW0.GTIOR.BIT.OBDF = 1;			// B25, B26 01 -> output in high Z in response to output negation request
	//GPTW0.GTIOR.BIT.OBE = 0;			// B24 0 -> pin disabled
	//GPTW0.GTIOR.BIT.OBHLD = 0;		// B23 0 -> output at start/stop depends on register setting
	//GPTW0.GTIOR.BIT.OBDFLT = 0;		// B22 0 -> ouput is low when counter is stopped
	//GPTW0.GTIOR.BIT.GTIOB = 0x13;		// B20, .., B16	10011 -> compare match, initial output high, output retained at cycle end, toggle output at compare match
	//GPTW0.GTIOR.BIT.OADF = 1;			// B9, B10 01 -> output in high Z in response to output negation request
	//GPTW0.GTIOR.BIT.OAE = 0;			// B8 0 -> pin disabled
	//GPTW0.GTIOR.BIT.OAHLD = 0;		// B7 0 -> output at start/stop depends on register setting
	//GPTW0.GTIOR.BIT.OADFLT = 0;		// B6 0 -> ouput is low when counter is stopped
	//GPTW0.GTIOR.BIT.GTIOA = 0x03;		// B4, .., B0 000011 -> compare match, initial output low, output retained at cycle end, toggle output at compare match

	// General PWM Timer Buffer Operation Enable Register (GTBER)
	GPTW0.GTBER.LONG = 0x0005000E;		// Buffer Operation Enable Register, resetval = 0x00000000
	GPTW1.GTBER.LONG = 0x0005000E;		// Buffer Operation Enable Register, resetval = 0x00000000
	GPTW2.GTBER.LONG = 0x0005000E;		// Buffer Operation Enable Register, resetval = 0x00000000
	//GPTW0.GTBER.BIT.CCRB = 1;			// B3, B2		GTCCRB Buffer Operation	01 -> single buffer
	//GPTW0.GTBER.BIT.CCRA = 1;			// B1, B0		GTCCRA Buffer Operation	01 -> single buffer

	// Set GPTW0, 1, 2 compare match init value
	GPTW0.GTCCRA = halfper3 - 1;
	GPTW1.GTCCRA = halfper3 - 1;
	GPTW2.GTCCRA = halfper3 - 1;

	// Set GPTW0, 1, 2 buffers values
	GPTW0.GTCCRC = halfper3 - 1;
	GPTW1.GTCCRC = halfper3 - 1;
	GPTW2.GTCCRC = halfper3 - 1;

	// Set GPTW0, 1, 2 dead time setting
	GPTW0.GTDTCR.LONG = 0x00000101;		// Dead Time Control Register, resetval = 0x00000000
	GPTW1.GTDTCR.LONG = 0x00000101;		// Dead Time Control Register, resetval = 0x00000000
	GPTW2.GTDTCR.LONG = 0x00000101;		// Dead Time Control Register, resetval = 0x00000000
	//GPTW0.GTDTCR.BIT.TDFER = 1;		// B8	GTDVD Setting					1 -> GTDVD equal to GTDVU
		// B7, B6
	//GPTW0.GTDTCR.BIT.TDBDE = 0;		// B5	GTDVD Buffer Operation Enable	0 -> disabled
	//GPTW0.GTDTCR.BIT.TDBUE = 0;		// B4	GTDVU Buffer Operation Enable	0 -> disabled
		// B3, B2, B1
	//GPTW0.GTDTCR.BIT.TDE = 1;			// B0	Negative-Phase Waveform Setting 1 -> automatic

	// Set GPTW0, 1, 2 dead time value
	GPTW0.GTDVU = DEADTIM3;
	GPTW1.GTDVU = DEADTIM3;
	GPTW2.GTDVU = DEADTIM3;

	// pins assignment to the peripheral
	// NOW the pin configuration is all outputs (at not active level) I/O ports (from hwsetup.c)
	MPC.PWPR.BYTE = 0x00;			// enable writing BIT6
	MPC.PWPR.BYTE = 0x40;			// enable writing MPC registers
	MPC.PD2PFS.BYTE = 0x15;			// PD2 p023 UH3 GTIOC0A
	MPC.PD1PFS.BYTE = 0x15;			// PD1 p024 UL3 GTIOC0B
	MPC.PD0PFS.BYTE = 0x15;			// PD0 p025 VH3 GTIOC1A
	MPC.PB7PFS.BYTE = 0x14;			// PB7 p026 VL3 GTIOC1B
	MPC.PB6PFS.BYTE = 0x14;			// PB6 p027 WH3 GTIOC2A
	MPC.PB5PFS.BYTE = 0x14;			// PB5 p028 WL3 GTIOC2B
	MPC.PWPR.BYTE = 0x80;			// disable writing MPC registers

	// port mode registers setting
	PORTB.PMR.BYTE |= 0xE0;			// port mode register
	//PORTB.PMR.B7 = 1;				// PB7 p026 VL3 GTIOC1B
	//PORTB.PMR.B6 = 1;				// PB6 p027 WH3 GTIOC2A
	//PORTB.PMR.B5 = 1;				// PB5 p028 WL3 GTIOC2B
	PORTD.PMR.BYTE |= 0x07;			// port mode register
	//PORTD.PMR.B2 = 1;				// PD2 p023 UH3 GTIOC0A
	//PORTD.PMR.B1 = 1;				// PD1 p024 UL3 GTIOC0B
	//PORTD.PMR.B0 = 1;				// PD0 p025 VH3 GTIOC1A

	// POE pin status check before POE init
	if(0 == PORT1.PIDR.BIT.B1)		// P11 p099 OVC3 POE9
	{
		SET_ALRM3_ON
		UIF_R.var.all = FAULT3_ALL;
	}

	// setting active level of output pin for POE control
	POE.ALR3.WORD = 0x00BF;			// Input level control/status register 3 (reset 0x0000)
	//POE.ALR3.BYTE.H = 0x00;
	//POE.ALR3.BYTE.L = 0x00;
		// B15, .., B8
	//POE.ALR3.BIT.OLSEN = 1;		// B7 Active level setting enable	1 -> enabled
		// B6
	//POE.ALR3.BIT.OLSG2B = 1;		// B5 GTIOC2B-A	1 -> high active
	//POE.ALR3.BIT.OLSG2A = 1;		// B4 GTIOC2A-A	1 -> high active
	//POE.ALR3.BIT.OLSG1B = 1;		// B3 GTIOC1B-A	1 -> high active
	//POE.ALR3.BIT.OLSG1A = 1;		// B2 GTIOC1A-A	1 -> high active
	//POE.ALR3.BIT.OLSG0B = 1;		// B1 GTIOC0B-A	1 -> high active
	//POE.ALR3.BIT.OLSG0A = 1;		// B0 GTIOC0A-A	1 -> high active

	POE.ICSR8.WORD = 0x0000;		// INPUT level control/status register 8 (modif. only once)
	//POE.ICSR8.BIT.POE9M = 0;		// B1, B0 POE9 Mode	00 -> Falling edge
	//POE.ICSR8.BIT.PIE8 = 0;		// B8 Port interrupt enable
	//POE.ICSR8.BIT.POE9F = 0;		// B12 POE9 Flag

	POE.OCSR3.WORD = 0x0200;		// OUTPUT level control/status register 3 (modif. only once)
	//POE.OCSR3.BIT.OSF3 = 0;		// B15 output short circuit Flag 3
	//POE.OCSR3.BIT.OCE3 = 1;		// B9 output short circuit high impedance control 3
	//POE.OCSR3.BIT.OIE3 = 0;		// B8 output short circuit interrupt enable 3

	POE.POECR3.WORD |= 0x0007;		// Port output enable control register 3 (modif. only once)
	//POE.POECR3.BIT.GTO2ABZE = 1;	// B2 PB6-PB5	WH-WL
	//POE.POECR3.BIT.GTO1ABZE = 1;	// B1 PD0-PB7	VH-VL
	//POE.POECR3.BIT.GTO0ABZE = 1;	// B0 PD2-PD1	UH-UL

	// pin assignment to the peripheral
	MPC.PWPR.BYTE = 0x00;			// enable writing BIT6
	MPC.PWPR.BYTE = 0x40;			// enable writing MPC registers
	MPC.P11PFS.BYTE = 0x07;			// P11 p099 OVC3 POE9
	MPC.PWPR.BYTE = 0x80;			// disable writing MPC registers

	// port mode register setting
	PORT1.PMR.BIT.B1 = 1;			// P11 p099 OVC3 POE9

}

/******************************************************************************
Function:		MC_StartPWM3
Description:	starts pwm and main interrupt (but not the outputs)
Input:			nothing
Output:			nothing
******************************************************************************/
void MC_StartPWM3(void)
{

	// Cancel ELC module stop state
	WAKEUP_ELC
	DELAY1MS(1)

	// enable ELC operations
	ELC.ELCR.BIT.ELCON = 1;
	ELC.ELSR46.BIT.ELS = 0x50;						// GPTW0 A/D conversion request to AD2

	// set A/D trigger moment
	GPTW0.GTADTRA = CON_DELAY3;
//	GPTW1.GTADTRA = 0xFFFF;
//	GPTW2.GTADTRA = 0xFFFF;

	// Set GPTW0 interrupt and A/D conversion request generation
	GPTW0.GTINTAD.LONG = 0x00010000;		// Interrupt Output Setting Register, resetval = 0x00000000
	//GPTW0.GTINTAD.BIT.ADTRAUEN = 1;		// B16	GTADTRA Compare Match (Up-Counting)			1 -> A/D request enabled

	// Set GPTW0 interrupt and A/D conversion request skipping
//	GPTW0.GTITC.WORD = 0x00000000;			// Interrupt and A/D Converter Start Request Skipping Setting Register, resetval=0x0000
	if(1 < fre_ratio)
	{
		GPTW0.GTITC.BIT.IVTT = (fre_ratio - 1);	// B10, B9, B8	GTCIV Interrupt Skipping Count Select
		GPTW0.GTITC.BIT.IVTC = 2;	// B7, B6	10: Troughs are counted and skipped
		GPTW0.GTITC.BIT.ADTAL = 1;	// B12	GTADTRA A/D Converter Start Request Link
	}

	// enable GPT software start
	GPTW0.GTSSR.BIT.CSTRT = 1;
	GPTW1.GTSSR.BIT.CSTRT = 1;
	GPTW2.GTSSR.BIT.CSTRT = 1;

	// A/D converter configuration for triggered single scan conversion
	// of currents and bus voltage
	S12AD2.ADSTRGR.BIT.TRSA = 0x3A;	// select ELC as trigger source
	S12AD2.ADANSA0.WORD = 0x030F;	// selects channels 0, 1, 2, 3, 8, 9

	// interrupt setup
	S12AD2.ADCSR.WORD = 0x1200; 	// ADIE, TRGE are 1
	IPR(S12AD2, S12ADI2) = MC_INT_P;	// interrupt priority (S12ADI)
//NOT NOW	IR(S12AD2, S12ADI) = 0;			// reset interrupt request
//NOT NOW	IEN(S12AD2, S12ADI) = 1;		// enable interrupt

	// stop outputs for safety
	MC_StopOut3();

}

/******************************************************************************
Function:		MC_CheckPOEFlags3
Description:	check POE flags and eventually set an alarm; in case reset
				the flags
Input:			nothing
Output:			nothing
******************************************************************************/
static void MC_CheckPOEFlags3(void)
{
	if (OUT3_ENABLED)
	{
		if ((0 != POE.ICSR8.BIT.POE9F)	||	// B12
			(0 != POE.OCSR3.BIT.OSF3)	||	// B15
			(0 == PORT1.PIDR.BIT.B1)	)	// P11 p099 OVC3 POE9
		{
			MC_StopOut3();					// all outputs disabled (at inactive level)
			UIF_R.var.all = FAULT3_ALL;
			SET_ALRM3_ON
		}	
	}
	else
	{
	}
	POE.ICSR8.WORD &= 0xEFFF;			// reset B12 (POE9F) after reading it 1
	POE.OCSR3.WORD &= 0x7FFF;			// reset B15 (OSF3) after reading it 1
}

/******************************************************************************
Function:		MC_PWMGen3
Description:	output duties calc
Input:			nothing
Note:			uses global variables vuc3, vvc3 and vwc3 (requested voltages),
				global variable vbus3 (bus voltage)
Output:			nothing
Modifies:		global variables duty3_u, duty3_v, duty3_w, vux3, vvx3, vwx3
******************************************************************************/
void MC_PWMGen3(void)
{
	float32_t	f32a;
	int32_t		s32a;
	int16_t		*amin, *amed, *amax;
	int16_t		s16a, dmin, hmed, hmax;

	if(VBMIN > vbus3)
	{
		duty3_u = duty3_v = duty3_w = halfper3 - 1;
		vux3 = vvx3 = vwx3 = 0.0f;
		return;
	}

	// duty-cycles calculation
	// note: no problems if halfper is summed to all the three duties
	f32a = halfper3 / (-vbus3);				// f32a = halfper / vbus;
	duty3_u = f32a * vuc3;					// duty3_u = f32a * (vbus - vuc3);
	duty3_v = f32a * vvc3;					// duty3_v = f32a * (vbus - vvc3);
	duty3_w = f32a * vwc3;					// duty3_w = f32a * (vbus - vwc3);

	// finding duties order and limits
	if(duty3_u >= duty3_v)
	{										// du >= dv
		if(duty3_v >= duty3_w)
		{									// du >= dv >= dw
			amin = (&duty3_w);
			amed = (&duty3_v);
			amax = (&duty3_u);
		}
		else
		{									// du >= dv, dw > dv
			amin = (&duty3_v);
			if(duty3_u >= duty3_w)
			{								// du >= dw > dv
				amed = (&duty3_w);
				amax = (&duty3_u);
			}
			else
			{								// dw > du > dv
				amed = (&duty3_u);
				amax = (&duty3_w);
			}
		}
	}
	else
	{										// dv > du
		if(duty3_u >= duty3_w)
		{									// dv > du >= dw
			amin = (&duty3_w);
			amed = (&duty3_u);
			amax = (&duty3_v);
		}
		else
		{									// dv > du, dw > du
			amin = (&duty3_u);
			if(duty3_v >= duty3_w)
			{								// dv > dw > du
				amed = (&duty3_w);
				amax = (&duty3_v);
			}
			else
			{								// dw > dv > du
				amed = (&duty3_v);
				amax = (&duty3_w);
			}
		}
	}

	// duties differences calculation
	hmed = (*amed) - (*amin);
	hmax = (*amax) - (*amin);

	// maximum limit control (and saturation)
	if(hmax > delmax3)		// delmax is max delta between max duty and min duty
	{
		s32a = mul_w(hmed, delmax3);
		hmed = div_w(s32a, hmax);
		hmax = delmax3;
	}

	// medium limit control (and saturation)
	s16a = hmax - hmed;		// (*amax) - (*amed)
	if(s16a > delmed3)		// delmed is max delta between max duty and med duty
	{
		s32a = mul_w(hmax, delmed3);
		hmax = div_w(s32a, s16a);
		s32a = mul_w(hmed, delmed3);
		hmed = div_w(s32a, s16a);
	}

	// minimum duty (corresponding to maximum voltage) calculation
	dmin = halfper3 - 1 - hmax;

// now we have min_duty equal to dmin, med_duty equal to (dmin + hmed), and max_duty equal to (dmin + hmax)
// the maximum duty is at its maximum value halfper - 1, that is, the modulation is clamped at the minimum voltage
// at least two duty cycles are greater than the minimum value needed for good current reading due to the previous clamping (delmed)
// the duty corresponding to the voltage average (star-centre) is: dmin + ((hmed + hmax) / 3)

	// duties update
#ifdef CENTRED3
	// moving the duties to obtain centred modulation
	s32a = mul_w((hmed + hmax), 5461);			// 5461/16384 ~ 1/3
	s16a = dmin + (s32a >> 14);					// star centre equivalent duty
	if(s16a > centre_pos3)						// we can only decrease the duties (increase the voltages)
	{
		dmin = dmin + centre_pos3 - s16a;
		if(dmin < DMIN3)
		{
			dmin = DMIN3;						// cannot go under the minimum
		}
	}
	(*amax) = dmin + hmax;
#else	// ifdef CENTRED3
	// keeping clamped position
	(*amax) = halfper3 - 1;
#endif	// else ifdef CENTRED3
	(*amed) = dmin + hmed;
	(*amin) = dmin;

	// output voltages calculation after clamping
	f32a = vbus3 * uhalfper3;
	vux3 = (halfper3 - duty3_u) * f32a;
	vvx3 = (halfper3 - duty3_v) * f32a;
	vwx3 = (halfper3 - duty3_w) * f32a;

}	// end of function MC_PWMGen()

/******************************************************************************
Function:		MC_PWM_Man
Description:	starts pwms and interrupts (but not the outputs)
Input:			nothing
Output:			nothing
******************************************************************************/
void MC_PWM_Man(void)
{
	MC_IniPWM1();
	MC_IniPWM2();
	MC_IniPWM3();
	MC_StartPWM1();
	MC_StartPWM2();
	MC_StartPWM3();

	// timer start for PWM 1
	MTU.TSTRA.BYTE |= 0xC0;						// simultaneously start timer 3 and 4

	// starts the other two timers in sequence
	if(1 == fre_ratio)
	{
		while(pwm_hper_twoth_int > MTU4.TCNT);	// waits
		MTU.TSTRB.BYTE |= 0xC0;					// simultaneously start timer 6 and 7
		while(pwm_hper_twoth_int > MTU7.TCNT);	// waits
		GPTW0.GTSTR.LONG |= 0x00000007;			// Software Start Register, resetval = 0x00000000
	}
	else if(2 == fre_ratio)
	{
		while((pwm_hper_twoth_int + 10) >= MTU4.TCNT);// waits
		while(pwm_hper_twoth_int <= MTU4.TCNT);// waits
		MTU.TSTRB.BYTE |= 0xC0;					// simultaneously start timer 6 and 7
		while((pwm_hper_twoth_int + 10) >= MTU7.TCNT);// waits
		while(pwm_hper_twoth_int <= MTU7.TCNT);// waits
		GPTW0.GTSTR.LONG |= 0x00000007;			// Software Start Register, resetval = 0x00000000
	}
	else	// if(3 == fre_ratio)
	{
		while(10 < MTU4.TCNT);					// waits
		MTU.TSTRB.BYTE |= 0xC0;					// simultaneously start timer 6 and 7
		while(10 < MTU7.TCNT);					// waits
		GPTW0.GTSTR.LONG |= 0x00000007;			// Software Start Register, resetval = 0x00000000
	}

	// enable interrupts
	IR(S12AD, S12ADI) = 0;						// reset interrupt request for PWM 1
	IEN(S12AD, S12ADI) = 1;						// enable interrupt
	IR(S12AD1, S12ADI1) = 0;					// reset interrupt request for PWM 2
	IEN(S12AD1, S12ADI1) = 1;					// enable interrupt
	IR(S12AD2, S12ADI2) = 0;					// reset interrupt request for PWM 3
	IEN(S12AD2, S12ADI2) = 1;					// enable interrupt
}
// end of PWM management functions

/******************************************************************************
Function:		MC_VecComp
Description:	calculation of the second component of a vector (absolute value)
Input:			vector amplitude amp (greater than zero)
				first component cmp
Output:			second component
Note:			result is positive or zero
******************************************************************************/
float32_t MC_VecComp(float32_t amp, float32_t cmp)
{
	float32_t f32a;

	f32a = (amp * amp) - (cmp * cmp);
	if(0.0f < f32a)
	{
		return(sqrtf(f32a));
	}
	else
	{
		return(0.0f);
	}
}

/******************************************************************************
Function:		MC_IniPar1
Description:	internal constants initialization, using eeprom values
Input:			nothing
Output:			nothing
Modifies:		many internal variables, using eeprom parameters values
******************************************************************************/
void MC_IniPar1(void)
{
#ifdef FLUXWEAK
	// direct current variation ramps (flux weakening)
	intid_rup1 = ((float32_t)DCUR_DT1) * sam_per_s;	// id integral variation ramp up in FW
	intid_rdw1 = ((float32_t)DCUR_DT1) * sam_per_s;	// id integral variation ramp dw in FW
#endif	// ifdef FLUXWEAK

	// rpm max and min
	rpm_max1 = RPM_MAX1;
	rpm_min1 = RPM_MIN1;

	// max angular speed, max speed for trip detection
	max_speed1 = rpm_max1 * krpmocp1;
	max_speed_trip1 = max_speed1 * T_MARGH;
	max_s_trip1 = max_speed_trip1;

	// min angular speed, and min speed for trip detection
	min_speed1 = rpm_min1 * krpmocp1;
	min_speed_trip1 = min_speed1 * T_MARGL;
	min_s_trip1 = min_speed_trip1;

	// startup time in internal units calculation, and delta speed every startup step
	sup_tim1 = SUP_TIM1;
	delta_om1 = min_speed1 * (sam_per_s / sup_tim1);	// to be added to speed at every step

	// acceleration ramp
	r_acc_ep1 = R_ACC1;				// rpm/s
	r_acc1 = r_acc_ep1 * mloop_per_s;	// rpm/one_loop_time

	// deceleration ramp
	r_dec_ep1 = R_DEC1;				// rpm/s
	r_dec1 = r_dec_ep1 * mloop_per_s;	// rpm/one_loop_time

	// startup current
	i_start1 = I_START1;

	// current rising time and current variation ramps
	is_rup1 = i_start1 * sam_per_s * ((float32_t)(1.0 / STUP_CUR_RT_S));
	is_rdw1 = i_start1 * sam_per_s * ((float32_t)(1.0 / STUP_CUR_FT_S));

	// maximum current
	i_max1 = I_MAX1;
#ifdef FLUXWEAK
	idmax1 = i_max1 * K_MARGI_FW;
#endif	// ifdef FLUXWEAK

	// stator resistance
	r_sta1 = R_STA1;

	// synchronous inductance
	l_sq1 = L_SQ1;

	// permanent magnets flux
	pm_fl1 = PM_FLX1;

	// flux amplitude feedback gain (used in case of exact integration estimation algo)
	fb_gain1 = FB_GAIN1;

	// PI gains
	kp_cur1 = KP_CUR1;				// [Ohm]
	ki_cur1 = sam_per_s * KI_CUR1;	// parameter referred to continuous time [Ohm/sec], internal value to discrete time [Ohm]
	kp_vel1 = KP_VEL1;				// [Ampere*sec/rad]
	ki_vel1 = sam_per_s * KI_VEL1;	// parameter referred to continuous time [Ampere/rad], internal value to discrete time [Ampere*sec/rad]

	// flux and speed estimation functions init
	McrpLibf_FluxEst1_SetParam(r_sta1, l_sq1, pm_fl1, fb_gain1, sam_per_s, SPEED_LP_CUTOFF_HZ);

	// speed ramp state machine
	ramp1_status = STOP_0;
	SET_STOPPED1
	RES_STARTED1

	// phase offset
	Phase_offset1 = 0.0f;
}

/******************************************************************************
Function:		MC_IniPar2
Description:	internal constants initialization, using eeprom values
Input:			nothing
Output:			nothing
Modifies:		many internal variables, using eeprom parameters values
******************************************************************************/
void MC_IniPar2(void)
{
#ifdef FLUXWEAK
	// direct current variation ramps (flux weakening)
	intid_rup2 = ((float32_t)DCUR_DT2) * sam_per_s;	// id integral variation ramp up in FW
	intid_rdw2 = ((float32_t)DCUR_DT2) * sam_per_s;	// id integral variation ramp dw in FW
#endif	// ifdef FLUXWEAK

	// rpm max and min
	rpm_max2 = RPM_MAX2;
	rpm_min2 = RPM_MIN2;

	// max angular speed, max speed for trip detection
	max_speed2 = rpm_max2 * krpmocp2;
	max_speed_trip2 = max_speed2 * T_MARGH;
	max_s_trip2 = max_speed_trip2;

	// min angular speed, and min speed for trip detection
	min_speed2 = rpm_min2 * krpmocp2;
	min_speed_trip2 = min_speed2 * T_MARGL;
	min_s_trip2 = min_speed_trip2;

	// startup time in internal units calculation, and delta speed every startup step
	sup_tim2 = SUP_TIM2;
	delta_om2 = min_speed2 * (sam_per_s / sup_tim2);	// to be added to speed at every step

	// acceleration ramp
	r_acc_ep2 = R_ACC2;				// rpm/s
	r_acc2 = r_acc_ep2 * mloop_per_s;	// rpm/one_loop_time

	// deceleration ramp
	r_dec_ep2 = R_DEC2;				// rpm/s
	r_dec2 = r_dec_ep2 * mloop_per_s;	// rpm/one_loop_time

	// startup current
	i_start2 = I_START2;

	// current rising time and current variation ramps
	is_rup2 = i_start2 * sam_per_s * ((float32_t)(1.0 / STUP_CUR_RT_S));
	is_rdw2 = i_start2 * sam_per_s * ((float32_t)(1.0 / STUP_CUR_FT_S));

	// maximum current
	i_max2 = I_MAX2;
#ifdef FLUXWEAK
	idmax2 = i_max2 * K_MARGI_FW;
#endif	// ifdef FLUXWEAK

	// stator resistance
	r_sta2 = R_STA2;

	// synchronous inductance
	l_sq2 = L_SQ2;

	// permanent magnets flux
	pm_fl2 = PM_FLX2;

	// flux amplitude feedback gain (used in case of exact integration estimation algo)
	fb_gain2 = FB_GAIN2;

	// PI gains
	kp_cur2 = KP_CUR2;				// [Ohm]
	ki_cur2 = sam_per_s * KI_CUR2;	// parameter referred to continuous time [Ohm/sec], internal value to discrete time [Ohm]
	kp_vel2 = KP_VEL2;				// [Ampere*sec/rad]
	ki_vel2 = sam_per_s * KI_VEL2;	// parameter referred to continuous time [Ampere/rad], internal value to discrete time [Ampere*sec/rad]

	// flux and speed estimation functions init
	McrpLibf_FluxEst2_SetParam(r_sta2, l_sq2, pm_fl2, fb_gain2, sam_per_s, SPEED_LP_CUTOFF_HZ);

	// speed ramp state machine
	ramp2_status = STOP_0;
	SET_STOPPED2
	RES_STARTED2

	// phase offset
	Phase_offset2 = 0.0f;

}

/******************************************************************************
Function:		MC_IniPar3
Description:	internal constants initialization, using eeprom values
Input:			nothing
Output:			nothing
Modifies:		many internal variables, using eeprom parameters values
******************************************************************************/
void MC_IniPar3(void)
{
#ifdef FLUXWEAK
	// direct current variation ramps (flux weakening)
	intid_rup3 = ((float33_t)DCUR_DT3) * sam_per_s;	// id integral variation ramp up in FW
	intid_rdw3 = ((float33_t)DCUR_DT3) * sam_per_s;	// id integral variation ramp dw in FW
#endif	// ifdef FLUXWEAK

	// rpm max and min
	rpm_max3 = RPM_MAX3;
	rpm_min3 = RPM_MIN3;

	// max angular speed, max speed for trip detection
	max_speed3 = rpm_max3 * krpmocp3;
	max_speed_trip3 = max_speed3 * T_MARGH;
	max_s_trip3 = max_speed_trip3;

	// min angular speed, and min speed for trip detection
	min_speed3 = rpm_min3 * krpmocp3;
	min_speed_trip3 = min_speed3 * T_MARGL;
	min_s_trip3 = min_speed_trip3;

	// startup time in internal units calculation, and delta speed every startup step
	sup_tim3 = SUP_TIM3;
	delta_om3 = min_speed3 * (sam_per_s / sup_tim3);	// to be added to speed at every step

	// acceleration ramp
	r_acc_ep3 = R_ACC3;				// rpm/s
	r_acc3 = r_acc_ep3 * mloop_per_s;	// rpm/one_loop_time

	// deceleration ramp
	r_dec_ep3 = R_DEC3;				// rpm/s
	r_dec3 = r_dec_ep3 * mloop_per_s;	// rpm/one_loop_time

	// startup current
	i_start3 = I_START3;

	// current rising time and current variation ramps
	is_rup3 = i_start3 * sam_per_s * ((float32_t)(1.0 / STUP_CUR_RT_S));
	is_rdw3 = i_start3 * sam_per_s * ((float32_t)(1.0 / STUP_CUR_FT_S));

	// maximum current
	i_max3 = I_MAX3;
#ifdef FLUXWEAK
	idmax3 = i_max3 * K_MARGI_FW;
#endif	// ifdef FLUXWEAK

	// stator resistance
	r_sta3 = R_STA3;

	// synchronous inductance
	l_sq3 = L_SQ3;

	// permanent magnets flux
	pm_fl3 = PM_FLX3;

	// flux amplitude feedback gain (used in case of exact integration estimation algo)
	fb_gain3 = FB_GAIN3;

	// PI gains
	kp_cur3 = KP_CUR3;				// [Ohm]
	ki_cur3 = sam_per_s * KI_CUR3;	// parameter referred to continuous time [Ohm/sec], internal value to discrete time [Ohm]
	kp_vel3 = KP_VEL3;				// [Ampere*sec/rad]
	ki_vel3 = sam_per_s * KI_VEL3;	// parameter referred to continuous time [Ampere/rad], internal value to discrete time [Ampere*sec/rad]

	// flux and speed estimation functions init
	McrpLibf_FluxEst3_SetParam(r_sta3, l_sq3, pm_fl3, fb_gain3, sam_per_s, SPEED_LP_CUTOFF_HZ);

	// speed ramp state machine
	ramp3_status = STOP_0;
	SET_STOPPED3
	RES_STARTED3

	// phase offset
	Phase_offset3 = 0.0f;

}

/******************************************************************************
Function:		MC_IniPar
Description:	internal constants initialization, using eeprom values
Input:			nothing
Output:			nothing
Modifies:		many internal variables, using eeprom parameters values
******************************************************************************/
void MC_IniPar(void)
{
	uint16_t	u16a;
	float32_t	f32a;

	// pwm constants setting, based on eeprom values
	MC_SetPwmConst();
	UIF_R.var.pwmf = pwm_fre_Hz;
	UIF_R.var.sf = sam_fre_Hz;

#ifdef MACRO_DEBUG
	macro_debug();
#endif	// ifdef MACRO_DEBUG

	// additional features enabling
#ifdef CPI_TUN
	ENA_CURPI_TUN
#endif	// ifdef CPI_TUN
#ifdef CPI_AUT
	ENA_CURPI_AUT
#endif	// ifdef CPI_AUT
#ifdef	MOT_IDENT
	ENA_AUTO_IDEN
#endif	//	ifdef MOT_IDENT
#ifdef OSC_WIN
	ENA_OSCI_WIND
#endif	// ifdef OSC_WIN

	MC_IniPar1();
	MC_IniPar2();
	MC_IniPar3();

	if(MOT1_SEL)
	{
		f32a = i_max1;
	}
	else if(MOT2_SEL)
	{
		f32a = i_max2;
	}
	else	// if(MOT3_SEL)
	{
		f32a = i_max3;
	}

#ifdef MOT_IDENT
	// motor identification variables
	ial_1 = f32a * HIG_CUR_RATIO;
	ial_2 = f32a * MID_CUR_RATIO;
	ial_3 = f32a * LOW_CUR_RATIO;
	ial_r = ial_1 * sam_per_ms * ((float32_t)(1.0 / CUR_RISE_TIME_MS));
	iden_om = ((float32_t)(TWOPI * IDENT_SPEED_HZ));
	iden_or = iden_om * sam_per_ms * ((float32_t)(1.0f / SPE_RISE_TIME_MS));
#endif	// ifdef MOT_IDENT

#ifdef OSC_WIN
	// oscilloscope window variables
	if(0.0001f < f32a)
	{
		imax1000 = 1000.0f / f32a;
	}
	else
	{
		imax1000 = 1000000.0f;
	}
	selmem = 0;
	bcnt0 = 0;
	bcnt1 = 0;
	bcntm = 0;
	phmem = 0.0f;
	sample = 0;
	RES_TRGED
	RES_RBUSY
	RES_CSELD
#endif	// ifdef OSC_WIN

	// buffers
	rbuf = ((uint16_t *)(outbuf.ss));
	wbuf = ((uint16_t *)(outbuf1.ss));
	pbuf = rbuf;
	for(u16a = 0; u16a < OUTBUF_SDIM; u16a++)
	{
		rbuf[u16a] = 0;
		wbuf[u16a] = 0;
	}

	// mode
	SET_NORM_MODE
}

/******************************************************************************
Function:		MC_UpdPar1
Description:	internal constants update, if parameters have been changed
Input:			nothing
Output:			nothing
Modifies:		many internal variables, using eeprom parameters values
******************************************************************************/
void MC_UpdPar1(void)
{
	int16_t	s16mod = 0;

	// parameters update if changed
	if(	(RPM_MIN1 != rpm_min1) || (RPM_MAX1 != rpm_max1) ||
		(SUP_TIM1 != sup_tim1) )
	{
		rpm_min1 = RPM_MIN1;
		rpm_max1 = RPM_MAX1;
		sup_tim1 = SUP_TIM1;
		max_speed1 = rpm_max1 * krpmocp1;
		min_speed1 = rpm_min1 * krpmocp1;
		max_s_trip1 = max_speed_trip1 = max_speed1 * T_MARGH;
		min_s_trip1 = min_speed_trip1 = min_speed1 * T_MARGL;
		delta_om1 = min_speed1 * (sam_per_s / sup_tim1);	// to be added to speed at every step
	}
	if(R_ACC1 != r_acc_ep1)
	{
		r_acc_ep1 = R_ACC1;					// in rpm/sec
		r_acc1 = r_acc_ep1 * ((float32_t) mloop_per_s);
	}
	if(R_DEC1 != r_dec_ep1)
	{
		r_dec_ep1 = R_DEC1;
		r_dec1 = r_dec_ep1 * ((float32_t) mloop_per_s);
	}
	if(I_START1 != i_start1)
	{
		i_start1 = I_START1;
		is_rup1 = i_start1 * sam_per_s * ((float32_t)(1.0 / STUP_CUR_RT_S));
		is_rdw1 = i_start1 * sam_per_s * ((float32_t)(1.0 / STUP_CUR_FT_S));
	}
	if(I_MAX1 != i_max1)
	{
		i_max1 = I_MAX1;
#ifdef FLUXWEAK
		idmax1 = i_max1 * K_MARGI_FW;
#endif	// ifdef FLUXWEAK
#ifdef MOT_IDENT
		if(MOT1_SEL)
		{
			ial_1 = i_max1 * HIG_CUR_RATIO;
			ial_2 = i_max1 * MID_CUR_RATIO;
			ial_3 = i_max1 * LOW_CUR_RATIO;
			ial_r = ial_1 * sam_per_ms * ((float32_t)(1.0f / CUR_RISE_TIME_MS));
		}
#endif	// ifdef MOT_IDENT
#ifdef OSC_WIN
	if(MOT1_SEL)
	{
		if(0.0001f < i_max1)
		{
			imax1000 = 1000.0f / i_max1;
		}
		else
		{
			imax1000 = 1000000.0f;
		}
	}
#endif	// ifdef OSC_WIN
	}
	if(R_STA1 != r_sta1)
	{
		r_sta1 = R_STA1;
		s16mod = -1;
	}
	if(L_SQ1 != l_sq1)
	{
		l_sq1 = L_SQ1;
		s16mod = -1;
	}
	if(PM_FLX1 != pm_fl1)
	{
		pm_fl1 = PM_FLX1;
		s16mod = -1;
	}
	if(FB_GAIN1 != fb_gain1)
	{
		fb_gain1 = FB_GAIN1;
		s16mod = -1;
	}
	if(0 != s16mod)
	{
		McrpLibf_FluxEst1_SetParam(r_sta1, l_sq1, pm_fl1, fb_gain1, sam_per_s, SPEED_LP_CUTOFF_HZ);
	}
	kp_cur1 = KP_CUR1;				// [Ohm]
	ki_cur1 = sam_per_s * KI_CUR1;	// parameter referred to continuous time [Ohm/sec], internal value to discrete time [Ohm]
	kp_vel1 = KP_VEL1;				// [Ampere*sec/rad]
	ki_vel1 = sam_per_s * KI_VEL1;	// parameter referred to continuous time [Ampere/rad], internal value to discrete time [Ampere*sec/rad]
	if(0.0f > omrif1)
	{
		Phase_offset1 = PHA_OFF1 * (-FTWOPI / 360.0f);
	}
	else if(0.0f < omrif1)
	{
		Phase_offset1 = PHA_OFF1 * (FTWOPI / 360.0f);
	}
	else
	{
		Phase_offset1 = 0.0f;
	}
}

/******************************************************************************
Function:		MC_UpdPar2
Description:	internal constants update, if parameters have been changed
Input:			nothing
Output:			nothing
Modifies:		many internal variables, using eeprom parameters values
******************************************************************************/
void MC_UpdPar2(void)
{
	int16_t	s16mod = 0;

	// parameters update if changed
	if(	(RPM_MIN2 != rpm_min2) || (RPM_MAX2 != rpm_max2) ||
		(SUP_TIM2 != sup_tim2) )
	{
		rpm_min2 = RPM_MIN2;
		rpm_max2 = RPM_MAX2;
		sup_tim2 = SUP_TIM2;
		max_speed2 = rpm_max2 * krpmocp2;
		min_speed2 = rpm_min2 * krpmocp2;
		max_s_trip2 = max_speed_trip2 = max_speed2 * T_MARGH;
		min_s_trip2 = min_speed_trip2 = min_speed2 * T_MARGL;
		delta_om2 = min_speed2 * (sam_per_s / sup_tim2);	// to be added to speed at every step
	}
	if(R_ACC2 != r_acc_ep2)
	{
		r_acc_ep2 = R_ACC2;					// in rpm/sec
		r_acc2 = r_acc_ep2 * ((float32_t) mloop_per_s);
	}
	if(R_DEC2 != r_dec_ep2)
	{
		r_dec_ep2 = R_DEC2;
		r_dec2 = r_dec_ep2 * ((float32_t) mloop_per_s);
	}
	if(I_START2 != i_start2)
	{
		i_start2 = I_START2;
		is_rup2 = i_start2 * sam_per_s * ((float32_t)(1.0 / STUP_CUR_RT_S));
		is_rdw2 = i_start2 * sam_per_s * ((float32_t)(1.0 / STUP_CUR_FT_S));
	}
	if(I_MAX2 != i_max2)
	{
		i_max2 = I_MAX2;
#ifdef FLUXWEAK
		idmax2 = i_max2 * K_MARGI_FW;
#endif	// ifdef FLUXWEAK
#ifdef MOT_IDENT
		if(MOT2_SEL)
		{
			ial_1 = i_max2 * HIG_CUR_RATIO;
			ial_2 = i_max2 * MID_CUR_RATIO;
			ial_3 = i_max2 * LOW_CUR_RATIO;
			ial_r = ial_1 * sam_per_ms * ((float32_t)(1.0f / CUR_RISE_TIME_MS));
		}
#endif	// ifdef MOT_IDENT
#ifdef OSC_WIN
	if(MOT2_SEL)
	{
		if(0.0001f < i_max2)
		{
			imax1000 = 1000.0f / i_max2;
		}
		else
		{
			imax1000 = 1000000.0f;
		}
	}
#endif	// ifdef OSC_WIN
	}
	if(R_STA2 != r_sta2)
	{
		r_sta2 = R_STA2;
		s16mod = -1;
	}
	if(L_SQ2 != l_sq2)
	{
		l_sq2 = L_SQ2;
		s16mod = -1;
	}
	if(PM_FLX2 != pm_fl2)
	{
		pm_fl2 = PM_FLX2;
		s16mod = -1;
	}
	if(FB_GAIN2 != fb_gain2)
	{
		fb_gain2 = FB_GAIN2;
		s16mod = -1;
	}
	if(0 != s16mod)
	{
		McrpLibf_FluxEst2_SetParam(r_sta2, l_sq2, pm_fl2, fb_gain2, sam_per_s, SPEED_LP_CUTOFF_HZ);
	}
	kp_cur2 = KP_CUR2;				// [Ohm]
	ki_cur2 = sam_per_s * KI_CUR2;	// parameter referred to continuous time [Ohm/sec], internal value to discrete time [Ohm]
	kp_vel2 = KP_VEL2;				// [Ampere*sec/rad]
	ki_vel2 = sam_per_s * KI_VEL2;	// parameter referred to continuous time [Ampere/rad], internal value to discrete time [Ampere*sec/rad]
	if(0.0f > omrif2)
	{
		Phase_offset2 = PHA_OFF2 * (-FTWOPI / 360.0f);
	}
	else if(0.0f < omrif2)
	{
		Phase_offset2 = PHA_OFF2 * (FTWOPI / 360.0f);
	}
	else
	{
		Phase_offset2 = 0.0f;
	}
}

/******************************************************************************
Function:		MC_UpdPar3
Description:	internal constants update, if parameters have been changed
Input:			nothing
Output:			nothing
Modifies:		many internal variables, using eeprom parameters values
******************************************************************************/
void MC_UpdPar3(void)
{
	int16_t	s16mod = 0;

	// parameters update if changed
	if(	(RPM_MIN3 != rpm_min3) || (RPM_MAX3 != rpm_max3) ||
		(SUP_TIM3 != sup_tim3) )
	{
		rpm_min3 = RPM_MIN3;
		rpm_max3 = RPM_MAX3;
		sup_tim3 = SUP_TIM3;
		max_speed3 = rpm_max3 * krpmocp3;
		min_speed3 = rpm_min3 * krpmocp3;
		max_s_trip3 = max_speed_trip3 = max_speed3 * T_MARGH;
		min_s_trip3 = min_speed_trip3 = min_speed3 * T_MARGL;
		delta_om3 = min_speed3 * (sam_per_s / sup_tim3);	// to be added to speed at every step
	}
	if(R_ACC3 != r_acc_ep3)
	{
		r_acc_ep3 = R_ACC3;					// in rpm/sec
		r_acc3 = r_acc_ep3 * ((float32_t) mloop_per_s);
	}
	if(R_DEC3 != r_dec_ep3)
	{
		r_dec_ep3 = R_DEC3;
		r_dec3 = r_dec_ep3 * ((float32_t) mloop_per_s);
	}
	if(I_START3 != i_start3)
	{
		i_start3 = I_START3;
		is_rup3 = i_start3 * sam_per_s * ((float32_t)(1.0 / STUP_CUR_RT_S));
		is_rdw3 = i_start3 * sam_per_s * ((float32_t)(1.0 / STUP_CUR_FT_S));
	}
	if(I_MAX3 != i_max3)
	{
		i_max3 = I_MAX3;
#ifdef FLUXWEAK
		idmax3 = i_max3 * K_MARGI_FW;
#endif	// ifdef FLUXWEAK
#ifdef MOT_IDENT
		if(MOT3_SEL)
		{
			ial_1 = i_max3 * HIG_CUR_RATIO;
			ial_2 = i_max3 * MID_CUR_RATIO;
			ial_3 = i_max3 * LOW_CUR_RATIO;
			ial_r = ial_1 * sam_per_ms * ((float32_t)(1.0f / CUR_RISE_TIME_MS));
		}
#endif	// ifdef MOT_IDENT
#ifdef OSC_WIN
	if(MOT1_SEL)
	{
		if(0.0001f < i_max3)
		{
			imax1000 = 1000.0f / i_max3;
		}
		else
		{
			imax1000 = 1000000.0f;
		}
	}
#endif	// ifdef OSC_WIN
	}
	if(R_STA3 != r_sta3)
	{
		r_sta3 = R_STA3;
		s16mod = -1;
	}
	if(L_SQ3 != l_sq3)
	{
		l_sq3 = L_SQ3;
		s16mod = -1;
	}
	if(PM_FLX3 != pm_fl3)
	{
		pm_fl3 = PM_FLX3;
		s16mod = -1;
	}
	if(FB_GAIN3 != fb_gain3)
	{
		fb_gain3 = FB_GAIN3;
		s16mod = -1;
	}
	if(0 != s16mod)
	{
		McrpLibf_FluxEst3_SetParam(r_sta3, l_sq3, pm_fl3, fb_gain3, sam_per_s, SPEED_LP_CUTOFF_HZ);
	}
	kp_cur3 = KP_CUR3;				// [Ohm]
	ki_cur3 = sam_per_s * KI_CUR3;	// parameter referred to continuous time [Ohm/sec], internal value to discrete time [Ohm]
	kp_vel3 = KP_VEL3;				// [Ampere*sec/rad]
	ki_vel3 = sam_per_s * KI_VEL3;	// parameter referred to continuous time [Ampere/rad], internal value to discrete time [Ampere*sec/rad]
	if(0.0f > omrif3)
	{
		Phase_offset3 = PHA_OFF3 * (-FTWOPI / 360.0f);
	}
	else if(0.0f < omrif3)
	{
		Phase_offset3 = PHA_OFF3 * (FTWOPI / 360.0f);
	}
	else
	{
		Phase_offset3 = 0.0f;
	}
}

/******************************************************************************
Function:		MC_UpdPar
Description:	internal constants update, if parameters have been changed
Input:			nothing
Output:			nothing
Modifies:		many internal variables, using eeprom parameters values
******************************************************************************/
void MC_UpdPar(void)
{
	MC_UpdPar1();
	MC_UpdPar2();
	MC_UpdPar3();
}

/******************************************************************************
Function:		MC_ConFil1
Description:	management of measured values, to give them to the GUI
Input:			nothing
Output:			nothing
Modifies:		interface variables defined in userif.h
******************************************************************************/
void MC_ConFil1(void)
{

	// speed reference
	UIF_R.var.rif = rpmrif_y1;

	// mechanical speed
	mec_rpm1 = omf1 * ukrpmocp1;
	UIF_R.var.rpm = mec_rpm1;

	// imposed frequency
	freq1 = omf1 * ((float32_t) KOF);
	UIF_R.var.fre = freq1;				// [Hz]

	// direct current
	UIF_R.var.id = idmf1;				// [Apk]

	// quadrature current
	UIF_R.var.iq = iqmf1;				// [Apk]

	// direct voltage
	UIF_R.var.vd = vdmf1;				// [Vstar_pk]

	// quadrature voltage
	UIF_R.var.vq = vqmf1;				// [Vstar_pk]

	// bus voltage
	UIF_R.var.vb = vbusf1;				// [V]

	// total current
	McrpLibf_xy_rt(idmf1, iqmf1, &f_amp_i1, &f_arg_i1);
	UIF_R.var.toti = f_amp_i1;			// [Apk]

	// total voltage
	McrpLibf_xy_rt(vdmf1, vqmf1, &f_amp_v1, &f_arg_v1);
	UIF_R.var.totv = f_amp_v1;			// [Vstar_pk]

	// dummy
	FluxAmp1 = McrpLibf_FluxEst1_GetAmp();
	UIF_R.var.du0 = FluxAmp1;
}

/******************************************************************************
Function:		MC_ConFil2
Description:	management of measured values, to give them to the GUI
Input:			nothing
Output:			nothing
Modifies:		interface variables defined in userif.h
******************************************************************************/
void MC_ConFil2(void)
{

	// speed reference
	UIF_R.var.rif = rpmrif_y2;

	// mechanical speed
	mec_rpm2 = omf2 * ukrpmocp2;
	UIF_R.var.rpm = mec_rpm2;

	// imposed frequency
	freq2 = omf2 * ((float32_t) KOF);
	UIF_R.var.fre = freq2;				// [Hz]

	// direct current
	UIF_R.var.id = idmf2;				// [Apk]

	// quadrature current
	UIF_R.var.iq = iqmf2;				// [Apk]

	// direct voltage
	UIF_R.var.vd = vdmf2;				// [Vstar_pk]

	// quadrature voltage
	UIF_R.var.vq = vqmf2;				// [Vstar_pk]

	// bus voltage
	UIF_R.var.vb = vbusf2;				// [V]

	// total current
	McrpLibf_xy_rt(idmf2, iqmf2, &f_amp_i2, &f_arg_i2);
	UIF_R.var.toti = f_amp_i2;			// [Apk]

	// total voltage
	McrpLibf_xy_rt(vdmf2, vqmf2, &f_amp_v2, &f_arg_v2);
	UIF_R.var.totv = f_amp_v2;			// [Vstar_pk]

	// dummy
	FluxAmp2 = McrpLibf_FluxEst2_GetAmp();
	UIF_R.var.du0 = FluxAmp2;
}

/******************************************************************************
Function:		MC_ConFil3
Description:	management of measured values, to give them to the GUI
Input:			nothing
Output:			nothing
Modifies:		interface variables defined in userif.h
******************************************************************************/
void MC_ConFil3(void)
{

	// speed reference
	UIF_R.var.rif = rpmrif_y3;

	// mechanical speed
	mec_rpm3 = omf3 * ukrpmocp3;
	UIF_R.var.rpm = mec_rpm3;

	// imposed frequency
	freq3 = omf3 * ((float32_t) KOF);
	UIF_R.var.fre = freq3;				// [Hz]

	// direct current
	UIF_R.var.id = idmf3;				// [Apk]

	// quadrature current
	UIF_R.var.iq = iqmf3;				// [Apk]

	// direct voltage
	UIF_R.var.vd = vdmf3;				// [Vstar_pk]

	// quadrature voltage
	UIF_R.var.vq = vqmf3;				// [Vstar_pk]

	// bus voltage
	UIF_R.var.vb = vbusf3;				// [V]

	// total current
	McrpLibf_xy_rt(idmf3, iqmf3, &f_amp_i3, &f_arg_i3);
	UIF_R.var.toti = f_amp_i3;			// [Apk]

	// total voltage
	McrpLibf_xy_rt(vdmf3, vqmf3, &f_amp_v3, &f_arg_v3);
	UIF_R.var.totv = f_amp_v3;			// [Vstar_pk]

	// dummy
	FluxAmp3 = McrpLibf_FluxEst3_GetAmp();
	UIF_R.var.du0 = FluxAmp3;
}

/******************************************************************************
Function:		MC_ConFil
Description:	management of measured values, to give them to the GUI
Input:			nothing
Output:			nothing
Modifies:		interface variables defined in userif.h
******************************************************************************/
void MC_ConFil(void)
{
	if(MOT3_SEL)
	{
		MC_ConFil3();
	}
	else if(MOT2_SEL)
	{
		MC_ConFil2();
	}
	else	// if(MOT1_SEL)
	{
		MC_ConFil1();
	}
}

/******************************************************************************
Function:		MC_IdIqPI
Description:	Current PI control
Input:			reference direct current ird,
				measured direct current imd,
				reference quadrature current irq,
				measured quadrature current imq,
				maximum allowable output vmx,
				direct voltage output address avd,
				quadrature voltage output address avq,
				direct integral memory address iid,
				quadrature integral memory address iiq
Output:			nothing
Modifies:		control output voltage components *avd, *avq
				integral memories *iid, *iiq
******************************************************************************/
void MC_IdIqPI(	float32_t ird, float32_t imd, float32_t irq, float32_t imq, float32_t vmx,
				float32_t kp_cur, float32_t ki_cur,
				float32_t *avd, float32_t *avq, float32_t *iid, float32_t *iiq)
{
	float32_t f32a;

	if(0.0f >= vmx)
	{
		*avq = *avd = 0.0f;
		*iiq = *iid = 0.0f;
		return;
	}

	// id control
	f32a = vmx * K_MARGV_DQ;		// vmaxd
	(*avd) = McrpLibf_PIW((ird - imd), f32a, -f32a, kp_cur, ki_cur, iid);

	// iq control
	f32a = MC_VecComp(vmx, (*avd));	// vmaxq
	(*avq) = McrpLibf_PIW((irq - imq), f32a, -f32a, kp_cur, ki_cur, iiq);
}

#ifdef CPI_TUN
/******************************************************************************
Function:		MC_CurPITun
Description:	creation of a current step, to manually tune the current PIs
Input:			nothing
Output:			nothing
******************************************************************************/
void MC_CurPITun(float32_t idm, float32_t *idr, float32_t imax)
{
	if(MAX_SAM_CNT > pit_c)
	{
		*idr = imax * ratio;
		if(50 > pit_c)				// 50 samples	0, .., 49, and 50 interrupts
		{
			rbuf[pit_c++] = idm * 1000.0f;
			cur_ampf = 0.0f;
			pit_s = 0;
		}
		else if(65 > pit_c)			// 15 samples	50, .., 64, and 45 interrupts
		{
			if(3 > pit_s)
			{
				pit_s++;
				cur_ampf += idm;
			}
			else
			{
				rbuf[pit_c++] = 1000.0f * cur_ampf / pit_s;
				cur_ampf = 0.0f;
				pit_s = 0;
			}
		}
		else if(80 > pit_c)			// 15 samples	65, .., 79, and 135 interrupts
		{
			if(9 > pit_s)
			{
				pit_s++;
				cur_ampf += idm;
			}
			else
			{
				rbuf[pit_c++] = 1000.0f * cur_ampf / pit_s;
				cur_ampf = 0.0f;
				pit_s = 0;
			}
		}
		else if(95 > pit_c)			// 15 samples	80, .., 94, and 405 interrupts
		{
			if(27 > pit_s)
			{
				pit_s++;
				cur_ampf += idm;
			}
			else
			{
				rbuf[pit_c++] = 1000.0f * cur_ampf / pit_s;
				cur_ampf = 0.0f;
				pit_s = 0;
			}
		}
		else if(110 > pit_c)		// 15 samples	95, .., 109, and 1215 interrupts
		{
			if(81 > pit_s)
			{
				pit_s++;
				cur_ampf += idm;
			}
			else
			{
				rbuf[pit_c++] = 1000.0f * cur_ampf / pit_s;
				cur_ampf = 0.0f;
				pit_s = 0;
			}
		}
		else /*if(MAX_SAM_CNT > pit_c)*/	// remaining samples	110, .., 1XX, and YYYY interrupts
		{
			if(243 > pit_s)
			{
				pit_s++;
				cur_ampf += idm;
			}
			else
			{
				rbuf[pit_c++] = 1000.0f * cur_ampf / pit_s;
				cur_ampf = 0.0f;
				pit_s = 0;
			}
		}
	}		// total: MAX_SAM_CNT samples and less than 5495 interrupts (around 343ms @16kHz)
	else	// pit_c >= MAX_SAM_CNT	(MAX_SAM_CNT <= 125)
	{
		*idr = 0.0f;
		if(150 > pit_c)
		{
			pit_c++;
		}
	}
}
#endif	// ifdef CPI_TUN

#ifdef CPI_AUT
/******************************************************************************
Function:		MC_CurPIAuto
Description:	creation of a voltage profile, used to automatically tune
				the current PIs
Input:			nothing
Output:			nothing
******************************************************************************/
void MC_CurPIAuto(	float32_t  idm, float32_t  iqm,
					float32_t *vdc, float32_t *vqc)
{
	PIT_SetCur(idm, iqm);
	switch(pitun_status)
	{
		case R_UP:		// voltage ramp up till current reaches rated value
			if(PIT_RampUp(&v_req))
			{
				pitun_status = R_MS;
			}
			break;
		case R_MS:		// wait some time, measuring the current level (filtered)
			if(PIT_Measure(&v_req))
			{
				pitun_status = R_DW;
			}
			break;
		case R_DW:		// voltage ramp down
			if(PIT_RampDown(&v_req))
			{
				pitun_status = R_ST;
			}
			break;
		case R_ST:		// voltage step
			if(PIT_VoltStep(&v_req))
			{
				pitun_status = R_EN;
			}
			break;		// finished
		case R_EN:
		default:
			v_req = 0.0f;
			break;
	}
	*vdc = v_req;
	*vqc = 0.0f;
}
#endif	// ifdef CPI_AUT

#ifdef MOT_IDENT
/******************************************************************************
Function:		MC_MotIdent
Description:	motor identification sequence
Input:			nothing
Output:			nothing
******************************************************************************/
void MC_MotIdent(	float32_t idm, float32_t iqm, float32_t vdm, float32_t vqm,
					float32_t *id, float32_t *iq, float32_t *om, float32_t *sp)
{

	*iq = 0.0f;
	MC_Ident_SetMea(idm, iqm, vdm, vqm, *om);

	if(0 > x_cnt)
	{
		x_cnt = 0;
	}
	else if(X_TIM1 >= x_cnt)	// id ramp up
	{
		if(*id < (ial_1 - ial_r))
		{
			*id += ial_r;
		}
		else
		{
			*id = ial_1;
		}
		*om = 0.0f;
		*sp = 0.0f;
	}
	else if(X_TIM2 > x_cnt)		// first measurement cycle
	{
		MC_Ident_UpdAcc();
		*id = ial_1;
		*om = 0.0f;
		*sp = 0.0f;
	}
	else if(X_TIM2 == x_cnt)	// first measurement acknowledge
	{
		MC_Ident_Step1();
		*id = ial_1;
		*om = 0.0f;
		*sp = 0.0f;
	}
	else if(X_TIM3 >= x_cnt)	// id ramp dw
	{
		if(*id > (ial_2 + ial_r))
		{
			*id -= ial_r;
		}
		else
		{
			*id = ial_2;
		}
		*om = 0.0f;
		*sp = 0.0f;
	}
	else if(X_TIM4 > x_cnt)		// second measurement cycle
	{
		MC_Ident_UpdAcc();
		*id = ial_2;
		*om = 0.0f;
		*sp = 0.0f;
	}
	else if(X_TIM4 == x_cnt)	// second measurement acknowledge
	{
		MC_Ident_Step2();
		*id = ial_2;
		*om = 0.0f;
		*sp = 0.0f;
	}
	else if(X_TIM5 >= x_cnt)	// speed ramp
	{
		*id = ial_2;
		if(*om < (iden_om - iden_or))
		{
			*om += iden_or;
		}
		else
		{
			*om = iden_om;
		}
		*sp = McrpLibf_AngleNrm(*sp + (*om * sam_per_s));
	}
	else if(X_TIM6 > x_cnt)		// third measurement cycle
	{
		MC_Ident_UpdAcc();
		*id = ial_2;
		*om = iden_om;
		*sp = McrpLibf_AngleNrm(*sp + (*om * sam_per_s));
	}
	else if(X_TIM6 == x_cnt)	// third measurement acknowledge
	{
		MC_Ident_Step3();
		*id = ial_2;
		*om = iden_om;
		*sp = McrpLibf_AngleNrm(*sp + (*om * sam_per_s));
	}
	else if(X_TIM7 >= x_cnt)	// id ramp dw
	{
		if(*id > (ial_3 + ial_r))
		{
			*id -= ial_r;
		}
		else
		{
			*id = ial_3;
		}
		*om = iden_om;
		*sp = McrpLibf_AngleNrm(*sp + (*om * sam_per_s));
	}
	else if(X_TIM8 > x_cnt)		// fourth measurement cycle
	{
		MC_Ident_UpdAcc();
		*id = ial_3;
		*om = iden_om;
		*sp = McrpLibf_AngleNrm(*sp + (*om * sam_per_s));
	}
	else if(X_TIM8 == x_cnt)	// fourth measurement acknowledge
	{
		MC_Ident_Step4();
		*id = 0.0f;
		*om = 0.0f;
		*sp = 0.0f;
	}
	else						// waiting end
	{
		*id = 0.0f;
		*om = 0.0f;
		*sp = 0.0f;
	}
	if(0x7FFFFFFF > x_cnt)
	{
		x_cnt++;
	}
}
#endif	// ifdef MOT_IDENT

/******************************************************************************
Function:		MC_WorkMan1
Description:	Working modes management function (speed ramps etc.)
Input:			nothing
Output:			nothing
Modifies:		internal speed reference
******************************************************************************/
void MC_WorkMan1(void)
{
	static int16_t	rif_mem;
	float32_t 		f32a;

	// alarm management
	if(0 != UIF_R.var.all)
	{
		MC_StopOut1();
		RES_STARTED1
		SET_STOPPED1
		RES_DECEL1
		rpmrif_x1 = 0.0f;
		rpmrif_y1 = 0.0f;
		omrif1 = 0.0f;
		omrif_abs1 = 0.0f;
		ramp1_status = STOP_0;
		if(MAX_ALL_CNT > all1_cnt)
		{
			++all1_cnt;
		}
		else if((FAULT1_ALL == UIF_R.var.all) || (TRIP1_ALL == UIF_R.var.all))
		{
			if(	((-0.9f < ref1) && (0.9f > ref1))		||
				(( 0.0f < ref1) && (0.0f > rif_mem))	||
				(( 0.0f > ref1) && (0.0f < rif_mem))	)
			{
				UIF_R.var.all = 0;
				RES_ALRM1_ON
			}
		}
		rif_mem = ref1;
		SET_NORM_MODE		// on alarm, normal mode is reestablished
		RES_STA_BSY
		SET_END_NOK
		RES_GUI_TRI
		RES_GUI_STP
		return;
	}
	all1_cnt = 0;
	rif_mem = ref1;

	if(MOT1_SEL)
	{
		// working mode requests management
		if(NOT_OUT1_ENA && NOT_OUT2_ENA && NOT_OUT3_ENA)	// all requests are taken into consideration only if COM_OFF
		{
#ifdef CPI_TUN
			if(CURPI_TUN_REQ)
			{
				SET_CURPI_TUN
			}
			else
#endif	// ifdef CPI_TUN
#ifdef CPI_AUT
			if(CURPI_AUT_REQ)
			{
				SET_CURPI_AUT
			}
			else
#endif	// ifdef CPI_AUT
#ifdef MOT_IDENT
			if(AUTO_IDEN_REQ)
			{
				SET_AUTO_IDEN
			}
#endif	// ifdef MOT_IDENT
			if(NOT_NORM_MODE)
			{
				RES_STARTED1
				SET_STOPPED1
				RES_DECEL1
				rpmrif_x1 = 0.0f;
				rpmrif_y1 = 0.0f;
				omrif1 = 0.0f;
				omrif_abs1 = 0.0f;
				ramp1_status = STOP_0;
				if(NORM_MODE_REQ)
				{
					UIF_R.var.kpi = KP_CUR1;
					UIF_R.var.kii = KI_CUR1;
					UIF_R.var.rs = R_STA1;
					UIF_R.var.ls = L_SQ1;
					UIF_R.var.fl = PM_FLX1;
					RES_STA_BSY
					SET_NORM_MODE
				}
			}
		}
#ifdef CPI_TUN
		// Manual current PI tuning mode (here normal eeprom parameters are used)
		if(CURPI_TUN)
		{
			if(NOT_OUT1_ENA)
			{
				if(GUI_TRI)
				{
					ratio = UIF_W.var.cra;		// ratio of maximum current
					if(0.0f > ratio)
					{
						ratio = 0.0f;
					}
					else if(1.0f < ratio)
					{
						ratio = 1.0f;
					}
					rbuf = ((uint16_t *)(outbuf.ss));
					wbuf = ((uint16_t *)(outbuf1.ss));
					pbuf = rbuf;
					pit_c = 0;
					SET_STA_BSY
					MC_StartOut1();
				}
			}
			else if(GUI_STP)
			{
				MC_StopOut1();
				SET_END_NOK
				RES_STA_BSY
			}
			else if(130 <= pit_c)	// 130 surely > MAX_SAM_CNT
			{
				MC_StopOut1();
				RES_END_NOK
				RES_STA_BSY
			}
			else
			{
				SET_STA_BSY
				MC_StartOut1();
			}
			RES_GUI_TRI
			RES_GUI_STP
			return;
		}
#endif	// ifdef CPI_TUN
#ifdef CPI_AUT
		// Automatic current PI tuning mode
		if(CURPI_AUT)
		{
			if(NOT_OUT1_ENA)
			{
				if(GUI_TRI)
				{
					PIT_IniVar(i_max1 * I_PIT_RATIO, vbusf1, sam_per_s);
					v_req = 0.0f;
					pitun_status = R_UP;
					SET_STA_BSY
					MC_StartOut1();
				}
			}
			else if(GUI_STP)
			{
				MC_StopOut1();
				SET_END_NOK
				RES_STA_BSY
			}
			else if(R_EN <= pitun_status)
			{
				MC_StopOut1();
				UIF_R.var.kpi = PIT_ReadKP();
				UIF_R.var.kii = sam_fre_Hz * PIT_ReadKI();	// identification returns directly the discrete time value in [Ohm], parameter is the continuous time value in [Ohm/sec]
				RES_END_NOK
				RES_STA_BSY
			}
			else
			{
				SET_STA_BSY
				MC_StartOut1();
			}
			RES_GUI_TRI
			RES_GUI_STP
			return;
		}
#endif	// ifdef CPI_AUT
#ifdef MOT_IDENT
		// Motor parameters auto identification mode
		if(AUTO_IDEN)
		{
			if(NOT_OUT1_ENA)
			{
				if(GUI_TRI)
				{
					INI_IDENT
					SET_STA_BSY
					MC_StartOut1();
				}
			}
			else if(GUI_STP)
			{
				MC_StopOut1();
				SET_END_NOK
				RES_STA_BSY
			}
			else if(IDENT_ENDED)
			{
				MC_StopOut1();
				MC_Ident_CalMotPar(&iden_rs, &iden_ls, &iden_fl);
				UIF_R.var.rs = iden_rs;
				UIF_R.var.ls = iden_ls;
				UIF_R.var.fl = iden_fl;
				RES_END_NOK
				RES_STA_BSY
			}
			else
			{
				SET_STA_BSY
				MC_StartOut1();
			}
			RES_GUI_TRI
			RES_GUI_STP
			return;
		}
#endif	// ifdef MOT_IDENT
		// From here normal mode management
		RES_END_NOK
	}	// if(MOT1_SEL)

	// preliminary reference management
	f32a = ref1;
	if(rpm_min1 <= f32a)
	{
		if(rpm_max1 < f32a)
		{
			f32a = rpm_max1;
		}
	}
	else if(-rpm_min1 >= f32a)
	{
		if(-rpm_max1 > f32a)
		{
			f32a = -rpm_max1;
		}
	}
	else
	{
		f32a = 0.0f;
	}

	// ramp management state-machine
	switch(ramp1_status)
	{
		case START_P:
			RES_STOPPED1
			RES_DECEL1
			MC_StartOut1();
			rpmrif_x1 = rpm_min1;
			rpmrif_y1 = rpm_min1;
			if(f32a < rpm_min1)
			{
				ramp1_status = STOP_W;
				if(-rpm_min1 >= f32a)
				{
					rpmrif_x1 = -rpm_min1;
				}
				else
				{
					rpmrif_x1 = 0.0f;
				}
				break;
			}
			else if(NOT_STARTED1)
			{
				break;
			}
			ramp1_status = GO_P;
			break;
		case GO_P:
			RES_STOPPED1
			MC_StartOut1();
			if(f32a < rpm_min1)
			{
				if(rpmrif_y1 <= rpm_min1)
				{
					rpmrif_y1 = 0.0f;
					ramp1_status = STOP_W;
					if(-rpm_min1 >= f32a)
					{
						rpmrif_x1 = -rpm_min1;
					}
					else
					{
						rpmrif_x1 = 0.0f;
					}
					break;
				}
				rpmrif_x1 = rpm_min1;
			}
			else
			{
				rpmrif_x1 = f32a;
			}
			f32a = rpmrif_y1;
			if(f32a < (rpmrif_x1 - r_acc1))
			{
				RES_DECEL1
				f32a += r_acc1;
			}
			else if(f32a > (rpmrif_x1 + r_dec1))
			{
				SET_DECEL1
				if(NOT_RAMPLIM1)
				{
					f32a -= r_dec1;
				}
			}
			else
			{
				RES_DECEL1
				f32a = rpmrif_x1;
			}
			rpmrif_y1 = f32a;
			break;
		case START_N:
			RES_STOPPED1
			RES_DECEL1
			MC_StartOut1();
			rpmrif_x1 = -rpm_min1;
			rpmrif_y1 = -rpm_min1;
			if(-rpm_min1 < f32a)
			{
				ramp1_status = STOP_W;
				if(f32a >= rpm_min1)
				{
					rpmrif_x1 = rpm_min1;
				}
				else
				{
					rpmrif_x1 = 0.0f;
				}
				break;
			}
			else if(NOT_STARTED1)
			{
				break;
			}
			ramp1_status = GO_N;
			break;
		case GO_N:
			RES_STOPPED1
			MC_StartOut1();
			if(-rpm_min1 < f32a)
			{
				if(-rpm_min1 <= rpmrif_y1)
				{
					rpmrif_y1 = 0.0f;
					ramp1_status = STOP_W;
					if(f32a >= rpm_min1)
					{
						rpmrif_x1 = rpm_min1;
					}
					else
					{
						rpmrif_x1 = 0.0f;
					}
					break;
				}
				rpmrif_x1 = -rpm_min1;
			}
			else
			{
				rpmrif_x1 = f32a;
			}
			f32a = rpmrif_y1;
			if(f32a > (rpmrif_x1 + r_acc1))
			{
				RES_DECEL1
				f32a -= r_acc1;
			}
			else if(f32a < (rpmrif_x1 - r_dec1))
			{
				SET_DECEL1
				if(NOT_RAMPLIM1)
				{
					f32a += r_dec1;
				}
			}
			else
			{
				RES_DECEL1
				f32a = rpmrif_x1;
			}
			rpmrif_y1 = f32a;
			break;
		case STOP_W:
			RES_STARTED1
			RES_DECEL1
			rpmrif_y1 = 0.0f;
			MC_StartOut1();
			if(f32a >= rpm_min1)
			{
				rpmrif_x1 = rpm_min1;
				if(STOPPED1)
				{
					ramp1_status = START_P;
				}
			}
			else if(-rpm_min1 >= f32a)
			{
				rpmrif_x1 = -rpm_min1;
				if(STOPPED1)
				{
					ramp1_status = START_N;
				}
			}
			else
			{
				rpmrif_x1 = 0.0f;
				if(STOPPED1)
				{
					ramp1_status = STOP_0;
				}
			}
			break;
		case STOP_0:
		default:
			MC_StopOut1();
			SET_STOPPED1
			RES_STARTED1
			RES_DECEL1
			rpmrif_x1 = 0.0f;
			rpmrif_y1 = 0.0f;
			if(f32a >= rpm_min1)
			{
				ramp1_status = START_P;
			}
			else if(-rpm_min1 >= f32a)
			{
				ramp1_status = START_N;
			}
			else
			{
				ramp1_status = STOP_0;
			}
			break;
	}

	// ramp output update and conversion in rad/sec
	omrif1 = rpmrif_y1 * krpmocp1;
	omrif_abs1 = (0.0f > omrif1? -omrif1: omrif1);
}

/******************************************************************************
Function:		MC_WorkMan2
Description:	Working modes management function (speed ramps etc.)
Input:			nothing
Output:			nothing
Modifies:		internal speed reference
******************************************************************************/
void MC_WorkMan2(void)
{
	static int16_t	rif_mem;
	float32_t 		f32a;

	// alarm management
	if(0 != UIF_R.var.all)
	{
		MC_StopOut2();
		RES_STARTED2
		SET_STOPPED2
		RES_DECEL2
		rpmrif_x2 = 0.0f;
		rpmrif_y2 = 0.0f;
		omrif2 = 0.0f;
		omrif_abs2 = 0.0f;
		ramp2_status = STOP_0;
		if(MAX_ALL_CNT > all2_cnt)
		{
			++all2_cnt;
		}
		else if((FAULT2_ALL == UIF_R.var.all) || (TRIP2_ALL == UIF_R.var.all))
		{
			if(	((-0.9f < ref2) && (0.9f > ref2))		||
				(( 0.0f < ref2) && (0.0f > rif_mem))	||
				(( 0.0f > ref2) && (0.0f < rif_mem))	)
			{
				UIF_R.var.all = 0;
				RES_ALRM2_ON
			}
		}
		rif_mem = ref2;
		SET_NORM_MODE		// on alarm, normal mode is reestablished
		RES_STA_BSY
		SET_END_NOK
		RES_GUI_TRI
		RES_GUI_STP
		return;
	}
	all2_cnt = 0;
	rif_mem = ref2;

	if(MOT2_SEL)
	{
		// working mode requests management
		if(NOT_OUT1_ENA && NOT_OUT2_ENA && NOT_OUT3_ENA)	// all requests are taken into consideration only if COM_OFF
		{
#ifdef CPI_TUN
			if(CURPI_TUN_REQ)
			{
				SET_CURPI_TUN
			}
			else
#endif	// ifdef CPI_TUN
#ifdef CPI_AUT
			if(CURPI_AUT_REQ)
			{
				SET_CURPI_AUT
			}
			else
#endif	// ifdef CPI_AUT
#ifdef MOT_IDENT
			if(AUTO_IDEN_REQ)
			{
				SET_AUTO_IDEN
			}
#endif	// ifdef MOT_IDENT
			if(NOT_NORM_MODE)
			{
				RES_STARTED2
				SET_STOPPED2
				RES_DECEL2
				rpmrif_x2 = 0.0f;
				rpmrif_y2 = 0.0f;
				omrif2 = 0.0f;
				omrif_abs2 = 0.0f;
				ramp2_status = STOP_0;
				if(NORM_MODE_REQ)
				{
					UIF_R.var.kpi = KP_CUR2;
					UIF_R.var.kii = KI_CUR2;
					UIF_R.var.rs = R_STA2;
					UIF_R.var.ls = L_SQ2;
					UIF_R.var.fl = PM_FLX2;
					RES_STA_BSY
					SET_NORM_MODE
				}
			}
		}
#ifdef CPI_TUN
		// Manual current PI tuning mode (here normal eeprom parameters are used)
		if(CURPI_TUN)
		{
			if(NOT_OUT2_ENA)
			{
				if(GUI_TRI)
				{
					ratio = UIF_W.var.cra;		// ratio of maximum current
					if(0.0f > ratio)
					{
						ratio = 0.0f;
					}
					else if(1.0f < ratio)
					{
						ratio = 1.0f;
					}
					rbuf = ((uint16_t *)(outbuf.ss));
					wbuf = ((uint16_t *)(outbuf1.ss));
					pbuf = rbuf;
					pit_c = 0;
					SET_STA_BSY
					MC_StartOut2();
				}
			}
			else if(GUI_STP)
			{
				MC_StopOut2();
				SET_END_NOK
				RES_STA_BSY
			}
			else if(130 <= pit_c)	// 130 surely > MAX_SAM_CNT
			{
				MC_StopOut2();
				RES_END_NOK
				RES_STA_BSY
			}
			else
			{
				SET_STA_BSY
				MC_StartOut2();
			}
			RES_GUI_TRI
			RES_GUI_STP
			return;
		}
#endif	// ifdef CPI_TUN
#ifdef CPI_AUT
		// Automatic current PI tuning mode
		if(CURPI_AUT)
		{
			if(NOT_OUT2_ENA)
			{
				if(GUI_TRI)
				{
					PIT_IniVar(i_max2 * I_PIT_RATIO, vbusf2, sam_per_s);
					v_req = 0.0f;
					pitun_status = R_UP;
					SET_STA_BSY
					MC_StartOut2();
				}
			}
			else if(GUI_STP)
			{
				MC_StopOut2();
				SET_END_NOK
				RES_STA_BSY
			}
			else if(R_EN <= pitun_status)
			{
				MC_StopOut2();
				UIF_R.var.kpi = PIT_ReadKP();
				UIF_R.var.kii = sam_fre_Hz * PIT_ReadKI();	// identification returns directly the discrete time value in [Ohm], parameter is the continuous time value in [Ohm/sec]
				RES_END_NOK
				RES_STA_BSY
			}
			else
			{
				SET_STA_BSY
				MC_StartOut2();
			}
			RES_GUI_TRI
			RES_GUI_STP
			return;
		}
#endif	// ifdef CPI_AUT
#ifdef MOT_IDENT
		// Motor parameters auto identification mode
		if(AUTO_IDEN)
		{
			if(NOT_OUT2_ENA)
			{
				if(GUI_TRI)
				{
					INI_IDENT
					SET_STA_BSY
					MC_StartOut2();
				}
			}
			else if(GUI_STP)
			{
				MC_StopOut2();
				SET_END_NOK
				RES_STA_BSY
			}
			else if(IDENT_ENDED)
			{
				MC_StopOut2();
				MC_Ident_CalMotPar(&iden_rs, &iden_ls, &iden_fl);
				UIF_R.var.rs = iden_rs;
				UIF_R.var.ls = iden_ls;
				UIF_R.var.fl = iden_fl;
				RES_END_NOK
				RES_STA_BSY
			}
			else
			{
				SET_STA_BSY
				MC_StartOut2();
			}
			RES_GUI_TRI
			RES_GUI_STP
			return;
		}
#endif	// ifdef MOT_IDENT
		// From here normal mode management
		RES_END_NOK
	}	// if(MOT2_SEL)

	// preliminary reference management
	f32a = ref2;
	if(rpm_min2 <= f32a)
	{
		if(rpm_max2 < f32a)
		{
			f32a = rpm_max2;
		}
	}
	else if(-rpm_min2 >= f32a)
	{
		if(-rpm_max2 > f32a)
		{
			f32a = -rpm_max2;
		}
	}
	else
	{
		f32a = 0.0f;
	}

	// ramp management state-machine
	switch(ramp2_status)
	{
		case START_P:
			RES_STOPPED2
			RES_DECEL2
			MC_StartOut2();
			rpmrif_x2 = rpm_min2;
			rpmrif_y2 = rpm_min2;
			if(f32a < rpm_min2)
			{
				ramp2_status = STOP_W;
				if(-rpm_min2 >= f32a)
				{
					rpmrif_x2 = -rpm_min2;
				}
				else
				{
					rpmrif_x2 = 0.0f;
				}
				break;
			}
			else if(NOT_STARTED2)
			{
				break;
			}
			ramp2_status = GO_P;
			break;
		case GO_P:
			RES_STOPPED2
			MC_StartOut2();
			if(f32a < rpm_min2)
			{
				if(rpmrif_y2 <= rpm_min2)
				{
					rpmrif_y2 = 0.0f;
					ramp2_status = STOP_W;
					if(-rpm_min2 >= f32a)
					{
						rpmrif_x2 = -rpm_min2;
					}
					else
					{
						rpmrif_x2 = 0.0f;
					}
					break;
				}
				rpmrif_x2 = rpm_min2;
			}
			else
			{
				rpmrif_x2 = f32a;
			}
			f32a = rpmrif_y2;
			if(f32a < (rpmrif_x2 - r_acc2))
			{
				RES_DECEL2
				f32a += r_acc2;
			}
			else if(f32a > (rpmrif_x2 + r_dec2))
			{
				SET_DECEL2
				if(NOT_RAMPLIM2)
				{
					f32a -= r_dec2;
				}
			}
			else
			{
				RES_DECEL2
				f32a = rpmrif_x2;
			}
			rpmrif_y2 = f32a;
			break;
		case START_N:
			RES_STOPPED2
			RES_DECEL2
			MC_StartOut2();
			rpmrif_x2 = -rpm_min2;
			rpmrif_y2 = -rpm_min2;
			if(-rpm_min2 < f32a)
			{
				ramp2_status = STOP_W;
				if(f32a >= rpm_min2)
				{
					rpmrif_x2 = rpm_min2;
				}
				else
				{
					rpmrif_x2 = 0.0f;
				}
				break;
			}
			else if(NOT_STARTED2)
			{
				break;
			}
			ramp2_status = GO_N;
			break;
		case GO_N:
			RES_STOPPED2
			MC_StartOut2();
			if(-rpm_min2 < f32a)
			{
				if(-rpm_min2 <= rpmrif_y2)
				{
					rpmrif_y2 = 0.0f;
					ramp2_status = STOP_W;
					if(f32a >= rpm_min2)
					{
						rpmrif_x2 = rpm_min2;
					}
					else
					{
						rpmrif_x2 = 0.0f;
					}
					break;
				}
				rpmrif_x2 = -rpm_min2;
			}
			else
			{
				rpmrif_x2 = f32a;
			}
			f32a = rpmrif_y2;
			if(f32a > (rpmrif_x2 + r_acc2))
			{
				RES_DECEL2
				f32a -= r_acc2;
			}
			else if(f32a < (rpmrif_x2 - r_dec2))
			{
				SET_DECEL2
				if(NOT_RAMPLIM2)
				{
					f32a += r_dec2;
				}
			}
			else
			{
				RES_DECEL2
				f32a = rpmrif_x2;
			}
			rpmrif_y2 = f32a;
			break;
		case STOP_W:
			RES_STARTED2
			RES_DECEL2
			rpmrif_y2 = 0.0f;
			MC_StartOut2();
			if(f32a >= rpm_min2)
			{
				rpmrif_x2 = rpm_min2;
				if(STOPPED2)
				{
					ramp2_status = START_P;
				}
			}
			else if(-rpm_min2 >= f32a)
			{
				rpmrif_x2 = -rpm_min2;
				if(STOPPED2)
				{
					ramp2_status = START_N;
				}
			}
			else
			{
				rpmrif_x2 = 0.0f;
				if(STOPPED2)
				{
					ramp2_status = STOP_0;
				}
			}
			break;
		case STOP_0:
		default:
			MC_StopOut2();
			SET_STOPPED2
			RES_STARTED2
			RES_DECEL2
			rpmrif_x2 = 0.0f;
			rpmrif_y2 = 0.0f;
			if(f32a >= rpm_min2)
			{
				ramp2_status = START_P;
			}
			else if(-rpm_min2 >= f32a)
			{
				ramp2_status = START_N;
			}
			else
			{
				ramp2_status = STOP_0;
			}
			break;
	}

	// ramp output update and conversion in rad/sec
	omrif2 = rpmrif_y2 * krpmocp2;
	omrif_abs2 = (0.0f > omrif2? -omrif2: omrif2);
}

/******************************************************************************
Function:		MC_WorkMan3
Description:	Working modes management function (speed ramps etc.)
Input:			nothing
Output:			nothing
Modifies:		internal speed reference
******************************************************************************/
void MC_WorkMan3(void)
{
	static int16_t	rif_mem;
	float32_t 		f32a;

	// alarm management
	if(0 != UIF_R.var.all)
	{
		MC_StopOut3();
		RES_STARTED3
		SET_STOPPED3
		RES_DECEL3
		rpmrif_x3 = 0.0f;
		rpmrif_y3 = 0.0f;
		omrif3 = 0.0f;
		omrif_abs3 = 0.0f;
		ramp3_status = STOP_0;
		if(MAX_ALL_CNT > all3_cnt)
		{
			++all3_cnt;
		}
		if((FAULT3_ALL == UIF_R.var.all) || (TRIP3_ALL == UIF_R.var.all))
		{
			if(	((-0.9f < ref3) && (0.9f > ref3))		||
				(( 0.0f < ref3) && (0.0f > rif_mem))	||
				(( 0.0f > ref3) && (0.0f < rif_mem))	)
			{
				UIF_R.var.all = 0;
				RES_ALRM3_ON
			}
		}
		rif_mem = ref3;
		SET_NORM_MODE		// on alarm, normal mode is reestablished
		RES_STA_BSY
		SET_END_NOK
		RES_GUI_TRI
		RES_GUI_STP
		return;
	}
	all3_cnt = 0;
	rif_mem = ref3;

	if(MOT3_SEL)
	{
		// working mode requests management
		if(NOT_OUT1_ENA && NOT_OUT2_ENA && NOT_OUT3_ENA)	// all requests are taken into consideration only if COM_OFF
		{
#ifdef CPI_TUN
			if(CURPI_TUN_REQ)
			{
				SET_CURPI_TUN
			}
			else
#endif	// ifdef CPI_TUN
#ifdef CPI_AUT
			if(CURPI_AUT_REQ)
			{
				SET_CURPI_AUT
			}
			else
#endif	// ifdef CPI_AUT
#ifdef MOT_IDENT
			if(AUTO_IDEN_REQ)
			{
				SET_AUTO_IDEN
			}
#endif	// ifdef MOT_IDENT
			if(NOT_NORM_MODE)
			{
				RES_STARTED3
				SET_STOPPED3
				RES_DECEL3
				rpmrif_x3 = 0.0f;
				rpmrif_y3 = 0.0f;
				omrif3 = 0.0f;
				omrif_abs3 = 0.0f;
				ramp3_status = STOP_0;
				if(NORM_MODE_REQ)
				{
					UIF_R.var.kpi = KP_CUR3;
					UIF_R.var.kii = KI_CUR3;
					UIF_R.var.rs = R_STA3;
					UIF_R.var.ls = L_SQ3;
					UIF_R.var.fl = PM_FLX3;
					RES_STA_BSY
					SET_NORM_MODE
				}
			}
		}
#ifdef CPI_TUN
		// Manual current PI tuning mode (here normal eeprom parameters are used)
		if(CURPI_TUN)
		{
			if(NOT_OUT3_ENA)
			{
				if(GUI_TRI)
				{
					ratio = UIF_W.var.cra;		// ratio of maximum current
					if(0.0f > ratio)
					{
						ratio = 0.0f;
					}
					else if(1.0f < ratio)
					{
						ratio = 1.0f;
					}
					rbuf = ((uint16_t *)(outbuf.ss));
					wbuf = ((uint16_t *)(outbuf1.ss));
					pbuf = rbuf;
					pit_c = 0;
					SET_STA_BSY
					MC_StartOut3();
				}
			}
			else if(GUI_STP)
			{
				MC_StopOut3();
				SET_END_NOK
				RES_STA_BSY
			}
			else if(130 <= pit_c)	// 130 surely > MAX_SAM_CNT
			{
				MC_StopOut3();
				RES_END_NOK
				RES_STA_BSY
			}
			else
			{
				SET_STA_BSY
				MC_StartOut3();
			}
			RES_GUI_TRI
			RES_GUI_STP
			return;
		}
#endif	// ifdef CPI_TUN
#ifdef CPI_AUT
		// Automatic current PI tuning mode
		if(CURPI_AUT)
		{
			if(NOT_OUT3_ENA)
			{
				if(GUI_TRI)
				{
					PIT_IniVar(i_max3 * I_PIT_RATIO, vbusf3, sam_per_s);
					v_req = 0.0f;
					pitun_status = R_UP;
					SET_STA_BSY
					MC_StartOut3();
				}
			}
			else if(GUI_STP)
			{
				MC_StopOut3();
				SET_END_NOK
				RES_STA_BSY
			}
			else if(R_EN <= pitun_status)
			{
				MC_StopOut3();
				UIF_R.var.kpi = PIT_ReadKP();
				UIF_R.var.kii = sam_fre_Hz * PIT_ReadKI();	// identification returns directly the discrete time value in [Ohm], parameter is the continuous time value in [Ohm/sec]
				RES_END_NOK
				RES_STA_BSY
			}
			else
			{
				SET_STA_BSY
				MC_StartOut3();
			}
			RES_GUI_TRI
			RES_GUI_STP
			return;
		}
#endif	// ifdef CPI_AUT
#ifdef MOT_IDENT
		// Motor parameters auto identification mode
		if(AUTO_IDEN)
		{
			if(NOT_OUT3_ENA)
			{
				if(GUI_TRI)
				{
					INI_IDENT
					SET_STA_BSY
					MC_StartOut3();
				}
			}
			else if(GUI_STP)
			{
				MC_StopOut3();
				SET_END_NOK
				RES_STA_BSY
			}
			else if(IDENT_ENDED)
			{
				MC_StopOut3();
				MC_Ident_CalMotPar(&iden_rs, &iden_ls, &iden_fl);
				UIF_R.var.rs = iden_rs;
				UIF_R.var.ls = iden_ls;
				UIF_R.var.fl = iden_fl;
				RES_END_NOK
				RES_STA_BSY
			}
			else
			{
				SET_STA_BSY
				MC_StartOut3();
			}
			RES_GUI_TRI
			RES_GUI_STP
			return;
		}
#endif	// ifdef MOT_IDENT
		// From here normal mode management
		RES_END_NOK
	}	// if(MOT3_SEL)

	// preliminary reference management
	f32a = ref3;
	if(rpm_min3 <= f32a)
	{
		if(rpm_max3 < f32a)
		{
			f32a = rpm_max3;
		}
	}
	else if(-rpm_min3 >= f32a)
	{
		if(-rpm_max3 > f32a)
		{
			f32a = -rpm_max3;
		}
	}
	else
	{
		f32a = 0.0f;
	}

	// ramp management state-machine
	switch(ramp3_status)
	{
		case START_P:
			RES_STOPPED3
			RES_DECEL3
			MC_StartOut3();
			rpmrif_x3 = rpm_min3;
			rpmrif_y3 = rpm_min3;
			if(f32a < rpm_min3)
			{
				ramp3_status = STOP_W;
				if(-rpm_min3 >= f32a)
				{
					rpmrif_x3 = -rpm_min3;
				}
				else
				{
					rpmrif_x3 = 0.0f;
				}
				break;
			}
			else if(NOT_STARTED3)
			{
				break;
			}
			ramp3_status = GO_P;
			break;
		case GO_P:
			RES_STOPPED3
			MC_StartOut3();
			if(f32a < rpm_min3)
			{
				if(rpmrif_y3 <= rpm_min3)
				{
					rpmrif_y3 = 0.0f;
					ramp3_status = STOP_W;
					if(-rpm_min3 >= f32a)
					{
						rpmrif_x3 = -rpm_min3;
					}
					else
					{
						rpmrif_x3 = 0.0f;
					}
					break;
				}
				rpmrif_x3 = rpm_min3;
			}
			else
			{
				rpmrif_x3 = f32a;
			}
			f32a = rpmrif_y3;
			if(f32a < (rpmrif_x3 - r_acc3))
			{
				RES_DECEL3
				f32a += r_acc3;
			}
			else if(f32a > (rpmrif_x3 + r_dec3))
			{
				SET_DECEL3
				if(NOT_RAMPLIM3)
				{
					f32a -= r_dec3;
				}
			}
			else
			{
				RES_DECEL3
				f32a = rpmrif_x3;
			}
			rpmrif_y3 = f32a;
			break;
		case START_N:
			RES_STOPPED3
			RES_DECEL3
			MC_StartOut3();
			rpmrif_x3 = -rpm_min3;
			rpmrif_y3 = -rpm_min3;
			if(-rpm_min3 < f32a)
			{
				ramp3_status = STOP_W;
				if(f32a >= rpm_min3)
				{
					rpmrif_x3 = rpm_min3;
				}
				else
				{
					rpmrif_x3 = 0.0f;
				}
				break;
			}
			else if(NOT_STARTED3)
			{
				break;
			}
			ramp3_status = GO_N;
			break;
		case GO_N:
			RES_STOPPED3
			MC_StartOut3();
			if(-rpm_min3 < f32a)
			{
				if(-rpm_min3 <= rpmrif_y3)
				{
					rpmrif_y3 = 0.0f;
					ramp3_status = STOP_W;
					if(f32a >= rpm_min3)
					{
						rpmrif_x3 = rpm_min3;
					}
					else
					{
						rpmrif_x3 = 0.0f;
					}
					break;
				}
				rpmrif_x3 = -rpm_min3;
			}
			else
			{
				rpmrif_x3 = f32a;
			}
			f32a = rpmrif_y3;
			if(f32a > (rpmrif_x3 + r_acc3))
			{
				RES_DECEL3
				f32a -= r_acc3;
			}
			else if(f32a < (rpmrif_x3 - r_dec3))
			{
				SET_DECEL3
				if(NOT_RAMPLIM3)
				{
					f32a += r_dec3;
				}
			}
			else
			{
				RES_DECEL3
				f32a = rpmrif_x3;
			}
			rpmrif_y3 = f32a;
			break;
		case STOP_W:
			RES_STARTED3
			RES_DECEL3
			rpmrif_y3 = 0.0f;
			MC_StartOut3();
			if(f32a >= rpm_min3)
			{
				rpmrif_x3 = rpm_min3;
				if(STOPPED3)
				{
					ramp3_status = START_P;
				}
			}
			else if(-rpm_min3 >= f32a)
			{
				rpmrif_x3 = -rpm_min3;
				if(STOPPED3)
				{
					ramp3_status = START_N;
				}
			}
			else
			{
				rpmrif_x3 = 0.0f;
				if(STOPPED3)
				{
					ramp3_status = STOP_0;
				}
			}
			break;
		case STOP_0:
		default:
			MC_StopOut3();
			SET_STOPPED3
			RES_STARTED3
			RES_DECEL3
			rpmrif_x3 = 0.0f;
			rpmrif_y3 = 0.0f;
			if(f32a >= rpm_min3)
			{
				ramp3_status = START_P;
			}
			else if(-rpm_min3 >= f32a)
			{
				ramp3_status = START_N;
			}
			else
			{
				ramp3_status = STOP_0;
			}
			break;
	}

	// ramp output update and conversion in rad/sec
	omrif3 = rpmrif_y3 * krpmocp3;
	omrif_abs3 = (0.0f > omrif3? -omrif3: omrif3);
}

/******************************************************************************
Function:		MC_WorkMan
Description:	Working modes management function (speed ramps etc.)
Input:			nothing
Output:			nothing
Modifies:		internal speed reference
******************************************************************************/
void MC_WorkMan(void)
{
	if(MOT1_SEL)
	{
		ref1 = UIF_W.var.rif;
		ref2 = 0;
		ref3 = 0;
	}
	else if(MOT2_SEL)
	{
		ref1 = 0;
		ref2 = UIF_W.var.rif;
		ref3 = 0;
	}
	else if(MOT3_SEL)
	{
		ref1 = 0;
		ref2 = 0;
		ref3 = UIF_W.var.rif;
	}
	else if(MOTA_SEL)
	{
		ref1 = UIF_W.var.rif;
		ref2 = UIF_W.var.rif;
		ref3 = UIF_W.var.rif;
	}
	MC_WorkMan1();
	MC_WorkMan2();
	MC_WorkMan3();
}

/******************************************************************************
Function:		MC_FluxWeak
Description:	flux weakening algorithm
Input:			voltage margin vmf,
				maximum current direct imax,
				reference current direct iref
				new direct current reference address i
Output:			nothing
Modifies:		new direct current reference *i
******************************************************************************/
void MC_FluxWeak(	float32_t vmf, float32_t imax, float32_t iref, float32_t *i,
					float32_t vbu, float32_t hvb, float32_t rdw, float32_t rup)
{

	if((hvb < vbu) || (0.0f > vmf))
	{
		if(-imax < (*i))
		{
			(*i) =  (*i) - rdw;
		}
	}
	else if((*i) > (iref + rdw))
	{
		(*i) = (*i) - rdw;
	}
	else if((*i) < (iref - rup))
	{
		(*i) = (*i) + rup;
	}
	else
	{
		(*i) = iref;
	}
}

#ifdef TRIP_CONTROL1
/******************************************************************************
Function:		MC_TripCon1
Description:	loosing of control of the phase estimation algorithm check
Input:			nothing
Output:			nothing
Note:			uses some global variables
Modifies:		global alarm, if needed
******************************************************************************/
void MC_TripCon1(void)
{
	if(3 < startup_cnt1)
	{
		if(MAX_TRIP <= trip1_cnt)
		{
			MC_StopOut1();
			UIF_R.var.all = TRIP1_ALL;
			SET_ALRM1_ON
			trip1_cnt = 0;
		}
		else if(GO_P == ramp1_status)
		{
			if((Speed_est1 < min_speed_trip1) || (Speed_est1 > max_speed_trip1))
			{
				trip1_cnt += 1;
			}
			else if(1 < trip1_cnt)
			{
				trip1_cnt -= 2;
			}
		}
		else if(GO_N == ramp1_status)
		{
			if((-min_speed_trip1 < Speed_est1) || (-max_speed_trip1 > Speed_est1))
			{
				trip1_cnt += 1;
			}
			else if(1 < trip1_cnt)
			{
				trip1_cnt -= 2;
			}
		}
	}
	else
	{
		trip1_cnt = 0;
	}
}
#endif	// ifdef TRIP_CONTROL1

#ifdef TRIP_CONTROL2
/******************************************************************************
Function:		MC_TripCon2
Description:	loosing of control of the phase estimation algorithm check
Input:			nothing
Output:			nothing
Note:			uses some global variables
Modifies:		global alarm, if needed
******************************************************************************/
void MC_TripCon2(void)
{
	if(3 < startup_cnt2)
	{
		if(MAX_TRIP <= trip2_cnt)
		{
			MC_StopOut2();
			UIF_R.var.all = TRIP2_ALL;
			SET_ALRM2_ON
			trip2_cnt = 0;
		}
		else if(GO_P == ramp2_status)
		{
			if((Speed_est2 < min_speed_trip2) || (Speed_est2 > max_speed_trip2))
			{
				trip2_cnt += 1;
			}
			else if(1 < trip2_cnt)
			{
				trip2_cnt -= 2;
			}
		}
		else if(GO_N == ramp2_status)
		{
			if((-min_speed_trip2 < Speed_est2) || (-max_speed_trip2 > Speed_est2))
			{
				trip2_cnt += 1;
			}
			else if(1 < trip2_cnt)
			{
				trip2_cnt -= 2;
			}
		}
	}
	else
	{
		trip2_cnt = 0;
	}
}
#endif	// ifdef TRIP_CONTROL2

#ifdef TRIP_CONTROL3
/******************************************************************************
Function:		MC_TripCon3
Description:	loosing of control of the phase estimation algorithm check
Input:			nothing
Output:			nothing
Note:			uses some global variables
Modifies:		global alarm, if needed
******************************************************************************/
void MC_TripCon3(void)
{
	if(3 < startup_cnt3)
	{
		if(MAX_TRIP <= trip3_cnt)
		{
			MC_StopOut3();
			UIF_R.var.all = TRIP3_ALL;
			SET_ALRM3_ON
			trip3_cnt = 0;
		}
		else if(GO_P == ramp3_status)
		{
			if((Speed_est3 < min_speed_trip3) || (Speed_est3 > max_speed_trip3))
			{
				trip3_cnt += 1;
			}
			else if(1 < trip3_cnt)
			{
				trip3_cnt -= 2;
			}
		}
		else if(GO_N == ramp3_status)
		{
			if((-min_speed_trip3 < Speed_est3) || (-max_speed_trip3 > Speed_est3))
			{
				trip3_cnt += 1;
			}
			else if(1 < trip3_cnt)
			{
				trip3_cnt -= 2;
			}
		}
	}
	else
	{
		trip3_cnt = 0;
	}
}
#endif	// ifdef TRIP_CONTROL3

/******************************************************************************
Function:		MC_ConInt1
Description:	control interrupt
Input:			nothing
Output:			nothing
Note:			this function is called every sampling instant, and performs
           		the motor control
******************************************************************************/
void MC_ConInt1(void)
{
	float32_t	f32a;

	IR(S12AD, S12ADI) = 0;		// reset interrupt request

	SET_LD1						// debug

	// enables higher priority interrupts (serial communication)
//	set_ipl(SCI_INT_P - 1);
	setpsw_i();					// enables other interrupts

	// triggered A/D conversions management (currents and bus voltage)
	MC_ADMan1();				// modifies the global variables ium, ivm, iwm, iam, ibm. vbus

	// check POE flags
	MC_CheckPOEFlags1();

	if(COM1_ON)
	{
		// current transformations (previous angle)
		McrpLibf_alphabeta_dq1(iam1, ibm1, &idm1, &iqm1);

		// voltage measurements (related to currents measurements)
		vam1 = vax1;
		vbm1 = vbx1;
		vdm1 = vdx1;
		vqm1 = vqx1;
	}	// if(COM1_ON)
	else
	{
		iqm1 = idm1 = 0.0f;
		vbm1 = vam1 = 0.0f;
		vqm1 = vdm1 = 0.0f;
	}

	// angle management
	McrpLibf_AngleSet1(SystemPhase1);	// from here new angle (sin and cos) (conversions etc.)

	// voltages references and duty cycles calc
	if(COM1_ON)
	{

#ifdef CPI_AUT
		if(MOT1_SEL && CURPI_AUT)
		{
			idr1 = iqr1 = 0;
			MC_CurPIAuto(idm1, iqm1, &vdc1, &vqc1);
		}	// if(CURPI_AUT)
		else
#endif	// ifdef CPI_AUT
		{	// normal case: idr, iqr come from previous cycle

			// current PI controls
			MC_IdIqPI(idr1, idm1, iqr1, iqm1, vfmax1, kp_cur1, ki_cur1, &vdc1, &vqc1, &idint1, &iqint1);
		}	// end of normal case

		// voltage transformations (actual angle)
		McrpLibf_dq_alphabeta1(vdc1, vqc1, &vac1, &vbc1);
		McrpLibf_alphabeta_uv(vac1, vbc1, &vuc1, &vvc1);
		vwc1 = -vuc1 - vvc1;

		// pwm output generation
		MC_PWMGen1();

		// pwm output registers setting (HERE WE SHOULD BE BEFORE PWM CREST!)
		SET_PWM1(duty1_u, duty1_v, duty1_w)

		// output voltages in (alpha, beta) frame update after modulation clamping
		McrpLibf_uvw_alphabeta(vux1, vvx1, vwx1, &vax1, &vbx1);
		McrpLibf_alphabeta_dq1(vax1, vbx1, &vdx1, &vqx1);

	}
	else	// else of if(COM1_ON)
	{
		iqint1 = idint1 = 0.0f;
		vqc1 = vdc1 = 0.0f;
		vbc1 = vac1 = 0.0f;
		vwc1 = vvc1 = vuc1 = 0.0f;
		vqx1 = vdx1 = 0.0f;
		vbx1 = vax1 = 0.0f;
		vwx1 = vvx1 = vux1 = 0.0f;
		duty1_u = duty1_v = duty1_w = halfperdead1;

		// pwm output registers setting (if outputs enabled, this means the lower arm always on (used for BOOTSTRAP))
		SET_PWM1(halfperdead1, halfperdead1, halfperdead1)

	}

#ifdef VB_RAMP
	// ramp limitation depending on vbus
	if(DECEL1)
	{
		if(HVBUS_LIMH1 <= vbus1)
		{
			SET_RAMPLIM1
		}
		else if(HVBUS_LIML1 > vbus1)
		{
			RES_RAMPLIM1
		}
	}
	else
	{
		RES_RAMPLIM1
	}
#endif	// ifdef VB_RAMP

	// current references calculation, startup, position and speed management
	// the outputs of this block are: next system phase, next d and q current references
	if(COM1_ON)
	{

#ifdef FLUXWEAK
		// measured current and voltages vectors amplitude
		//amp_i1 = sqrtf((iam1 * iam1) + (ibm1 * ibm1));// McrpLibf_xy_rt(iam1, ibm1, &amp_i1, &arg_i1);
		amp_v1 = sqrtf((vam1 * vam1) + (vbm1 * vbm1));	// McrpLibf_xy_rt(vam1, vbm1, &amp_v1, &arg_v1);
#endif  // ifdef FLUXWEAK

#ifdef CPI_TUN
		if(CURPI_TUN && MOT1_SEL)
		{
			iqr1 = 0.0f;
			MC_CurPITun(idm1, &idr1, i_max1);
		}
		else
#endif	// ifdef CPI_TUN

#ifdef MOT_IDENT
		if(AUTO_IDEN && MOT1_SEL)
		{
			MC_MotIdent(idm1, iqm1, vdm1, vqm1, &idr1, &iqr1, &omegae1, &SystemPhase1);
		}
		else
#endif	// ifdef MOT_IDENT

		{	// normal behaviour block beginning

#ifdef FLUXWEAK
			// voltage margin for flux weakening calc
			vmarg1 = (vfmax1 * K_MARGV_FW) - amp_v1;
			if((0.0f < omegae1) && (0.0f >= vqc1))
			{
				vmarg1 -= vqc1;
			}
			else if((0.0f > omegae1) && (0.0f <= vqc1))
			{
				vmarg1 += vqc1;
			}
			if((0.0f > vmarg1) && (	((0.0f < omegae1) && (0.0f >= iqr1))	||
									((0.0f > omegae1) && (0.0f <= iqr1))	))
			{
				vmarg1 = 0.0f;
			}
#endif	// ifdef FLUXWEAK

			// speed reference filter
			f_omrif1 += ((omrif1 - f_omrif1) * omr_ukt);	// speed reference filtering

			// permanent magnets flux vector position and speed estimation
			McrpLibf_FluxEst1(vam1, vbm1, iam1, ibm1);
			FluxPhase1 = McrpLibf_FluxEst1_GetPhase();
			Speed_est1 = McrpLibf_FluxEst1_GetSpeed();

			// phase compensation and optional phase offset
			Phase_est1 = McrpLibf_AngleNrm(FluxPhase1 + (comptime * Speed_est1) + Phase_offset1);

			// position loss control
#ifdef TRIP_CONTROL1
			MC_TripCon1();
#endif	// ifdef TRIP_CONTROL1

			// STARTUP
			if(STOP_W == ramp1_status)	// stop control
			{
				itr1 = idr1 = iqr1 = 0.0f;
				startup_cnt1 = 0;
				SET_STOPPED1
				SystemPhase1 = 0.0f;
				omf1 = omegae1 = 0.0f;
			}
			else if(0 == startup_cnt1)	// alignment
			{
				SystemPhase1 = 0.0f;
				omf1 = omegae1 = 0.0f;
				if(itr1 < i_start1)
				{
					itr1 += is_rup1;
				}
				else
				{
					itr1 = i_start1;
					startup_cnt1 = 1;
					FluxPhase1 = SystemPhase1;
					McrpLibf_FluxEst1_SetFlux(FluxPhase1, iam1, ibm1, omegae1);
				}
				if(0.0f > omrif1)
				{
					McrpLibf_rt_xy(itr1, -ISTART_PH, &idr1, &iqr1);
				}
				else
				{
					McrpLibf_rt_xy(itr1, ISTART_PH, &idr1, &iqr1);
				}
			}
			else if(1 == startup_cnt1)	// speed increasing till minimum speed
			{

				if(START_P == ramp1_status)
				{
					if(omegae1 < (min_speed1 - delta_om1))
					{
						omegae1 += delta_om1;
					}
					else
					{
						omegae1 = min_speed1;
						startup_cnt1 = 2;
					}
				}
				else if(START_N == ramp1_status)
				{
					if(omegae1 > (delta_om1 - min_speed1))
					{
						omegae1 -= delta_om1;
					}
					else
					{
						omegae1 = -min_speed1;
						startup_cnt1 = 2;
					}
				}
				omf1 = omegae1;

				// feed-forward angle management
				SystemPhase1 = McrpLibf_AngleNrm(SystemPhase1 + omegae1 * sam_per_s);
			}
			else if(2 == startup_cnt1)	// reference system change
			{
				startup_cnt1 = 3;
				f_omrif1 = omf1 = omegae1;

				// control memories calc and setting
				McrpLibf_dq_alphabeta1(idint1, iqint1, &iaint1, &ibint1);	// current PI integral terms in old ref. frame
				McrpLibf_dq_alphabeta1(idr1, iqr1, &iar1, &ibr1);			// references in old ref. frame
				McrpLibf_AngleSet1(Phase_est1);								// phase update
				McrpLibf_alphabeta_dq1(iaint1, ibint1, &idint1, &iqint1);	// current PI integral terms in new ref. frame
				McrpLibf_alphabeta_dq1(iar1, ibr1, &idr1, &iqr1);			// references in new ref. frame
				errint1 = iqr1;												// speed PI integral term

				// phase alignment
				SystemPhase1 = Phase_est1;
				trip1_cnt = 0;
				SET_STARTED1
				// itr is still equal to i_start
			}
			else if(3 == startup_cnt1)	// id decreasing
			{

				// itr ramp down
				if(itr1 > is_rdw1)
				{
					itr1 -= is_rdw1;
				}
				else
				{
					itr1 = 0;
					startup_cnt1 = 4;
				}

				// phase and speed update
				SystemPhase1 = Phase_est1;
				omegae1 = Speed_est1;

				// speed control
				iqmax1 = i_max1;
				f32a = f_omrif1 - omegae1;
#ifdef SPEEDPI_ERRCLAMP
				if(maxerr1 < f32a)
				{
					f32a = maxerr1;
				}
				else if(-maxerr1 > f32a)
				{
					f32a = -maxerr1;
				}
#endif	// ifdef SPEEDPI_ERRCLAMP
				iqr1 = McrpLibf_PIW(f32a, iqmax1, -iqmax1, kp_vel1, ki_vel1, &errint1);

				// idr calc
				f32a = MC_VecComp(itr1, iqr1);
				if(f32a < idr1)
				{
					idr1 = f32a;
				}
				else if(-f32a > idr1)
				{
					idr1 = -f32a;
				}
			}
			// STARTUP IS FINISHED, NORMAL CONTROL
			else		// normal sensorless control
			{

				// phase and speed update
				SystemPhase1 = Phase_est1;
				omegae1 = Speed_est1;

				// id reference calc
				idrvar1 = 0.0f;

				// idr and iqmax calc
#ifdef FLUXWEAK
				MC_FluxWeak(vmarg1, idmax1, idrvar1, &idr1, vbus1, HVBUS_LIMH1, intid_rdw1, intid_rup1);
#else	// ifdef FLUXWEAK
				idr1 = idrvar1;
#endif	// else ifdef FLUXWEAK
				iqmax1 = MC_VecComp(i_max1, idr1);

				// speed control
#ifdef VB_RAMP
				if(RAMPLIM1)
				{
					errint1 *= K_RAMPLIM;
				}
#endif	// ifdef VB_RAMP
				f32a = f_omrif1 - omegae1;
#ifdef SPEEDPI_ERRCLAMP
				if(maxerr1 < f32a)
				{
					f32a = maxerr1;
				}
				else if(-maxerr1 > f32a)
				{
					f32a = -maxerr1;
				}
#endif	// ifdef SPEEDPI_ERRCLAMP
				iqr1 = McrpLibf_PIW(f32a, iqmax1, -iqmax1, kp_vel1, ki_vel1, &errint1);

			}	// end of normal control

		}	// end of startup and normal behaviour

		// visualization filters
		idmf1 += ((idm1 - idmf1) * visu_ukt);	// d current
		iqmf1 += ((iqm1 - iqmf1) * visu_ukt);	// q current
		vdmf1 += ((vdm1 - vdmf1) * visu_ukt);	// d voltage
		vqmf1 += ((vqm1 - vqmf1) * visu_ukt);	// q voltage
		omf1 += ((omegae1 - omf1) * visu_ukt);	// angular speed

	}	// if(COM1_ON)
	else
	{

		// speed PI integral term reset
		errint1 = 0.0f;

		// current references reset
		itr1 = iqr1 = idr1 = 0.0f;

		// measurements reset
		amp_v1 = 0.0f;
		//arg_v1 = SystemPhase;
		//amp_i1 = 0.0f;
		//arg_i1 = SystemPhase;

#ifdef FLUXWEAK
		// voltage margin reset
		vmarg1 = vfmax1;
#endif	// ifdef FLUXWEAK

		// position and speed reset
		SystemPhase1 = 0.0f;
		omegae1 = 0.0f;

		// phase detection variables reset
		Phase_est1 = FluxPhase1 = SystemPhase1;
		Speed_est1 = omegae1;
		McrpLibf_FluxEst1_SetFlux(FluxPhase1, iam1, ibm1, omegae1);
		trip1_cnt = 0;

		// startup variables and flags reset
		startup_cnt1 = 0;
		idrvar1 = 0.0f;
		iqmax1 = 0.0f;

		// filters memories reset
		f_omrif1 = 0.0f;
		iqmf1 = idmf1 = 0.0f;
		vqmf1 = vdmf1 = 0.0f;
		omf1 = 0.0f;

	}	// else of if(COM1_ON)

	// bus voltage filter and vfmax calc
	if(vbus1 < vbus_minf1)
	{
		vbus_minf1 += ((vbus1 - vbus_minf1) * vb_ukt_fast); // fast decrease
	}
	else if(vbus1 > vbus_minf1)
	{
		vbus_minf1 += ((vbus1 - vbus_minf1) * vb_ukt_slow);	// slow increase
	}
	vfmax1 = vbus_minf1 * k_vout1;

	// visualization filters
	vbusf1 += ((vbus1 - vbusf1) * visu_ukt);	// DC bus voltage

#ifdef OSC_WIN
	// management of oscilloscope window in GUI
	if(NORM_MODE && MOT1_SEL)
	{
		if(CSELD)
		{
			sample = ium1 * imax1000;
		}
		else
		{
			sample = SystemPhase1 * 1000.0f;
		}
		if(COM1_ON)
		{
			if(NOT_TRGED)
			{
				if(selmem != ((uint16_t)UIF_W.var.sel))
				{
					selmem = (uint16_t)UIF_W.var.sel;
					bcntm = selmem >> 8;
					if(0 == (selmem & 0x00FF))
					{
						RES_CSELD
					}
					else
					{
						SET_CSELD
					}
				}
				if(	((0.0f < omegae1) && (0.0f > phmem) && (0.0f <= SystemPhase1)) ||
					((0.0f > omegae1) && (0.0f < phmem) && (0.0f >= SystemPhase1)) )
				{
					SET_TRGED
					bcnt1 = 1;
					bcnt0 = 1;
					wbuf[0] = sample;
				}
			}
			else if(MAX_SAM_CNT > bcnt0)
			{
				if(bcnt1 < bcntm)
				{
					bcnt1++;
				}
				else
				{
					bcnt1 = 1;
					wbuf[bcnt0++] = sample;
				}
			}
			else if(NOT_RBUSY)
			{
				pbuf = rbuf;
				rbuf = wbuf;
				wbuf = pbuf;
				RES_TRGED
			}
		}	// COM1_ON
		else
		{
			RES_TRGED
			if(selmem != ((uint16_t)UIF_W.var.sel))
			{
				selmem = (uint16_t)UIF_W.var.sel;
				bcntm = selmem >> 8;
				if(0 == (selmem & 0x00FF))
				{
					RES_CSELD
				}
				else
				{
					SET_CSELD
				}
			}
			if(MAX_SAM_CNT > bcnt0)
			{
				wbuf[bcnt0++] = 0;
			}
			else if(NOT_RBUSY)
			{
				pbuf = rbuf;
				rbuf = wbuf;
				wbuf = pbuf;
				bcnt0 = 0;
			}
		}	// COM_OFF
		phmem = SystemPhase1;
	}	// if(NORM_MODE && MOT1_SEL)
#endif	// ifdef OSC_WIN

	// serial communication receive delay management
	UI_RTX232_RXDelMan();

	// main loop synchronization counter
	if(0 < cnt_int)
	{
		cnt_int--;
	}

	RES_LD1						// debug

	// interrupt end
	return;
}

/******************************************************************************
Function:		MC_ConInt2
Description:	control interrupt
Input:			nothing
Output:			nothing
Note:			this function is called every sampling instant, and performs
           		the motor control
******************************************************************************/
void MC_ConInt2(void)
{
	float32_t	f32a;

	IR(S12AD1, S12ADI1) = 0;	// reset interrupt request

	SET_LD1						// debug

	// enables higher priority interrupts (serial communication)
//	set_ipl(SCI_INT_P - 1);
	setpsw_i();					// enables other interrupts

	// triggered A/D conversions management (currents and bus voltage)
	MC_ADMan2();				// modifies the global variables ium, ivm, iwm, iam, ibm. vbus

	// check POE flags
	MC_CheckPOEFlags2();

	if(COM2_ON)
	{
		// current transformations (previous angle)
		McrpLibf_alphabeta_dq2(iam2, ibm2, &idm2, &iqm2);

		// voltage measurements (related to currents measurements)
		vam2 = vax2;
		vbm2 = vbx2;
		vdm2 = vdx2;
		vqm2 = vqx2;
	}	// if(COM2_ON)
	else
	{
		iqm2 = idm2 = 0.0f;
		vbm2 = vam2 = 0.0f;
		vqm2 = vdm2 = 0.0f;
	}

	// angle management
	McrpLibf_AngleSet2(SystemPhase2);	// from here new angle (sin and cos) (conversions etc.)

	// voltages references and duty cycles calc
	if(COM2_ON)
	{

#ifdef CPI_AUT
		if(MOT2_SEL && CURPI_AUT)
		{
			idr2 = iqr2 = 0;
			MC_CurPIAuto(idm2, iqm2, &vdc2, &vqc2);
		}	// if(CURPI_AUT)
		else
#endif	// ifdef CPI_AUT
		{	// normal case: idr, iqr come from previous cycle

			// current PI controls
			MC_IdIqPI(idr2, idm2, iqr2, iqm2, vfmax2, kp_cur2, ki_cur2, &vdc2, &vqc2, &idint2, &iqint2);
		}	// end of normal case

		// voltage transformations (actual angle)
		McrpLibf_dq_alphabeta2(vdc2, vqc2, &vac2, &vbc2);
		McrpLibf_alphabeta_uv(vac2, vbc2, &vuc2, &vvc2);
		vwc2 = -vuc2 - vvc2;

		// pwm output generation
		MC_PWMGen2();

		// pwm output registers setting (HERE WE SHOULD BE BEFORE PWM CREST!)
		SET_PWM2(duty2_u, duty2_v, duty2_w)

		// output voltages in (alpha, beta) frame update after modulation clamping
		McrpLibf_uvw_alphabeta(vux2, vvx2, vwx2, &vax2, &vbx2);
		McrpLibf_alphabeta_dq2(vax2, vbx2, &vdx2, &vqx2);

	}
	else	// else of if(COM2_ON)
	{
		iqint2 = idint2 = 0.0f;
		vqc2 = vdc2 = 0.0f;
		vbc2 = vac2 = 0.0f;
		vwc2 = vvc2 = vuc2 = 0.0f;
		vqx2 = vdx2 = 0.0f;
		vbx2 = vax2 = 0.0f;
		vwx2 = vvx2 = vux2 = 0.0f;
		duty2_u = duty2_v = duty2_w = halfperdead2;

		// pwm output registers setting (if outputs enabled, this means the lower arm always on (used for BOOTSTRAP))
		SET_PWM2(halfperdead2, halfperdead2, halfperdead2)

	}

#ifdef VB_RAMP
	// ramp limitation depending on vbus
	if(DECEL2)
	{
		if(HVBUS_LIMH2 <= vbus2)
		{
			SET_RAMPLIM2
		}
		else if(HVBUS_LIML2 > vbus2)
		{
			RES_RAMPLIM2
		}
	}
	else
	{
		RES_RAMPLIM2
	}
#endif	// ifdef VB_RAMP

	// current references calculation, startup, position and speed management
	// the outputs of this block are: next system phase, next d and q current references
	if(COM2_ON)
	{

#ifdef FLUXWEAK
		// measured current and voltages vectors amplitude
		//amp_i2 = sqrtf((iam2 * iam2) + (ibm2 * ibm2));// McrpLibf_xy_rt(iam2, ibm2, &amp_i2, &arg_i2);
		amp_v2 = sqrtf((vam2 * vam2) + (vbm2 * vbm2));	// McrpLibf_xy_rt(vam2, vbm2, &amp_v2, &arg_v2);
#endif  // ifdef FLUXWEAK

#ifdef CPI_TUN
		if(CURPI_TUN && MOT2_SEL)
		{
			iqr2 = 0.0f;
			MC_CurPITun(idm2, &idr2, i_max2);
		}
		else
#endif	// ifdef CPI_TUN

#ifdef MOT_IDENT
		if(AUTO_IDEN && MOT2_SEL)
		{
			MC_MotIdent(idm2, iqm2, vdm2, vqm2, &idr2, &iqr2, &omegae2, &SystemPhase2);
		}
		else
#endif	// ifdef MOT_IDENT

		{	// normal behaviour block beginning

#ifdef FLUXWEAK
			// voltage margin for flux weakening calc
			vmarg2 = (vfmax2 * K_MARGV_FW) - amp_v2;
			if((0.0f < omegae2) && (0.0f >= vqc2))
			{
				vmarg2 -= vqc2;
			}
			else if((0.0f > omegae2) && (0.0f <= vqc2))
			{
				vmarg2 += vqc2;
			}
			if((0.0f > vmarg2) && (	((0.0f < omegae2) && (0.0f >= iqr2))	||
									((0.0f > omegae2) && (0.0f <= iqr2))	))
			{
				vmarg2 = 0.0f;
			}
#endif	// ifdef FLUXWEAK

			// speed reference filter
			f_omrif2 += ((omrif2 - f_omrif2) * omr_ukt);	// speed reference filtering

			// permanent magnets flux vector position and speed estimation
			McrpLibf_FluxEst2(vam2, vbm2, iam2, ibm2);
			FluxPhase2 = McrpLibf_FluxEst2_GetPhase();
			Speed_est2 = McrpLibf_FluxEst2_GetSpeed();

			// phase compensation and optional phase offset
			Phase_est2 = McrpLibf_AngleNrm(FluxPhase2 + (comptime * Speed_est2) + Phase_offset2);

			// position loss control
#ifdef TRIP_CONTROL2
			MC_TripCon2();
#endif	// ifdef TRIP_CONTROL2

			// STARTUP
			if(STOP_W == ramp2_status)	// stop control
			{
				itr2 = idr2 = iqr2 = 0.0f;
				startup_cnt2 = 0;
				SET_STOPPED2
				SystemPhase2 = 0.0f;
				omf2 = omegae2 = 0.0f;
			}
			else if(0 == startup_cnt2)	// alignment
			{
				SystemPhase2 = 0.0f;
				omf2 = omegae2 = 0.0f;
				if(itr2 < i_start2)
				{
					itr2 += is_rup2;
				}
				else
				{
					itr2 = i_start2;
					startup_cnt2 = 1;
					FluxPhase2 = SystemPhase2;
					McrpLibf_FluxEst2_SetFlux(FluxPhase2, iam2, ibm2, omegae2);
				}
				if(0.0f > omrif2)
				{
					McrpLibf_rt_xy(itr2, -ISTART_PH, &idr2, &iqr2);
				}
				else
				{
					McrpLibf_rt_xy(itr2, ISTART_PH, &idr2, &iqr2);
				}
			}
			else if(1 == startup_cnt2)	// speed increasing till minimum speed
			{

				if(START_P == ramp2_status)
				{
					if(omegae2 < (min_speed2 - delta_om2))
					{
						omegae2 += delta_om2;
					}
					else
					{
						omegae2 = min_speed2;
						startup_cnt2 = 2;
					}
				}
				else if(START_N == ramp2_status)
				{
					if(omegae2 > (delta_om2 - min_speed2))
					{
						omegae2 -= delta_om2;
					}
					else
					{
						omegae2 = -min_speed2;
						startup_cnt2 = 2;
					}
				}
				omf2 = omegae2;

				// feed-forward angle management
				SystemPhase2 = McrpLibf_AngleNrm(SystemPhase2 + omegae2 * sam_per_s);
			}
			else if(2 == startup_cnt2)	// reference system change
			{
				startup_cnt2 = 3;
				f_omrif2 = omf2 = omegae2;

				// control memories calc and setting
				McrpLibf_dq_alphabeta2(idint2, iqint2, &iaint2, &ibint2);	// current PI integral terms in old ref. frame
				McrpLibf_dq_alphabeta2(idr2, iqr2, &iar2, &ibr2);			// references in old ref. frame
				McrpLibf_AngleSet2(Phase_est2);								// phase update
				McrpLibf_alphabeta_dq2(iaint2, ibint2, &idint2, &iqint2);	// current PI integral terms in new ref. frame
				McrpLibf_alphabeta_dq2(iar2, ibr2, &idr2, &iqr2);			// references in new ref. frame
				errint2 = iqr2;												// speed PI integral term

				// phase alignment
				SystemPhase2 = Phase_est2;
				trip2_cnt = 0;
				SET_STARTED2
				// itr is still equal to i_start
			}
			else if(3 == startup_cnt2)	// id decreasing
			{

				// itr ramp down
				if(itr2 > is_rdw2)
				{
					itr2 -= is_rdw2;
				}
				else
				{
					itr2 = 0;
					startup_cnt2 = 4;
				}

				// phase and speed update
				SystemPhase2 = Phase_est2;
				omegae2 = Speed_est2;

				// speed control
				iqmax2 = i_max2;
				f32a = f_omrif2 - omegae2;
#ifdef SPEEDPI_ERRCLAMP
				if(maxerr2 < f32a)
				{
					f32a = maxerr2;
				}
				else if(-maxerr2 > f32a)
				{
					f32a = -maxerr2;
				}
#endif	// ifdef SPEEDPI_ERRCLAMP
				iqr2 = McrpLibf_PIW(f32a, iqmax2, -iqmax2, kp_vel2, ki_vel2, &errint2);

				// idr calc
				f32a = MC_VecComp(itr2, iqr2);
				if(f32a < idr2)
				{
					idr2 = f32a;
				}
				else if(-f32a > idr2)
				{
					idr2 = -f32a;
				}
			}
			// STARTUP IS FINISHED, NORMAL CONTROL
			else		// normal sensorless control
			{

				// phase and speed update
				SystemPhase2 = Phase_est2;
				omegae2 = Speed_est2;

				// id reference calc
				idrvar2 = 0.0f;

				// idr and iqmax calc
#ifdef FLUXWEAK
				MC_FluxWeak(vmarg2, idmax2, idrvar2, &idr2, vbus2, HVBUS_LIMH2, intid_rdw2, intid_rup2);
#else	// ifdef FLUXWEAK
				idr2 = idrvar2;
#endif	// else ifdef FLUXWEAK
				iqmax2 = MC_VecComp(i_max2, idr2);

				// speed control
#ifdef VB_RAMP
				if(RAMPLIM2)
				{
					errint2 *= K_RAMPLIM;
				}
#endif	// ifdef VB_RAMP
				f32a = f_omrif2 - omegae2;
#ifdef SPEEDPI_ERRCLAMP
				if(maxerr2 < f32a)
				{
					f32a = maxerr2;
				}
				else if(-maxerr2 > f32a)
				{
					f32a = -maxerr2;
				}
#endif	// ifdef SPEEDPI_ERRCLAMP
				iqr2 = McrpLibf_PIW(f32a, iqmax2, -iqmax2, kp_vel2, ki_vel2, &errint2);

			}	// end of normal control

		}	// end of startup and normal behaviour

		// visualization filters
		idmf2 += ((idm2 - idmf2) * visu_ukt);	// d current
		iqmf2 += ((iqm2 - iqmf2) * visu_ukt);	// q current
		vdmf2 += ((vdm2 - vdmf2) * visu_ukt);	// d voltage
		vqmf2 += ((vqm2 - vqmf2) * visu_ukt);	// q voltage
		omf2 += ((omegae2 - omf2) * visu_ukt);	// angular speed

	}	// if(COM2_ON)
	else
	{

		// speed PI integral term reset
		errint2 = 0.0f;

		// current references reset
		itr2 = iqr2 = idr2 = 0.0f;

		// measurements reset
		amp_v2 = 0.0f;
		//arg_v2 = SystemPhase;
		//amp_i2 = 0.0f;
		//arg_i2 = SystemPhase;

#ifdef FLUXWEAK
		// voltage margin reset
		vmarg2 = vfmax2;
#endif	// ifdef FLUXWEAK

		// position and speed reset
		SystemPhase2 = 0.0f;
		omegae2 = 0.0f;

		// phase detection variables reset
		Phase_est2 = FluxPhase2 = SystemPhase2;
		Speed_est2 = omegae2;
		McrpLibf_FluxEst2_SetFlux(FluxPhase2, iam2, ibm2, omegae2);
		trip2_cnt = 0;

		// startup variables and flags reset
		startup_cnt2 = 0;
		idrvar2 = 0.0f;
		iqmax2 = 0.0f;

		// filters memories reset
		f_omrif2 = 0.0f;
		iqmf2 = idmf2 = 0.0f;
		vqmf2 = vdmf2 = 0.0f;
		omf2 = 0.0f;

	}	// else of if(COM2_ON)

	// bus voltage filter and vfmax calc
	if(vbus2 < vbus_minf2)
	{
		vbus_minf2 += ((vbus2 - vbus_minf2) * vb_ukt_fast); // fast decrease
	}
	else if(vbus2 > vbus_minf2)
	{
		vbus_minf2 += ((vbus2 - vbus_minf2) * vb_ukt_slow);	// slow increase
	}
	vfmax2 = vbus_minf2 * k_vout2;

	// visualization filters
	vbusf2 += ((vbus2 - vbusf2) * visu_ukt);	// DC bus voltage

#ifdef OSC_WIN
	// management of oscilloscope window in GUI
	if(NORM_MODE && MOT2_SEL)
	{
		if(CSELD)
		{
			sample = ium2 * imax1000;
		}
		else
		{
			sample = SystemPhase2 * 1000.0f;
		}
		if(COM1_ON)
		{
			if(NOT_TRGED)
			{
				if(selmem != ((uint16_t)UIF_W.var.sel))
				{
					selmem = (uint16_t)UIF_W.var.sel;
					bcntm = selmem >> 8;
					if(0 == (selmem & 0x00FF))
					{
						RES_CSELD
					}
					else
					{
						SET_CSELD
					}
				}
				if(	((0.0f < omegae2) && (0.0f > phmem) && (0.0f <= SystemPhase2)) ||
					((0.0f > omegae2) && (0.0f < phmem) && (0.0f >= SystemPhase2)) )
				{
					SET_TRGED
					bcnt1 = 1;
					bcnt0 = 1;
					wbuf[0] = sample;
				}
			}
			else if(MAX_SAM_CNT > bcnt0)
			{
				if(bcnt1 < bcntm)
				{
					bcnt1++;
				}
				else
				{
					bcnt1 = 1;
					wbuf[bcnt0++] = sample;
				}
			}
			else if(NOT_RBUSY)
			{
				pbuf = rbuf;
				rbuf = wbuf;
				wbuf = pbuf;
				RES_TRGED
			}
		}	// COM1_ON
		else
		{
			RES_TRGED
			if(selmem != ((uint16_t)UIF_W.var.sel))
			{
				selmem = (uint16_t)UIF_W.var.sel;
				bcntm = selmem >> 8;
				if(0 == (selmem & 0x00FF))
				{
					RES_CSELD
				}
				else
				{
					SET_CSELD
				}
			}
			if(MAX_SAM_CNT > bcnt0)
			{
				wbuf[bcnt0++] = 0;
			}
			else if(NOT_RBUSY)
			{
				pbuf = rbuf;
				rbuf = wbuf;
				wbuf = pbuf;
				bcnt0 = 0;
			}
		}	// COM_OFF
		phmem = SystemPhase2;
	}	// if(NORM_MODE && MOT2_SEL)
#endif	// ifdef OSC_WIN

	RES_LD1						// debug

	// interrupt end
	return;
}

/******************************************************************************
Function:		MC_ConInt3
Description:	control interrupt
Input:			nothing
Output:			nothing
Note:			this function is called every sampling instant, and performs
           		the motor control
******************************************************************************/
void MC_ConInt3(void)
{
	float32_t	f32a;

	IR(S12AD2, S12ADI2) = 0;	// reset interrupt request

	SET_LD1						// debug

	// enables higher priority interrupts (serial communication)
//	set_ipl(SCI_INT_P - 1);
	setpsw_i();					// enables other interrupts

	// triggered A/D conversions management (currents and bus voltage)
	MC_ADMan3();				// modifies the global variables ium, ivm, iwm, iam, ibm. vbus

	// check POE flags
	MC_CheckPOEFlags3();

	if(COM3_ON)
	{
		// current transformations (previous angle)
		McrpLibf_alphabeta_dq3(iam3, ibm3, &idm3, &iqm3);

		// voltage measurements (related to currents measurements)
		vam3 = vax3;
		vbm3 = vbx3;
		vdm3 = vdx3;
		vqm3 = vqx3;
	}	// if(COM3_ON)
	else
	{
		iqm3 = idm3 = 0.0f;
		vbm3 = vam3 = 0.0f;
		vqm3 = vdm3 = 0.0f;
	}

	// angle management
	McrpLibf_AngleSet3(SystemPhase3);	// from here new angle (sin and cos) (conversions etc.)

	// voltages references and duty cycles calc
	if(COM3_ON)
	{

#ifdef CPI_AUT
		if(MOT3_SEL && CURPI_AUT)
		{
			idr3 = iqr3 = 0;
			MC_CurPIAuto(idm3, iqm3, &vdc3, &vqc3);
		}	// if(CURPI_AUT)
		else
#endif	// ifdef CPI_AUT
		{	// normal case: idr, iqr come from previous cycle

			// current PI controls
			MC_IdIqPI(idr3, idm3, iqr3, iqm3, vfmax3, kp_cur3, ki_cur3, &vdc3, &vqc3, &idint3, &iqint3);
		}	// end of normal case

		// voltage transformations (actual angle)
		McrpLibf_dq_alphabeta3(vdc3, vqc3, &vac3, &vbc3);
		McrpLibf_alphabeta_uv(vac3, vbc3, &vuc3, &vvc3);
		vwc3 = -vuc3 - vvc3;


		// pwm output generation
		MC_PWMGen3();

		// pwm output registers setting (HERE WE SHOULD BE BEFORE PWM CREST!)
		SET_PWM3(duty3_u, duty3_v, duty3_w)

		// output voltages in (alpha, beta) frame update after modulation clamping
		McrpLibf_uvw_alphabeta(vux3, vvx3, vwx3, &vax3, &vbx3);
		McrpLibf_alphabeta_dq3(vax3, vbx3, &vdx3, &vqx3);

	}
	else	// else of if(COM3_ON)
	{
		iqint3 = idint3 = 0.0f;
		vqc3 = vdc3 = 0.0f;
		vbc3 = vac3 = 0.0f;
		vwc3 = vvc3 = vuc3 = 0.0f;
		vqx3 = vdx3 = 0.0f;
		vbx3 = vax3 = 0.0f;
		vwx3 = vvx3 = vux3 = 0.0f;
		duty3_u = duty3_v = duty3_w = halfper3 - 1;

		// pwm output registers setting (if outputs enabled, this means the lower arm always on (used for BOOTSTRAP))
		SET_PWM3(duty3_u, duty3_v, duty3_w)

	}

#ifdef VB_RAMP
	// ramp limitation depending on vbus
	if(DECEL3)
	{
		if(HVBUS_LIMH3 <= vbus3)
		{
			SET_RAMPLIM3
		}
		else if(HVBUS_LIML3 > vbus3)
		{
			RES_RAMPLIM3
		}
	}
	else
	{
		RES_RAMPLIM3
	}
#endif	// ifdef VB_RAMP

	// current references calculation, startup, position and speed management
	// the outputs of this block are: next system phase, next d and q current references
	if(COM3_ON)
	{

#ifdef FLUXWEAK
		// measured current and voltages vectors amplitude
		//amp_i3 = sqrtf((iam3 * iam3) + (ibm3 * ibm3));// McrpLibf_xy_rt(iam3, ibm3, &amp_i3, &arg_i3);
		amp_v3 = sqrtf((vam3 * vam3) + (vbm3 * vbm3));	// McrpLibf_xy_rt(vam3, vbm3, &amp_v3, &arg_v3);
#endif  // ifdef FLUXWEAK

#ifdef CPI_TUN
		if(CURPI_TUN && MOT3_SEL)
		{
			iqr3 = 0.0f;
			MC_CurPITun(idm3, &idr3, i_max3);
		}
		else
#endif	// ifdef CPI_TUN

#ifdef MOT_IDENT
		if(AUTO_IDEN && MOT3_SEL)
		{
			MC_MotIdent(idm3, iqm3, vdm3, vqm3, &idr3, &iqr3, &omegae3, &SystemPhase3);
		}
		else
#endif	// ifdef MOT_IDENT

		{	// normal behaviour block beginning

#ifdef FLUXWEAK
			// voltage margin for flux weakening calc
			vmarg3 = (vfmax3 * K_MARGV_FW) - amp_v3;
			if((0.0f < omegae3) && (0.0f >= vqc3))
			{
				vmarg3 -= vqc3;
			}
			else if((0.0f > omegae3) && (0.0f <= vqc3))
			{
				vmarg3 += vqc3;
			}
			if((0.0f > vmarg3) && (	((0.0f < omegae3) && (0.0f >= iqr3))	||
									((0.0f > omegae3) && (0.0f <= iqr3))	))
			{
				vmarg3 = 0.0f;
			}
#endif	// ifdef FLUXWEAK

			// speed reference filter
			f_omrif3 += ((omrif3 - f_omrif3) * omr_ukt);	// speed reference filtering

			// permanent magnets flux vector position and speed estimation
			McrpLibf_FluxEst3(vam3, vbm3, iam3, ibm3);
			FluxPhase3 = McrpLibf_FluxEst3_GetPhase();
			Speed_est3 = McrpLibf_FluxEst3_GetSpeed();

			// phase compensation and optional phase offset
			Phase_est3 = McrpLibf_AngleNrm(FluxPhase3 + (comptime * Speed_est3) + Phase_offset3);

			// position loss control
#ifdef TRIP_CONTROL3
			MC_TripCon3();
#endif	// ifdef TRIP_CONTROL3

			// STARTUP
			if(STOP_W == ramp3_status)	// stop control
			{
				itr3 = idr3 = iqr3 = 0.0f;
				startup_cnt3 = 0;
				SET_STOPPED3
				SystemPhase3 = 0.0f;
				omf3 = omegae3 = 0.0f;
			}
			else if(0 == startup_cnt3)	// alignment
			{
				// feed-forward angle management
				SystemPhase3 = 0.0f;
				omf3 = omegae3 = 0.0f;
				if(itr3 < i_start3)
				{
					itr3 += is_rup3;
				}
				else
				{
					itr3 = i_start3;
					startup_cnt3 = 1;
					FluxPhase3 = SystemPhase3;
					McrpLibf_FluxEst3_SetFlux(FluxPhase3, iam3, ibm3, omegae3);
				}
				if(0.0f > omrif3)
				{
					McrpLibf_rt_xy(itr3, -ISTART_PH, &idr3, &iqr3);
				}
				else
				{
					McrpLibf_rt_xy(itr3, ISTART_PH, &idr3, &iqr3);
				}
			}
			else if(1 == startup_cnt3)	// speed increasing till minimum speed
			{

				if(START_P == ramp3_status)
				{
					if(omegae3 < (min_speed3 - delta_om3))
					{
						omegae3 += delta_om3;
					}
					else
					{
						omegae3 = min_speed3;
						startup_cnt3 = 2;
					}
				}
				else if(START_N == ramp3_status)
				{
					if(omegae3 > (delta_om3 - min_speed3))
					{
						omegae3 -= delta_om3;
					}
					else
					{
						omegae3 = -min_speed3;
						startup_cnt3 = 2;
					}
				}
				omf3 = omegae3;

				// feed-forward angle management
				SystemPhase3 = McrpLibf_AngleNrm(SystemPhase3 + omegae3 * sam_per_s);
			}
			else if(2 == startup_cnt3)	// reference system change
			{
				startup_cnt3 = 3;
				f_omrif3 = omf3 = omegae3;

				// control memories calc and setting
				McrpLibf_dq_alphabeta3(idint3, iqint3, &iaint3, &ibint3);	// current PI integral terms in old ref. frame
				McrpLibf_dq_alphabeta3(idr3, iqr3, &iar3, &ibr3);			// references in old ref. frame
				McrpLibf_AngleSet3(Phase_est3);								// phase update
				McrpLibf_alphabeta_dq3(iaint3, ibint3, &idint3, &iqint3);	// current PI integral terms in new ref. frame
				McrpLibf_alphabeta_dq3(iar3, ibr3, &idr3, &iqr3);			// references in new ref. frame
				errint3 = iqr3;												// speed PI integral term

				// phase alignment
				SystemPhase3 = Phase_est3;
				trip3_cnt = 0;
				SET_STARTED3
				// itr is still equal to i_start
			}
			else if(3 == startup_cnt3)	// id decreasing
			{

				// itr ramp down
				if(itr3 > is_rdw3)
				{
					itr3 -= is_rdw3;
				}
				else
				{
					itr3 = 0;
					startup_cnt3 = 4;
				}

				// phase and speed update
				SystemPhase3 = Phase_est3;
				omegae3 = Speed_est3;

				// speed control
				iqmax3 = i_max3;
				f32a = f_omrif3 - omegae3;
#ifdef SPEEDPI_ERRCLAMP
				if(maxerr3 < f32a)
				{
					f32a = maxerr3;
				}
				else if(-maxerr3 > f32a)
				{
					f32a = -maxerr3;
				}
#endif	// ifdef SPEEDPI_ERRCLAMP
				iqr3 = McrpLibf_PIW(f32a, iqmax3, -iqmax3, kp_vel3, ki_vel3, &errint3);

				// idr calc
				f32a = MC_VecComp(itr3, iqr3);
				if(f32a < idr3)
				{
					idr3 = f32a;
				}
				else if(-f32a > idr3)
				{
					idr3 = -f32a;
				}
			}
			// STARTUP IS FINISHED, NORMAL CONTROL
			else		// normal sensorless control
			{

				// phase and speed update
				SystemPhase3 = Phase_est3;
				omegae3 = Speed_est3;

				// id reference calc
				idrvar3 = 0.0f;

				// idr and iqmax calc
#ifdef FLUXWEAK
				MC_FluxWeak(vmarg3, idmax3, idrvar3, &idr3, vbus3, HVBUS_LIMH3, intid_rdw3, intid_rup3);
#else	// ifdef FLUXWEAK
				idr3 = idrvar3;
#endif	// else ifdef FLUXWEAK
				iqmax3 = MC_VecComp(i_max3, idr3);

				// speed control
#ifdef VB_RAMP
				if(RAMPLIM3)
				{
					errint3 *= K_RAMPLIM;
				}
#endif	// ifdef VB_RAMP
				f32a = f_omrif3 - omegae3;
#ifdef SPEEDPI_ERRCLAMP
				if(maxerr3 < f32a)
				{
					f32a = maxerr3;
				}
				else if(-maxerr3 > f32a)
				{
					f32a = -maxerr3;
				}
#endif	// ifdef SPEEDPI_ERRCLAMP
				iqr3 = McrpLibf_PIW(f32a, iqmax3, -iqmax3, kp_vel3, ki_vel3, &errint3);

			}	// end of normal control

		}	// end of startup and normal behaviour

		// visualization filters
		idmf3 += ((idm3 - idmf3) * visu_ukt);	// d current
		iqmf3 += ((iqm3 - iqmf3) * visu_ukt);	// q current
		vdmf3 += ((vdm3 - vdmf3) * visu_ukt);	// d voltage
		vqmf3 += ((vqm3 - vqmf3) * visu_ukt);	// q voltage
		omf3 += ((omegae3 - omf3) * visu_ukt);	// angular speed

	}	// if(COM3_ON)
	else
	{

		// speed PI integral term reset
		errint3 = 0.0f;

		// current references reset
		itr3 = iqr3 = idr3 = 0.0f;

		// measurements reset
		amp_v3 = 0.0f;
		//arg_v3 = SystemPhase;
		//amp_i3 = 0.0f;
		//arg_i3 = SystemPhase;

#ifdef FLUXWEAK
		// voltage margin reset
		vmarg3 = vfmax3;
#endif	// ifdef FLUXWEAK

		// position and speed reset
		SystemPhase3 = 0.0f;
		omegae3 = 0.0f;

		// phase detection variables reset
		Phase_est3 = FluxPhase3 = SystemPhase3;
		Speed_est3 = omegae3;
		McrpLibf_FluxEst3_SetFlux(FluxPhase3, iam3, ibm3, omegae3);
		trip3_cnt = 0;

		// startup variables and flags reset
		startup_cnt3 = 0;
		idrvar3 = 0.0f;
		iqmax3 = 0.0f;

		// filters memories reset
		f_omrif3 = 0.0f;
		iqmf3 = idmf3 = 0.0f;
		vqmf3 = vdmf3 = 0.0f;
		omf3 = 0.0f;

	}	// else of if(COM3_ON)

	// bus voltage filter and vfmax calc
	if(vbus3 < vbus_minf3)
	{
		vbus_minf3 += ((vbus3 - vbus_minf3) * vb_ukt_fast); // fast decrease
	}
	else if(vbus3 > vbus_minf3)
	{
		vbus_minf3 += ((vbus3 - vbus_minf3) * vb_ukt_slow);	// slow increase
	}
	vfmax3 = vbus_minf3 * k_vout3;

	// visualization filters
	vbusf3 += ((vbus3 - vbusf3) * visu_ukt);	// DC bus voltage

#ifdef OSC_WIN
	// management of oscilloscope window in GUI
	if(NORM_MODE && MOT3_SEL)
	{
		if(CSELD)
		{
			sample = ium3 * imax1000;
		}
		else
		{
			sample = SystemPhase3 * 1000.0f;
		}
		if(COM3_ON)
		{
			if(NOT_TRGED)
			{
				if(selmem != ((uint16_t)UIF_W.var.sel))
				{
					selmem = (uint16_t)UIF_W.var.sel;
					bcntm = selmem >> 8;
					if(0 == (selmem & 0x00FF))
					{
						RES_CSELD
					}
					else
					{
						SET_CSELD
					}
				}
				if(	((0.0f < omegae3) && (0.0f > phmem) && (0.0f <= SystemPhase3)) ||
					((0.0f > omegae3) && (0.0f < phmem) && (0.0f >= SystemPhase3)) )
				{
					SET_TRGED
					bcnt1 = 1;
					bcnt0 = 1;
					wbuf[0] = sample;
				}
			}
			else if(MAX_SAM_CNT > bcnt0)
			{
				if(bcnt1 < bcntm)
				{
					bcnt1++;
				}
				else
				{
					bcnt1 = 1;
					wbuf[bcnt0++] = sample;
				}
			}
			else if(NOT_RBUSY)
			{
				pbuf = rbuf;
				rbuf = wbuf;
				wbuf = pbuf;
				RES_TRGED
			}
		}	// COM3_ON
		else
		{
			RES_TRGED
			if(selmem != ((uint16_t)UIF_W.var.sel))
			{
				selmem = (uint16_t)UIF_W.var.sel;
				bcntm = selmem >> 8;
				if(0 == (selmem & 0x00FF))
				{
					RES_CSELD
				}
				else
				{
					SET_CSELD
				}
			}
			if(MAX_SAM_CNT > bcnt0)
			{
				wbuf[bcnt0++] = 0;
			}
			else if(NOT_RBUSY)
			{
				pbuf = rbuf;
				rbuf = wbuf;
				wbuf = pbuf;
				bcnt0 = 0;
			}
		}	// COM_OFF
		phmem = SystemPhase3;
	}	// if(NORM_MODE && MOT3_SEL)
#endif	// ifdef OSC_WIN

	RES_LD1						// debug

	// interrupt end
	return;
}

// EOF motorcontrol.c

